@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -47,8 +47,8 @@ def action_reschedule():
     if not host:
         raise MKGeneralException("Action reschedule: missing host name")
 
-    service  = html.var_utf8("service",  "")
-    wait_svc = html.var_utf8("wait_svc", "")
+    service  = html.get_unicode_input("service",  "")
+    wait_svc = html.get_unicode_input("wait_svc", "")
 
     if service:
         cmd = "SVC"
