@@ -19,11 +19,12 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
 
+import signal
 
 class MKAutomationError(Exception):
     def __init__(self, reason):
@@ -31,23 +32,56 @@ class MKAutomationError(Exception):
     def __str__(self):
         return self.reason
 
+
+def trigger_automation_timeout(signum, stackframe):
+    raise MKTimeout("Action timed out. The timeout of %d "
+                    "seconds was reached." % MKTimeout.timeout)
+
+
 def do_automation(cmd, args):
+    # Handle generic arguments (currently only the optional timeout argument)
+    if len(args) > 1 and args[0] == "--timeout":
+        args.pop(0)
+        timeout = int(args.pop(0))
+
+        if timeout:
+            MKTimeout.timeout = timeout
+            signal.signal(signal.SIGALRM, trigger_automation_timeout)
+            signal.alarm(timeout)
+
+
     try:
         if cmd == "get-configuration":
             read_config_files(with_conf_d=False)
             result = automation_get_configuration()
         elif cmd == "get-check-information":
             result = automation_get_check_information()
-        elif cmd == "delete-host":
-            read_config_files()
-            result = automation_delete_host(args)
+        elif cmd == "get-real-time-checks":
+            result = automation_get_real_time_checks()
+        elif cmd == "get-check-manpage":
+            result = automation_get_check_manpage(args)
+        elif cmd == "get-check-catalog":
+            result = automation_get_check_catalog(args)
+        elif cmd == "get-package-info":
+            result = automation_get_package_info(args)
+        elif cmd == "get-package":
+            result = automation_get_package(args)
+        elif cmd == "create-package":
+            result = automation_create_or_edit_package(args, "create")
+        elif cmd == "edit-package":
+            result = automation_create_or_edit_package(args, "edit")
+        elif cmd == "install-package":
+            result = automation_install_package(args)
+        elif cmd == "remove-package":
+            result = automation_remove_or_release_package(args, "remove")
+        elif cmd == "release-package":
+            result = automation_remove_or_release_package(args, "release")
+        elif cmd == "remove-unpackaged-file":
+            result = automation_remove_unpackaged_file(args)
         elif cmd == "notification-get-bulks":
             result = automation_get_bulks(args)
-        elif cmd == "update-dns-cache":
-            read_config_files()
-            result = automation_update_dns_cache()
         else:
-            read_config_files()
+            read_config_files(validate_hosts=False)
             if cmd == "try-inventory":
                 result = automation_try_discovery(args)
             elif cmd == "inventory":
@@ -68,20 +102,26 @@ def do_automation(cmd, args):
                 result = automation_scan_parents(args)
             elif cmd == "diag-host":
                 result = automation_diag_host(args)
-            elif cmd == "rename-host":
-                result = automation_rename_host(args)
+            elif cmd == "delete-host":
+                result = automation_delete_host(args)
+            elif cmd == "rename-hosts":
+                result = automation_rename_hosts()
             elif cmd == "create-snapshot":
                 result = automation_create_snapshot(args)
 	    elif cmd == "notification-replay":
 		result = automation_notification_replay(args)
 	    elif cmd == "notification-analyse":
 		result = automation_notification_analyse(args)
+            elif cmd == "update-dns-cache":
+                result = automation_update_dns_cache()
             elif cmd == "bake-agents":
                 result = automation_bake_agents()
+            elif cmd == "get-agent-output":
+                result = automation_get_agent_output(args)
             else:
                 raise MKAutomationError("Automation command '%s' is not implemented." % cmd)
 
-    except MKAutomationError, e:
+    except (MKAutomationError, MKTimeout), e:
         sys.stderr.write("%s\n" % e)
         if opt_debug:
             raise
@@ -104,13 +144,24 @@ def do_automation(cmd, args):
     output_profile()
     sys.exit(0)
 
-# Does inventory for *one* host. Possible values for how:
+
+# Does discovery for a list of hosts. Possible values for how:
 # "new" - find only new services (like -I)
 # "remove" - remove exceeding services
 # "fixall" - find new, remove exceeding
 # "refresh" - drop all services and reinventorize
+# Hosts on the list that are offline (unmonitored) will
+# be skipped.
 def automation_discovery(args):
 
+    # Error sensivity
+    if args[0] == "@raiseerrors":
+        args = args[1:]
+        on_error = "raise"
+        os.dup2(os.open("/dev/null", os.O_WRONLY), 2)
+    else:
+        on_error = "ignore"
+
     # perform full SNMP scan on SNMP devices?
     if args[0] == "@scan":
         do_snmp_scan = True
@@ -135,60 +186,12 @@ def automation_discovery(args):
     failed_hosts = {}
 
     for hostname in hostnames:
-        counts.setdefault(hostname, [0, 0, 0, 0]) # added, removed, kept, total
-        try:
-            # in "refresh" mode we first need to remove all previously discovered
-            # checks of the host, so that get_host_services() does show us the
-            # new discovered check parameters.
-            if how == "refresh":
-                counts[hostname][1] += remove_autochecks_of(hostname) # this is cluster-aware!
-
-            # Compute current state of new and existing checks
-            services = get_host_services(hostname, use_caches=use_caches, do_snmp_scan=do_snmp_scan)
-
-            # Create new list of checks
-            new_items = {}
-            for (check_type, item), (check_source, paramstring) in services.items():
-                if check_source in ("custom", "legacy", "active", "manual"):
-                    continue # this is not an autocheck or ignored and currently not checked
-                    # Note discovered checks that are shadowed by manual checks will vanish
-                    # that way.
-
-                if check_source in ("new"):
-                    if how in ("new", "fixall", "refresh"):
-                        counts[hostname][0] += 1 # added
-                        counts[hostname][3] += 1 # total
-                        new_items[(check_type, item)] = paramstring
-
-                elif check_source in ("old", "ignored"):
-                    # keep currently existing valid services in any case
-                    new_items[(check_type, item)] = paramstring
-                    counts[hostname][2] += 1 # kept
-                    counts[hostname][3] += 1 # total
-
-                elif check_source in ("obsolete", "vanished"):
-                    # keep item, if we are currently only looking for new services
-                    # otherwise fix it: remove ignored and non-longer existing services
-                    if how not in ("fixall", "remove"):
-                        new_items[(check_type, item)] = paramstring
-                        counts[hostname][2] += 1 # kept
-                        counts[hostname][3] += 1 # total
-                    else:
-                        counts[hostname][1] += 1 # removed
-
-                # Silently keep clustered services
-                elif check_source.startswith("clustered_"):
-                    new_items[(check_type, item)] = paramstring
-
-                else:
-                    raise MKGeneralException("Unknown check source '%s'" % check_source)
-
-            set_autochecks_of(hostname, new_items)
-
-        except Exception, e:
-	    if opt_debug:
-                raise
-            failed_hosts[hostname] = str(e)
+        result, error = discover_on_host(how, hostname, do_snmp_scan, use_caches, on_error)
+        counts[hostname] = result
+        if error is not None:
+            failed_hosts[hostname] = error
+        else:
+            trigger_discovery_check(hostname)
 
     return counts, failed_hosts
 
@@ -205,15 +208,22 @@ def automation_try_discovery(args):
         do_snmp_scan = True
         use_caches = False
 
+    if args[0] == '@raiseerrors':
+        on_error = "raise"
+        args = args[1:]
+    else:
+        on_error = "ignore"
+
     # TODO: Remove this unlucky option opt_use_cachefile. At least do not
     # handle this option so deep in the code. It should only be handled
     # by top-level functions.
-    global opt_use_cachefile, check_max_cachefile_age
-    opt_use_cachefile = use_caches
+    set_use_cachefile(use_caches)
+    global check_max_cachefile_age
     if use_caches:
         check_max_cachefile_age = inventory_max_cachefile_age
     hostname = args[0]
-    table = get_check_preview(hostname, use_caches=use_caches, do_snmp_scan=do_snmp_scan)
+    table = get_check_preview(hostname, use_caches=use_caches,
+                              do_snmp_scan=do_snmp_scan, on_error=on_error)
     return table
 
 
@@ -226,51 +236,13 @@ def automation_set_autochecks(args):
     hostname = args[0]
     new_items = eval(sys.stdin.read())
     set_autochecks_of(hostname, new_items)
-
-def set_autochecks_of(hostname, new_items):
-    # A Cluster does not have an autochecks file
-    # All of its services are located in the nodes instead
-    # So we cycle through all nodes remove all clustered service
-    # and add the ones we've got from stdin
-    if is_cluster(hostname):
-        for node in nodes_of(hostname):
-            new_autochecks = []
-            existing = parse_autochecks_file(node)
-            for check_type, item, paramstring in existing:
-                descr = service_description(check_type, item)
-                if hostname != host_of_clustered_service(node, descr):
-                    new_autochecks.append((check_type, item, paramstring))
-            for (check_type, item), paramstring in new_items.items():
-                new_autochecks.append((check_type, item, paramstring))
-            # write new autochecks file for that host
-            automation_write_autochecks_file(node, new_autochecks)
-    else:
-        existing = parse_autochecks_file(hostname)
-        # write new autochecks file, but take paramstrings from existing ones
-        # for those checks which are kept
-        new_autochecks = []
-        for ct, item, paramstring in existing:
-            if (ct, item) in new_items:
-                new_autochecks.append((ct, item, paramstring))
-                del new_items[(ct, item)]
-
-        for (ct, item), paramstring in new_items.items():
-            new_autochecks.append((ct, item, paramstring))
-
-        # write new autochecks file for that host
-        automation_write_autochecks_file(hostname, new_autochecks)
+    trigger_discovery_check(hostname)
 
 
-def automation_write_autochecks_file(hostname, table):
-    if not os.path.exists(autochecksdir):
-        os.makedirs(autochecksdir)
-    path = "%s/%s.mk" % (autochecksdir, hostname)
-    f = file(path, "w")
-    f.write("[\n")
-    for check_type, item, paramstring in table:
-        f.write("  (%r, %r, %s),\n" % (check_type, item, paramstring))
-    f.write("]\n")
-    if inventory_check_autotrigger and inventory_check_interval:
+# if required, schedule an inventory check
+def trigger_discovery_check(hostname):
+    if (inventory_check_autotrigger and inventory_check_interval) and\
+            (not is_cluster(hostname) or nodes_of(hostname)):
         schedule_inventory_check(hostname)
 
 
@@ -282,30 +254,12 @@ def automation_get_autochecks(args):
     return result
 
 
-def schedule_inventory_check(hostname):
-    try:
-        import socket
-        s = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
-        s.connect(livestatus_unix_socket)
-        now = int(time.time())
-        if 'cmk-inventory' in use_new_descriptions_for:
-            command = "SCHEDULE_FORCED_SVC_CHECK;%s;Check_MK Discovery;%d" % (hostname, now)
-        else:
-            # FIXME: Remove this old name handling one day
-            command = "SCHEDULE_FORCED_SVC_CHECK;%s;Check_MK inventory;%d" % (hostname, now)
-        s.send("COMMAND [%d] %s\n" % (now, command))
-    except Exception, e:
-        if opt_debug:
-            raise
-
-
-
 # Determine the type of the check, and how the parameters are being
 # constructed
 def automation_analyse_service(args):
     global g_hostname
     hostname = args[0]
-    servicedesc = args[1]
+    servicedesc = args[1].decode("utf-8")
     g_hostname = hostname # To be sure for all subfunctions
 
     # We just consider types of checks that are managed via WATO.
@@ -339,7 +293,7 @@ def automation_analyse_service(args):
 
             if hosttags_match_taglist(tags_of_host(hostname), taglist) and \
                in_extraconf_hostlist(hostlist, hostname):
-               descr = service_description(checktype, item)
+               descr = service_description(hostname, checktype, item)
                if descr == servicedesc:
                    return {
                        "origin"       : "static",
@@ -355,48 +309,57 @@ def automation_analyse_service(args):
     # our service there
     try:
         path = "%s/%s.mk" % (autochecksdir, hostname)
-        for entry in eval(file(path).read()):
-            if len(entry) == 4: # old format
-                hn, ct, item, params = entry
-            else:
-                ct, item, params = entry # new format without host name
-                hn = hostname
-
-            if (ct, item) not in check_table:
-                continue # this is a removed duplicate or clustered service
-            descr = service_description(ct, item)
-            if hn == hostname and descr == servicedesc:
-                dlv = check_info[ct].get("default_levels_variable")
-                if dlv:
-                    fs = factory_settings.get(dlv, None)
+        if os.path.exists(path):
+            for entry in eval(file(path).read()):
+                if len(entry) == 4: # old format
+                    hn, ct, item, params = entry
                 else:
-                    fs = None
+                    ct, item, params = entry # new format without host name
+                    hn = hostname
 
-                return {
-                    "origin"           : "auto",
-                    "checktype"        : ct,
-                    "checkgroup"       : check_info[ct].get("group"),
-                    "item"             : item,
-                    "inv_parameters"   : params,
-                    "factory_settings" : fs,
-                    "parameters"       : compute_check_parameters(hostname, ct, item, params),
-                }
+                if (ct, item) not in check_table:
+                    continue # this is a removed duplicate or clustered service
+                descr = service_description(hn, ct, item)
+                if hn == hostname and descr == servicedesc:
+                    dlv = check_info[ct].get("default_levels_variable")
+                    if dlv:
+                        fs = factory_settings.get(dlv, None)
+                    else:
+                        fs = None
+
+                    return {
+                        "origin"           : "auto",
+                        "checktype"        : ct,
+                        "checkgroup"       : check_info[ct].get("group"),
+                        "item"             : item,
+                        "inv_parameters"   : params,
+                        "factory_settings" : fs,
+                        "parameters"       : compute_check_parameters(hostname, ct, item, params),
+                    }
     except:
         if opt_debug:
             raise
 
     # 3. Classical checks
-    custchecks = host_extra_conf(hostname, custom_checks)
-    for nr, entry in enumerate(custchecks):
-        desc = entry["service_description"]
-        if desc == servicedesc:
-            result = {
-                "origin"       : "classic",
-                "rule_nr"      : nr,
-            }
-            if "command_line" in entry: # Only active checks have a command line
-                result["command_line"] = entry["command_line"]
-            return result
+    for nr, entry in enumerate(custom_checks):
+        if len(entry) == 4:
+            rule, tags, hosts, options = entry
+            if options.get("disabled"):
+                continue
+        else:
+            rule, tags, hosts = entry
+
+        matching_hosts = all_matching_hosts(tags, hosts, with_foreign_hosts = True)
+        if hostname in matching_hosts:
+            desc = rule["service_description"]
+            if desc == servicedesc:
+                result = {
+                    "origin"       : "classic",
+                    "rule_nr"      : nr,
+                }
+                if "command_line" in rule: # Only active checks have a command line
+                    result["command_line"] = rule["command_line"]
+                return result
 
     # 4. Active checks
     for acttype, rules in active_checks.items():
@@ -419,17 +382,53 @@ def automation_analyse_service(args):
 
 def automation_delete_host(args):
     hostname = args[0]
-    for path in [
-        "%s/%s"    % (precompiled_hostchecks_dir, hostname),
-        "%s/%s.py" % (precompiled_hostchecks_dir, hostname),
-        "%s/%s.mk" % (autochecksdir, hostname),
-        "%s/%s"    % (logwatch_dir, hostname),
-        "%s/%s"    % (counters_directory, hostname),
-        "%s/%s"    % (tcp_cache_dir, hostname),
-        "%s/%s.*"  % (tcp_cache_dir, hostname)]:
-        os.system("rm -rf '%s'" % path)
 
-def automation_restart(job = "restart", use_rushd = True):
+    # the inventory_archive as well as the performance data is kept
+    # we do not want to loose any historic data for accidently deleted hosts
+
+    # single files
+    for path in [
+        "%s/%s"                  % (precompiled_hostchecks_dir, hostname),
+        "%s/%s.py"               % (precompiled_hostchecks_dir, hostname),
+        "%s/%s.mk"               % (autochecksdir, hostname),
+        "%s/%s"                  % (counters_directory, hostname),
+        "%s/%s"                  % (tcp_cache_dir, hostname),
+        "%s/persisted/%s"        % (var_dir, hostname),
+        "%s/inventory/%s"        % (var_dir, hostname),
+        "%s/inventory/%s.gz"     % (var_dir, hostname),
+        "%s/agent_deployment/%s" % (var_dir, hostname),
+        ]:
+        if os.path.exists(path):
+            os.unlink(path)
+
+    # files from snmp devices
+    for filename in os.listdir(tcp_cache_dir):
+        if filename.startswith("%s." % hostname):
+            os.unlink("%s/%s" % (tcp_cache_dir, filename))
+
+    # softlinks for baked agents. obsolete packages are removed upon next bake action
+    agents_dir = var_dir + "/agents/"
+    if os.path.exists(agents_dir):
+        for folder in os.listdir(agents_dir):
+            if os.path.exists("%s/%s" % (folder, hostname)):
+                os.unlink("%s/%s" % (folder, hostname))
+
+    # logwatch and piggyback folders
+    import shutil
+    for what_dir in [ "%s/%s" % (logwatch_dir, hostname),
+                      "%s/piggyback/%s" % (tmp_dir, hostname), ]:
+        if os.path.exists(what_dir):
+            shutil.rmtree(what_dir)
+
+
+def automation_restart(job = "restart"):
+    if check_plugins_have_changed():
+        forced = True
+        job = "restart"
+    else:
+        forced = False
+
+
     # make sure, Nagios does not inherit any open
     # filedescriptors. This really happens, e.g. if
     # check_mk is called by WATO via Apache. Nagios inherits
@@ -444,7 +443,7 @@ def automation_restart(job = "restart", use_rushd = True):
                 pass
     else:
         objects_file = var_dir + "/core/config"
-        if job == "restart":
+        if job == "restart" and not forced:
             job = "reload" # force reload for CMC
 
     # os.closerange(3, 256) --> not available in older Python versions
@@ -461,7 +460,7 @@ def automation_restart(job = "restart", use_rushd = True):
 
     try:
         backup_path = None
-        if not lock_objects_file():
+        if another_activation_is_in_progress():
             raise MKAutomationError("Cannot activate changes. "
                   "Another activation process is currently in progresss")
 
@@ -472,10 +471,7 @@ def automation_restart(job = "restart", use_rushd = True):
             backup_path = None
 
         try:
-            if monitoring_core == "nagios":
-                create_nagios_config(file(objects_file, "w"))
-            else:
-                do_create_cmc_config(opt_cmc_relfilename, use_rushd = use_rushd)
+            configuration_warnings = create_core_config()
 
             if "do_bake_agents" in globals() and bake_agents_on_restart:
                 do_bake_agents()
@@ -510,6 +506,35 @@ def automation_restart(job = "restart", use_rushd = True):
         raise MKAutomationError(str(e))
 
     sys.stdout = old_stdout
+    return configuration_warnings
+
+
+def check_plugins_have_changed():
+    if not omd_root:
+        return False # not supported for manual setup
+
+    this_time = last_modification_in_dir(local_checks_dir)
+    last_time = time_of_last_core_restart()
+    return this_time > last_time
+
+
+def last_modification_in_dir(dir_path):
+    max_time = os.stat(dir_path).st_mtime
+    for file_name in os.listdir(dir_path):
+        max_time = max(max_time, os.stat(dir_path + "/" + file_name).st_mtime)
+    return max_time
+
+
+def time_of_last_core_restart():
+    if monitoring_core == "cmc":
+        pidfile_path = omd_root + "/tmp/run/cmc.pid"
+    else:
+        pidfile_path = omd_root + "/tmp/lock/nagios.lock"
+    if os.path.exists(pidfile_path):
+        return os.stat(pidfile_path).st_mtime
+    else:
+        return 0
+
 
 def automation_get_configuration():
     # We read the list of variable names from stdin since
@@ -522,22 +547,117 @@ def automation_get_configuration():
                 result[varname] = globals()[varname]
     return result
 
+
+def automation_get_check_catalog(args):
+    def path_prefix_matches(p, op):
+        if op and not p:
+            return False
+        elif not op:
+            return True
+        else:
+            return p[0] == op[0] and path_prefix_matches(p[1:], op[1:])
+
+    read_manpage_catalog()
+    tree = {}
+    if len(args) > 0:
+        only_path = tuple(args)
+    else:
+        only_path = ()
+
+    for path, entries in g_manpage_catalog.items():
+        if not path_prefix_matches(path, only_path):
+            continue
+        subtree = tree
+        for component in path[:-1]:
+            subtree = subtree.setdefault(component, {})
+        subtree[path[-1]] = map(strip_manpage_entry, entries)
+
+    for p in only_path:
+        tree = tree[p]
+
+    return tree, manpage_catalog_titles
+
+def strip_manpage_entry(entry):
+    return dict([ (k,v) for (k,v) in entry.items() if k in [
+        "name", "agents", "title"
+    ]])
+
 def automation_get_check_information():
     manuals = all_manuals()
+
     checks = {}
     for check_type, check in check_info.items():
-        manfile = manuals.get(check_type)
-        if manfile:
-            title = file(manfile).readline().strip().split(":", 1)[1].strip()
-        else:
-            title = check_type
-        checks[check_type] = { "title" : title }
-        if check["group"]:
-            checks[check_type]["group"] = check["group"]
-        checks[check_type]["service_description"] = check.get("service_description","%s")
-        checks[check_type]["snmp"] = check_uses_snmp(check_type)
+        try:
+            manfile = manuals.get(check_type)
+            if manfile:
+                title = file(manfile).readline().strip().split(":", 1)[1].strip()
+            else:
+                title = check_type
+            checks[check_type] = { "title" : title }
+            if check["group"]:
+                checks[check_type]["group"] = check["group"]
+            checks[check_type]["service_description"] = check.get("service_description","%s")
+            checks[check_type]["snmp"] = check_uses_snmp(check_type)
+        except Exception, e:
+            if opt_debug:
+                raise
+            raise MKAutomationError("Failed to parse man page '%s': %s" % (check_type, e))
     return checks
 
+
+def automation_get_real_time_checks():
+    manuals = all_manuals()
+
+    checks = []
+    for check_type, check in check_info.items():
+        if check["handle_real_time_checks"]:
+            title = check_type
+            try:
+                manfile = manuals.get(check_type)
+                if manfile:
+                    title = file(manfile).readline().strip().split(":", 1)[1].strip()
+            except Exception, e:
+                if opt_debug:
+                    raise
+
+            checks.append((check_type, "%s - %s" % (check_type, title)))
+
+    return checks
+
+
+def automation_get_check_manpage(args):
+    if len(args) != 1:
+        raise MKAutomationError("Need exactly one argument.")
+
+    check_type = args[0]
+    manpage = load_manpage(args[0])
+
+    # Add a few informations from check_info. Note: active checks do not
+    # have an entry in check_info
+    if check_type in check_info:
+        manpage["type"] = "check_mk"
+        info = check_info[check_type]
+        for key in [ "snmp_info", "has_perfdata", "service_description" ]:
+            if key in info:
+                manpage[key] = info[key]
+        if "." in check_type:
+            section = check_type.split(".")[0]
+            if section in check_info and "snmp_info" in check_info[section]:
+                manpage["snmp_info"] = check_info[section]["snmp_info"]
+
+        if "group" in info:
+            manpage["group"] = info["group"]
+
+    # Assume active check
+    elif check_type.startswith("check_"):
+        manpage["type"] = "active"
+    else:
+        raise MKAutomationError("Could not detect type of manpage: %s. "
+                                "Maybe the check is missing." % check_type)
+
+    return manpage
+
+
 def automation_scan_parents(args):
     settings = {
         "timeout"     : int(args[0]),
@@ -565,13 +685,16 @@ def automation_diag_host(args):
 
     if not ipaddress:
         try:
-            ipaddress = lookup_ipaddress(hostname)
+            ipaddress = lookup_ip_address(hostname)
         except:
             raise MKGeneralException("Cannot resolve hostname %s into IP address" % hostname)
 
+    ipv6_primary = is_ipv6_primary(hostname)
+
     try:
         if test == 'ping':
-            p = subprocess.Popen('ping -A -i 0.2 -c 2 -W 5 %s 2>&1' % ipaddress, shell = True, stdout = subprocess.PIPE)
+            base_cmd = ipv6_primary and "ping6" or "ping"
+            p = subprocess.Popen('%s -A -i 0.2 -c 2 -W 5 %s 2>&1' % (base_cmd, ipaddress), shell = True, stdout = subprocess.PIPE)
             response = p.stdout.read()
             return (p.wait(), response)
 
@@ -589,7 +712,8 @@ def automation_diag_host(args):
             if not traceroute_prog:
                 return 1, "Cannot find binary <tt>traceroute</tt>."
             else:
-                p = subprocess.Popen('traceroute -n %s 2>&1' % ipaddress, shell = True, stdout = subprocess.PIPE)
+                family_flag = ipv6_primary and "-6" or "-4"
+                p = subprocess.Popen('traceroute %s -n %s 2>&1' % (family_flag, ipaddress), shell = True, stdout = subprocess.PIPE)
                 response = p.stdout.read()
                 return (p.wait(), response)
 
@@ -621,7 +745,8 @@ def automation_diag_host(args):
             else:
                 return 1, "SNMP command not implemented"
 
-            data = get_snmp_table(hostname, ipaddress, None, ('.1.3.6.1.2.1.1', ['1.0', '4.0', '5.0', '6.0']))
+            data = get_snmp_table(hostname, ipaddress, None,
+                                  ('.1.3.6.1.2.1.1', ['1.0', '4.0', '5.0', '6.0']), use_snmpwalk_cache=True)
             if data:
                 return 0, 'sysDescr:\t%s\nsysContact:\t%s\nsysName:\t%s\nsysLocation:\t%s\n' % tuple(data[0])
             else:
@@ -635,20 +760,56 @@ def automation_diag_host(args):
             raise
         return 1, str(e)
 
-# WATO calls this automation when a host has been renamed. We need to change
-# several file and directory names.
-# HIRN: Hier auch das neue Format berücksichtigen! Andererseits sollte
-# eigentlich auch nix Schlimmes passieren, wenn der Hostname *nicht* in
-# der Datei steht.
-def automation_rename_host(args):
-    oldname = args[0]
-    newname = args[1]
+# WATO calls this automation when hosts have been renamed. We need to change
+# several file and directory names. This function has no argument but reads
+# Python pair-list from stdin:
+# [("old1", "new1"), ("old2", "new2")])
+def automation_rename_hosts():
+    renamings = eval(sys.stdin.read())
+
     actions = []
 
-    # Autochecks: simply read and write out the file again. We do
-    # not store a host name here anymore - but old versions did.
-    # by rewriting we get rid of the host name.
+    # At this place WATO already has changed it's configuration. All further
+    # data might be changed by the still running core. So we need to stop
+    # it now.
+    core_was_running = core_is_running()
+    if core_was_running:
+        do_core_action("stop", quiet=True)
 
+    for oldname, newname in renamings:
+        # Autochecks: simply read and write out the file again. We do
+        # not store a host name here anymore - but old versions did.
+        # by rewriting we get rid of the host name.
+        actions += rename_host_autochecks(oldname, newname)
+        actions += rename_host_files(oldname, newname)
+
+    # Start monitoring again. In case of CMC we need to ignore
+    # any configuration created by the CMC Rushahead daemon
+    if core_was_running:
+        global ignore_ip_lookup_failures
+        ignore_ip_lookup_failures = True # force config generation to succeed. The core *must* start.
+        automation_restart("start")
+        if monitoring_core == "cmc":
+            try:
+                os.remove(var_dir + "/core/config.rush")
+                os.remove(var_dir + "/core/config.rush.id")
+            except:
+                pass
+
+        for hostname in g_failed_ip_lookups:
+            actions.append("dnsfail-" + hostname)
+
+    # Convert actions into a dictionary { "what" : count }
+    action_counts = {}
+    for action in actions:
+        action_counts.setdefault(action, 0)
+        action_counts[action] += 1
+
+    return action_counts
+
+
+def rename_host_autochecks(oldname, newname):
+    actions = []
     acpath = autochecksdir + "/" + oldname + ".mk"
     if os.path.exists(acpath):
         old_autochecks = parse_autochecks_file(oldname)
@@ -660,13 +821,11 @@ def automation_rename_host(args):
         out.close()
         os.remove(acpath) # Remove old file
         actions.append("autochecks")
+    return actions
 
-    # At this place WATO already has changed it's configuration. All further
-    # data might be changed by the still running core. So we need to stop
-    # it now.
-    core_was_running = core_is_running()
-    if core_was_running:
-        do_core_action("stop", quiet=True)
+
+def rename_host_files(oldname, newname):
+    actions = []
 
     # Rename temporary files of the host
     for d in [ "cache", "counters" ]:
@@ -691,28 +850,35 @@ def automation_rename_host(args):
     if rename_host_file(snmpwalks_dir, oldname, newname):
         actions.append("snmpwalk")
 
+    # HW/SW-Inventory
+    if rename_host_file(var_dir + "/inventory", oldname, newname):
+        rename_host_file(var_dir + "/inventory", oldname + ".gz", newname + ".gz")
+        actions.append("inv")
+
+    if rename_host_dir(var_dir + "/inventory_archive", oldname, newname):
+        actions.append("invarch")
+
+    # Baked agents
+    agents_dir = var_dir + "/agents/"
+    have_renamed_agent = False
+    if os.path.exists(agents_dir):
+        for opsys in os.listdir(agents_dir):
+            if rename_host_file(agents_dir + opsys, oldname, newname):
+                have_renamed_agent = True
+    if have_renamed_agent:
+        actions.append("agent")
+
+    # Agent deployment
+    deployment_dir = var_dir + "/agent_deployment/"
+    if rename_host_file(deployment_dir, oldname, newname):
+        actions.append("agent_deployment")
+
     # OMD-Stuff. Note: The question really is whether this should be
     # included in Check_MK. The point is - however - that all these
     # actions need to take place while the core is stopped.
     if omd_root:
         actions += omd_rename_host(oldname, newname)
 
-    # Start monitoring again. In case of CMC we need to ignore
-    # any configuration created by the CMC Rushahead daemon
-    if core_was_running:
-        global ignore_ip_lookup_failures
-        ignore_ip_lookup_failures = True # force config generation to succeed. The core *must* start.
-        automation_restart("start", use_rushd = False)
-        if monitoring_core == "cmc":
-            try:
-                os.remove(var_dir + "/core/config.rush")
-                os.remove(var_dir + "/core/config.rush.id")
-            except:
-                pass
-
-        if failed_ip_lookups:
-            actions.append("ipfail")
-
     return actions
 
 
@@ -823,6 +989,11 @@ s/(HOST|SERVICE) NOTIFICATION: ([^;]+);%(old)s;/\1 NOTIFICATION: \2;%(new)s;/
 
 
 def automation_create_snapshot(args):
+    if args and args[0] == "sync":
+        sync_mode = True
+    else:
+        sync_mode = False
+
     try:
         import tarfile, time, cStringIO, shutil, subprocess, thread, traceback, threading
         from hashlib import sha256
@@ -879,8 +1050,11 @@ def automation_create_snapshot(args):
         try:
             pid = os.fork()
             if pid > 0:
+                if sync_mode:
+                    os.waitpid(pid, 0)
                 # Exit parent process
                 return
+
             # Decouple from parent environment
             os.chdir("/")
             os.umask(0)
@@ -1058,16 +1232,20 @@ def automation_notification_replay(args):
     nr = args[0]
     return notification_replay_backlog(int(nr))
 
+
 def automation_notification_analyse(args):
     nr = args[0]
     return notification_analyse_backlog(int(nr))
 
+
 def automation_get_bulks(args):
     only_ripe = args[0] == "1"
     return find_bulks(only_ripe)
 
+
 def automation_active_check(args):
     hostname, plugin, item = args
+    item = item.decode("utf-8")
     actchecks = []
     needed_commands = []
 
@@ -1107,19 +1285,17 @@ def load_resource_file(macros):
         if opt_debug:
             raise
 
+
 # Simulate replacing some of the more important macros of hosts. We
 # cannot use dynamic macros, of course. Note: this will not work
 # without OMD, since we do not know the value of $USER1$ and $USER2$
 # here. We could read the Nagios resource.cfg file, but we do not
 # know for sure the place of that either.
 def replace_core_macros(hostname, commandline):
-    macros  = {
-        "$HOSTNAME$"    : hostname,
-        "$HOSTADDRESS$" : lookup_ipaddress(hostname),
-    }
+    macros = get_basic_host_macros_from_attributes(hostname, get_host_attributes(hostname))
     load_resource_file(macros)
     for varname, value in macros.items():
-        commandline = commandline.replace(varname, value)
+        commandline = commandline.replace(varname, str(value))
     return commandline
 
 
@@ -1149,6 +1325,107 @@ def execute_check_plugin(commandline):
 def automation_update_dns_cache():
     return do_update_dns_cache()
 
+
 def automation_bake_agents():
     if "do_bake_agents" in globals():
         return do_bake_agents()
+
+
+def automation_get_agent_output(args):
+    hostname, ty = args
+
+    success    = True
+    output     = ""
+    agent_data = ""
+
+    try:
+        if ty == "agent":
+            agent_data = get_plain_hostinfo(hostname)
+        else:
+            path = snmpwalks_dir + "/" + hostname
+            do_snmpwalk_on(hostname, snmpwalks_dir + "/" + hostname)
+            agent_data = file(snmpwalks_dir + "/" + hostname).read()
+    except Exception, e:
+        success = False
+        output = "Failed to fetch data from %s: %s\n" % (hostname, e)
+        if opt_debug:
+            raise
+
+    return success, output, agent_data
+
+
+def automation_get_package_info(args):
+    load_module("packaging")
+    packages = {}
+    for package_name in all_package_names():
+        packages[package_name] = read_package_info(package_name)
+
+    return {
+        "installed" : packages,
+        "unpackaged" : unpackaged_files(),
+        "parts" : package_part_info(),
+    }
+
+
+def automation_get_package(args):
+    load_module("packaging")
+    package_name = args[0]
+    package = read_package_info(package_name)
+    if not package:
+        raise MKAutomationError("Package not installed or corrupt")
+
+    output_file = fake_file()
+    create_mkp_file(package, file_object=output_file)
+    return package, output_file.content()
+
+
+def automation_create_or_edit_package(args, mode):
+    load_module("packaging")
+    package_name = args[0]
+    new_package_info = eval(sys.stdin.read())
+    if mode == "create":
+        create_package(new_package_info)
+    else:
+        edit_package(package_name, new_package_info)
+
+
+def automation_install_package(args):
+    load_module("packaging")
+    file_content = sys.stdin.read()
+    input_file = fake_file(file_content)
+    try:
+        return install_package(file_object=input_file)
+    except Exception, e:
+        if opt_debug:
+            raise
+        raise MKAutomationError("Cannot install package: %s" % e)
+
+
+def automation_remove_or_release_package(args, mode):
+    load_module("packaging")
+    package_name = args[0]
+    package = read_package_info(package_name)
+    if not package:
+        raise MKAutomationError("Package not installed or corrupt")
+    if mode == "remove":
+        remove_package(package)
+    else:
+        remove_package_info(package_name)
+
+
+def automation_remove_unpackaged_file(args):
+    load_module("packaging")
+    part_name = args[0]
+    if part_name not in [ p[0] for p in package_parts ]:
+        raise MKAutomationError("Invalid package part")
+
+    rel_path = args[1]
+    if "../" in rel_path or rel_path.startswith("/"):
+        raise MKAutomationError("Invalid file name")
+
+    for part, title, perm, dir in package_parts:
+        if part == part_name:
+            abspath = dir + "/" + rel_path
+            if not os.path.isfile(abspath):
+                raise MKAutomationError("No such file")
+            os.remove(abspath)
