@@ -19,12 +19,13 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
 
 import os, pprint, glob
+import i18n
 from lib import *
 
 # In case we start standalone and outside a Check_MK enviroment,
@@ -35,15 +36,11 @@ try:
 except:
     import defaults_standalone as defaults
 
-# Python 2.3 does not have 'set' in normal namespace.
-# But it can be imported from 'sets'
-# FIXME: We should officially drop Python 2.3 support
-try:
-    set()
-except NameError:
-    from sets import Set as set
+# FIXME: Make clear whether or not user related values should be part
+# of the "config" module. Maybe move to dedicated module (userdb?). Then
+# move all user related stuff there. e.g. html.user should also be moved
+# there.
 
-#.
 #   .--Declarations--------------------------------------------------------.
 #   |       ____            _                 _   _                        |
 #   |      |  _ \  ___  ___| | __ _ _ __ __ _| |_(_) ___  _ __  ___        |
@@ -58,6 +55,7 @@ except NameError:
 
 user = None
 user_id = None
+user_confdir = None
 builtin_role_ids = [ "user", "admin", "guest" ] # hard coded in various permissions
 user_role_ids = []
 
@@ -88,6 +86,7 @@ HOST_STATE = ('__HOST_STATE__',)
 HIDDEN = ('__HIDDEN__',)
 class FOREACH_HOST: pass
 class FOREACH_CHILD: pass
+class FOREACH_CHILD_WITH: pass
 class FOREACH_PARENT: pass
 class FOREACH_SERVICE: pass
 class REMAINING: pass
@@ -132,12 +131,16 @@ def include(filename):
 
 # Load multisite.mk and all files in multisite.d/. This will happen
 # for *each* HTTP request.
+# FIXME: Optimize this to cache the config etc. until either the config files or plugins
+# have changed. We could make this being cached for multiple requests just like the
+# plugins of other modules. This may save significant time in case of small requests like
+# the graph ajax page or similar.
 def load_config():
-    global modification_timestamps
+    global modification_timestamps, sites
     modification_timestamps = []
 
     # Set default values for all user-changable configuration settings
-    load_plugins()
+    load_plugins(True)
 
     # First load main file
     include("multisite.mk")
@@ -155,6 +158,12 @@ def load_config():
     for p in filelist:
         include(p)
 
+    # Prevent problem when user has deleted all sites from his configuration
+    # and sites is {}. We assume a default single site configuration in
+    # that case.
+    if not sites:
+        sites = default_single_site_configuration()
+
 
 def reporting_available():
     try:
@@ -238,21 +247,23 @@ def login(u):
 
     # Get best base roles and use as "the" role of the user
     global user_baserole_id
-    if "admin" in user_role_ids:
+    if "admin" in user_baserole_ids:
         user_baserole_id = "admin"
-    elif "user" in user_role_ids:
+    elif "user" in user_baserole_ids:
         user_baserole_id = "user"
     else:
         user_baserole_id = "guest"
 
     # Prepare user object
-    global user, user_alias
+    global user, user_alias, user_email
     if u in multisite_users:
         user = multisite_users[u]
         user_alias = user.get("alias", user_id)
+        user_email = user.get("email", user_id)
     else:
         user = { "roles" : user_role_ids }
         user_alias = user_id
+        user_email = user_id
 
     # Prepare cache of already computed permissions
     global user_permissions
@@ -266,45 +277,82 @@ def login(u):
         user_permissions["wato.users"]  = True # ... with access to user management
 
     # Prepare users' own configuration directory
-    global user_confdir
-    user_confdir = config_dir + "/" + user_id
-    make_nagios_directory(user_confdir)
+    set_user_confdir(user_id)
 
     # load current on/off-switching states of sites
     read_site_config()
 
+# Login a user that has all permissions. This is needed for making
+# Livestatus queries from unauthentiated page handlers
+def login_super_user():
+    global user_id
+    user_id = None
+
+    global user_role_ids
+    user_role_ids = [ "admin" ]
+
+    global user_baserole_ids
+    user_baserole_ids = [ "admin" ]
+
+    global user_baserole_id
+    user_baserole_id = "admin"
+
+    # Prepare user object
+    global user, user_alias, user_email
+    user = { "roles" : "admin" }
+    user_alias = "Superuser for unauthenticated pages"
+    user_email = "admin"
+
+    # Prepare cache of already computed permissions
+    global user_permissions
+    user_permissions = {}
+
+    # All sites are enabled
+    global user_siteconf
+    user_siteconf = {}
+
+def set_user_confdir(user_id):
+    global user_confdir
+    user_confdir = config_dir + "/" + user_id.encode("utf-8")
+    make_nagios_directory(user_confdir)
+
 def get_language(default = None):
-    if default == None:
-        default = default_language
-    return user and user.get('language', default) or default
+    if user and "language" in user:
+        return user["language"]
+    elif default == None:
+        return default_language
+    else:
+        return default
 
 def hide_language(lang):
     return lang in hide_languages
 
 def roles_of_user(user):
-    # Make sure, builtin roles are present, even if not modified
-    # and saved with WATO.
-    for br in builtin_role_ids:
-        if br not in roles:
-            roles[br] = {}
-
     if user in multisite_users:
-        return multisite_users[user]["roles"]
+        return existing_role_ids(multisite_users[user]["roles"])
     elif user in admin_users:
         return [ "admin" ]
     elif user in guest_users:
         return [ "guest" ]
     elif users != None and user in users:
         return [ "user" ]
-    elif os.path.exists(config_dir + "/" + user + "/automation.secret"):
+    elif os.path.exists(config_dir + "/" + user.encode("utf-8") + "/automation.secret"):
         return [ "guest" ] # unknown user with automation account
     elif 'roles' in default_user_profile:
-        return default_user_profile['roles']
+        return existing_role_ids(default_user_profile['roles'])
     elif default_user_role:
-        return [ default_user_role ]
+        return existing_role_ids([ default_user_role ])
     else:
         return []
 
+
+def existing_role_ids(role_ids):
+    return [
+        role_id for role_id in role_ids
+        if role_id in roles
+    ]
+
+
 def alias_of_user(user):
     if user in multisite_users:
         return multisite_users[user].get("alias", user)
@@ -375,12 +423,6 @@ def get_role_permissions():
     # and for each permission loop all roles
     # and check wether it has the permission or not
 
-    # Make sure, builtin roles are present, even if not modified
-    # and saved with WATO.
-    for br in builtin_role_ids:
-        if br not in roles:
-            roles[br] = {}
-
     roleids = roles.keys()
     for perm in permissions_by_order:
         for role_id in roleids:
@@ -400,29 +442,45 @@ def save_stars(stars):
 
 # Helper functions
 def load_user_file(name, deflt, lock = False):
-    path = user_confdir + "/" + name + ".mk"
-    try:
-        if lock:
-            aquire_lock(path)
+    # In some early error during login phase there are cases where it might
+    # happen that a user file is requested byt the user_confdir is not yet
+    # set. We have all information to set it, then do it.
+    if user_confdir == None:
+        if user_id:
+            set_user_confdir(user_id)
+        else:
+            return deflt # No user known at this point of time
 
+    path = user_confdir + "/" + name + ".mk"
+
+    if lock:
+        aquire_lock(path)
+
+    try:
         return eval(file(path).read())
     except:
+        # TODO: Really "throw user data away" and start over?
         return deflt
 
-def save_user_file(name, content, unlock = False):
-    path = user_confdir + "/" + name + ".mk"
-    try:
-        write_settings_file(path, content)
+def save_user_file(name, content, unlock=False, user=None):
+    if user == None:
+        user = user_id
+    dirname = config_dir + "/" + user.encode("utf-8")
+    make_nagios_directory(dirname)
+    path = dirname + "/" + name + ".mk"
 
+    try:
+        try:
+            write_settings_file(path + ".new", content)
+            os.rename(path + ".new", path)
+        except Exception, e:
+            if debug:
+                raise
+            raise MKConfigError(_("Cannot save %s options for user <b>%s</b> into <b>%s</b>: %s") % \
+                    (name, user, path, e))
+    finally:
         if unlock:
             release_lock(path)
-    except Exception, e:
-        # Error while writing file -> release lock
-        release_lock(path)
-        if debug:
-            raise
-        raise MKConfigError(_("Cannot save %s options for user <b>%s</b> into <b>%s</b>: %s") % \
-                (name, user_id, path, e))
 
 #.
 #   .--Sites---------------------------------------------------------------.
@@ -436,9 +494,33 @@ def save_user_file(name, content, unlock = False):
 #   |  The config module provides some helper functions for sites.         |
 #   '----------------------------------------------------------------------'
 
-sites = { "": {} }
+
 use_siteicons = False
 
+def default_single_site_configuration():
+    if defaults.omd_site:
+        site_name = defaults.omd_site
+        site_alias = _("Local site %s") % site_name
+    else:
+        site_name = "local"
+        site_alias = _("Local site")
+
+    return {
+        site_name: {
+            'alias'        : site_alias,
+            'disable_wato' : True,
+            'disabled'     : False,
+            'insecure'     : False,
+            'multisiteurl' : '',
+            'persist'      : False,
+            'replicate_ec' : False,
+            'replication'  : '',
+            'timeout'      : 10,
+            'user_login'   : True,
+    }}
+
+sites = default_single_site_configuration()
+
 def sitenames():
     return sites.keys()
 
@@ -469,21 +551,36 @@ def site(name):
     s["id"] = name
     return s
 
-def site_is_local(name):
-    s = sites.get(name, {})
+
+def site_is_local(site_name):
+    s = sites.get(site_name, {})
     sock = s.get("socket")
     return not sock or sock == "unix:" + defaults.livestatus_unix_socket
 
-# FIXME: Should this return True even if all sites but one are disabled?
-# -> should we use allsites() instead of "sites" directly?
+
+def default_site():
+    for site_name, site in sites.items():
+        if site_is_local(site_name):
+            return site_name
+    try:
+        return config.sites.keys()[0]
+    except:
+        return None
+
+
 def is_multisite():
+    # TODO: Remove all calls of this function
+    return True
+
+def is_single_local_site():
     if len(sites) > 1:
-        return True
-    elif len(sites) == 0:
         return False
-    # Also use Multisite mode if the one and only site is not local
-    sitename = sites.keys()[0]
-    return not site_is_local(sitename)
+    elif len(sites) == 0:
+        return True
+    else:
+        # Also use Multisite mode if the one and only site is not local
+        sitename = sites.keys()[0]
+        return site_is_local(sitename)
 
 def read_site_config():
     global user_siteconf
@@ -505,7 +602,9 @@ def save_site_config():
 #   |  declare defaults for configuration variables.                       |
 #   '----------------------------------------------------------------------'
 
-def load_plugins():
+def load_plugins(force):
     load_web_plugins("config", globals())
 
-load_plugins()
+    # Make sure, builtin roles are present, even if not modified and saved with WATO.
+    for br in builtin_role_ids:
+        roles.setdefault(br, {})
