@@ -5,7 +5,7 @@
 // |           | |___| | | |  __/ (__|   <    | |  | | . \            |
 // |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
 // |                                                                  |
-// | Copyright Mathias Kettner 2013             mk@mathias-kettner.de |
+// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
 // +------------------------------------------------------------------+
 //
 // This file is part of Check_MK.
@@ -26,8 +26,7 @@
 // into the "Application" eventlog (at your own risk). Compile it with
 // 'make crash'
 
-int main(int argc, char **argv)
-{
+int main(int argc, char **argv) {
     char *p = 0x00000000;
     *p = 17;
 }
