@@ -19,11 +19,16 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
 
+try:
+    import simplejson as json
+except ImportError:
+    import json
+
 #   .--Overview------------------------------------------------------------.
 #   |              ___                       _                             |
 #   |             / _ \__   _____ _ ____   _(_) _____      __              |
@@ -207,8 +212,13 @@ def render_statistics(pie_id, what, table, filter, dashlet):
     pie_left_aspect  = 0.5
     pie_right_aspect = 0.8
 
-    info = what == 'hosts' and 'host' or 'service'
-    use_filters = visuals.filters_of_visual(dashlet, [info])
+    if what == 'hosts':
+        info = 'host'
+        infos = [ info ]
+    else:
+        info = 'service'
+        infos = [ 'host', 'service' ]
+    use_filters = visuals.filters_of_visual(dashlet, infos)
     for filt in use_filters:
         if filt.available() and not isinstance(filt, visuals.FilterSite):
             filter += filt.filter(info)
@@ -236,14 +246,25 @@ def render_statistics(pie_id, what, table, filter, dashlet):
 
     html.write('<table class="hoststats%s" style="float:left">' % (
         len(pies) > 1 and " narrow" or ""))
+
     table_entries = pies
     while len(table_entries) < 6:
         table_entries = table_entries + [ (("", "#95BBCD", "", ""), "&nbsp;") ]
     table_entries.append(((_("Total"), "", "all%s" % what, ""), total))
+
     for (name, color, viewurl, query), count in table_entries:
-        url = "view.py?view_name=" + viewurl + "&filled_in=filter&search=1&wato_folder="
+        url = "view.py?view_name=" + viewurl + "&filled_in=filter&search=1"
         for filter_name, url_params in dashlet['context'].items():
-            url += '&' + html.urlencode_vars(url_params.items())
+            if filter_name == "wato_folder" and html.has_var("wato_folder"):
+                url += "&wato_folder=" + html.var("wato_folder")
+
+            elif filter_name == "svcstate":
+                # The svcstate filter URL vars are controlled by dashlet
+                continue
+
+            else:
+                url += '&' + html.urlencode_vars(url_params.items())
+
         html.write('<tr><th><a href="%s">%s</a></th>' % (url, name))
         style = ''
         if color:
@@ -330,7 +351,12 @@ if (has_canvas_support()) {
 #   | Renders a single performance graph                                   |
 #   '----------------------------------------------------------------------'
 
-def make_pnp_url(dashlet, what):
+
+def dashlet_graph(nr, dashlet):
+    html.write('<div id="dashlet_graph_%d"></div>' % (nr))
+
+
+def dashlet_graph_reload_js(nr, dashlet):
     host = dashlet['context'].get('host')
     if not host:
         raise MKUserError('host', _('Missing needed host parameter.'))
@@ -346,34 +372,43 @@ def make_pnp_url(dashlet, what):
     else:
         html.live.set_prepend_site(True)
         query = "GET hosts\nFilter: name = %s\nColumns: name" % lqencode(host)
-        site = html.live.query_column(query)[0]
+        try:
+            site = html.live.query_column(query)[0]
+        except IndexError:
+            raise MKUserError("host", _("The host could not be found on any active site."))
         html.live.set_prepend_site(False)
 
-    if not site:
-        base_url = defaults.url_prefix
-    else:
-        base_url = html.site_status[site]["site"]["url_prefix"]
+    # New graphs which have been added via "add to visual" option don't have a timerange
+    # configured. So we assume the default timerange here by default.
+    timerange = dashlet.get('timerange', '1')
 
-    base_url += "pnp4nagios/index.php/"
-    var_part = "?host=%s&srv=%s&source=%d&view=%s&theme=multisite" % \
-            (pnp_cleanup(dashlet['context']['host']), pnp_cleanup(service),
-             dashlet['source'], dashlet['timerange'])
-    return base_url + what + var_part
+    graph_specification = ("template", {
+        "site"                : site,
+        "host_name"           : host,
+        "service_description" : service,
+        "graph_index"         : dashlet["source"] -1,
+    })
+    graph_render_options = {
+        "show_legend": dashlet.get("show_legend", False),
+        "show_service" : dashlet.get("show_service", True),
+    }
+
+    return "dashboard_render_graph(%d, %s, %s, '%s')" % \
+            (nr, json.dumps(graph_specification), json.dumps(graph_render_options), timerange)
 
-def dashlet_pnpgraph(nr, dashlet):
-    html.write('<a href="%s" id="dashlet_graph_%d"></a>' % (make_pnp_url(dashlet, 'graph'), nr))
 
 dashlet_types["pnpgraph"] = {
     "title"        : _("Performance Graph"),
     "sort_index"   : 20,
     "description"  : _("Displays a performance graph of a host or service."),
-    "render"       : dashlet_pnpgraph,
+    "render"       : dashlet_graph,
     "refresh"      : 60,
     "size"         : (60, 21),
     "allowed"      : config.builtin_role_ids,
     "infos"        : ["service", "host"],
     "single_infos" : ["service", "host"],
     "parameters"   : [
+        # Cleanup: switch to generic Timerange() valuespec!
         ("timerange", DropdownChoice(
             title = _('Timerange'),
             default_value = '1',
@@ -384,24 +419,84 @@ dashlet_types["pnpgraph"] = {
             ],
         )),
         ("source", Integer(
-            title = _('Source (n\'th Graph)'),
-            default_value = 0,
+            title = _('Source (n\'th graph)'),
+            default_value = 1,
+            minvalue = 1,
+        )),
+        ("show_legend", Checkbox(
+            title = _("Show Legend"),
+            label = _("Show the legend area of the graph"),
+            help = _("This option controls whether or not the legend below the graph "
+                     "area should be shown. This option is only used by the new Check_MK "
+                     "graphs which are only available in the Check_MK Enterprise Edition."),
+            default_value = False,
+        )),
+        ("show_service", Checkbox(
+            title = _("Show host/service name in title"),
+            label = _("Add the host/service to the graph title"),
+            default_value = True,
         )),
     ],
     "styles": """
 .dashlet.pnpgraph .dashlet_inner {
-    background-color: #fff;
+    background-color: #f8f4f0;
     color: #000;
     text-align: center;
 }
+.dashlet.pnpgraph .graph {
+    border: none;
+    box-shadow: none;
+}
+.dashlet.pnpgraph .container {
+    background-color: #f8f4f0;
+}
+.dashlet.pnpgraph div.title a {
+    color: #000;
+}
 """,
-    "on_resize"    : lambda nr, dashlet: 'dashboard_render_pnpgraph(%d, \'%s\');' %
-                                                 (nr, make_pnp_url(dashlet, 'image')),
+    "on_resize"    : dashlet_graph_reload_js,
     # execute this js handler instead of refreshing the dashlet by calling "render" again
-    "on_refresh"   : lambda nr, dashlet: 'dashboard_render_pnpgraph(%d, \'%s\');' %
-                                                 (nr, make_pnp_url(dashlet, 'image')),
+    "on_refresh"   : dashlet_graph_reload_js,
     "script": """
 var dashlet_offsets = {};
+function dashboard_render_graph(nr, graph_specification, graph_render_options, timerange)
+{
+    // Get the target size for the graph from the inner dashlet container
+    var inner = document.getElementById('dashlet_inner_' + nr);
+    var c_w = inner.clientWidth;
+    var c_h = inner.clientHeight;
+
+    var post_data = "spec=" + encodeURIComponent(JSON.stringify(graph_specification))
+                  + "&render=" + encodeURIComponent(JSON.stringify(graph_render_options))
+                  + "&timerange=" + encodeURIComponent(timerange)
+                  + "&width=" + c_w
+                  + "&height=" + c_h
+                  + "&id=" + nr;
+
+    call_ajax("graph_dashlet.py", {
+        post_data        : post_data,
+        method           : "POST",
+        response_handler : handle_dashboard_render_graph_response,
+        handler_data     : nr,
+    });
+}
+
+function handle_dashboard_render_graph_response(handler_data, response_body)
+{
+    var nr = handler_data;
+
+    // Fallback to PNP graph handling
+    if (response_body.indexOf('pnp4nagios') !== -1) {
+        var img_url = response_body;
+        dashboard_render_pnpgraph(nr, img_url);
+        return;
+    }
+
+    var container = document.getElementById('dashlet_graph_' + nr);
+    container.innerHTML = response_body;
+    executeJSbyObject(container);
+}
+
 function dashboard_render_pnpgraph(nr, img_url)
 {
     // Get the target size for the graph from the inner dashlet container
@@ -548,8 +643,14 @@ def dashlet_view(nr, dashlet):
     import bi # FIXME: Cleanup?
     bi.reset_cache_status() # needed for status icon
 
-    html.set_var('display_options', 'HRSIXL')
-    html.set_var('_display_options', 'HRSIXL')
+    is_reload = html.has_var("_reload")
+
+    display_options = "SIXL"
+    if not is_reload:
+        display_options += "HR"
+
+    html.set_var('display_options',  display_options)
+    html.set_var('_display_options', display_options)
     html.add_body_css_class('dashlet')
 
     import views # FIXME: HACK, clean this up somehow
@@ -579,7 +680,7 @@ def dashlet_view_handle_input(ident, dashlet):
 dashlet_types["view"] = {
     "title"          : _("View"),
     "sort_index"     : 10,
-    "description"    : _("Displays a the content of a Multisite view."),
+    "description"    : _("Displays the content of a Multisite view."),
     "size"           : (40, 20),
     "iframe_render"  : dashlet_view,
     "allowed"        : config.builtin_role_ids,
@@ -601,7 +702,16 @@ dashlet_types["view"] = {
 
 def dashlet_url(dashlet):
     if dashlet.get('show_in_iframe', True):
-        return dashlet['url']
+        try:
+            return dashlet['url']
+        except KeyError:
+            if "urlfunc" in dashlet:
+                raise MKUserError(None,
+                    _("You set the dashlet to use a dynamic URL rendering function. It seems "
+                      "that this function call failed. You may want to open the dashboard "
+                      "in debug mode to get more details."))
+            else:
+                raise
 
 def dashlet_url_validate(value, varprefix):
     if 'url' not in value and 'urlfunc' not in value:
@@ -636,3 +746,98 @@ dashlet_types["url"] = {
     "opt_params"      : ['url', 'urlfunc'],
     "validate_params" : dashlet_url_validate,
 }
+
+#.
+#   .--Snapin--------------------------------------------------------------.
+#   |                   ____                    _                          |
+#   |                  / ___| _ __   __ _ _ __ (_)_ __                     |
+#   |                  \___ \| '_ \ / _` | '_ \| | '_ \                    |
+#   |                   ___) | | | | (_| | |_) | | | | |                   |
+#   |                  |____/|_| |_|\__,_| .__/|_|_| |_|                   |
+#   |                                    |_|                               |
+#   +----------------------------------------------------------------------+
+#   | Render sidebar snapins within the dashboard                          |
+#   '----------------------------------------------------------------------'
+
+def dashlet_snapin(nr, dashlet):
+    import sidebar # FIXME: HACK, clean this up somehow
+    snapin = sidebar.sidebar_snapins.get(dashlet['snapin'])
+    if not snapin:
+        raise MKUserError(None, _('The configured snapin does not exist.'))
+
+    dashlet_type = dashlet_types[dashlet['type']]
+
+    overflow = ''
+    scroll_x, scroll_y = dashlet_type.get("iframe_scroll", (False, False))
+    if not scroll_x:
+        overflow += 'overflow-x: hidden;\n'
+    else:
+        overflow += 'overflow-x: auto;\n'
+    if not scroll_y:
+        overflow += 'overflow-y: hidden;\n'
+    else:
+        overflow += 'overflow-y: auto;\n'
+
+    html.set_browser_reload(dashlet_type['refresh'])
+    html.html_head(_('Snapin Dashlet'), javascripts=['sidebar'], stylesheets=['sidebar', 'status'])
+    html.write('''<style>
+#side_content {
+    height: auto;
+    top: 0;
+    padding-top: 4px;
+    padding-left: 4px;
+}
+div.snapin:last-child {
+    margin-bottom: 0;
+}
+div.snapin div.content {
+    background-image: none;
+    background-color: #508AA1;
+}
+div.snapin {
+    margin: 0;
+    padding: 0;
+}
+body.side {
+    %s
+}
+</style>''' % overflow)
+    html.write('<body class="side">\n')
+    html.write('<div id="check_mk_sidebar">\n')
+    html.write('<div id="side_content">\n')
+    html.write("<div id=\"snapin_container_%s\" class=snapin>\n" % dashlet['snapin'])
+    html.write("<div id=\"snapin_%s\" class=\"content\">\n" % (dashlet['snapin']))
+    sidebar.render_snapin_styles(snapin)
+    snapin['render']()
+    html.write('</div>\n')
+    html.write('</div>\n')
+    html.write('</div>\n')
+    html.write('</div>\n')
+    html.body_end()
+
+def dashlet_snapin_get_snapins():
+    import sidebar # FIXME: HACK, clean this up somehow
+    return sorted([ (k, v['title']) for k, v in sidebar.sidebar_snapins.items() ], key=lambda x: x[1])
+
+def dashlet_snapin_title(dashlet):
+    import sidebar # FIXME: HACK, clean this up somehow
+    return sidebar.sidebar_snapins[dashlet['snapin']]['title']
+
+dashlet_types["snapin"] = {
+    "title"          : _("Sidebar Snapin"),
+    "title_func"     : dashlet_snapin_title,
+    "sort_index"     : 55,
+    "description"    : _("Displays a sidebar snapin."),
+    "size"           : (27, 20),
+    "iframe_render"  : dashlet_snapin,
+    "iframe_scroll"  : (False, True),
+    "allowed"        : config.builtin_role_ids,
+    "refresh"        : 30,
+    "parameters"     : [
+        ('snapin', DropdownChoice(
+            title = _('Snapin'),
+            help = _('Choose the snapin you would like to show.'),
+            choices = dashlet_snapin_get_snapins,
+        )),
+    ],
+}
