@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -38,9 +38,9 @@ loaded_with_language = False
 #   | Declare general permissions for Multisite                            |
 #   '----------------------------------------------------------------------'
 
-def load():
+def load_plugins(force):
     global loaded_with_language
-    if loaded_with_language == current_language:
+    if loaded_with_language == current_language and not force:
         return
 
     config.declare_permission_section("general", _('General Permissions'), 10)
@@ -51,7 +51,7 @@ def load():
          [ "admin", "user", "guest" ])
 
     config.declare_permission("general.see_all",
-         _("See all Nagios objects"),
+         _("See all host and services"),
          _("See all objects regardless of contacts and contact groups. "
            "If combined with 'perform commands' then commands may be done on all objects."),
          [ "admin", "guest" ])
@@ -141,8 +141,17 @@ def load():
          _("Allows to ignore the hard query limit imposed upon the number of datasets returned by a query"),
          [ "admin" ])
 
+    config.declare_permission("general.acknowledge_werks",
+         _("Acknowledge Incompatible Werks"),
+         _("In the change log of the Check_MK software version the administrator can manage change log entries "
+           "(Werks) that requrire user interaction. These <i>incompatible Werks</i> can be acknowledged only "
+           "if the user has this permission."),
+         [ "admin" ])
+
+
     loaded_with_language = current_language
 
+# TODO: This has been obsoleted by pagetypes.py
 def declare_visual_permissions(what, what_plural):
     config.declare_permission("general.edit_" + what,
          _("Customize %s and use them") % what_plural,
@@ -151,7 +160,7 @@ def declare_visual_permissions(what, what_plural):
 
     config.declare_permission("general.publish_" + what,
          _("Publish %s") % what_plural,
-         _("Make %s visible and usable for other users") % what_plural,
+         _("Make %s visible and usable for other users.") % what_plural,
          [ "admin", "user" ])
 
     config.declare_permission("general.see_user_" + what,
@@ -163,3 +172,8 @@ def declare_visual_permissions(what, what_plural):
          _("Modify builtin %s") % what_plural,
          _("Make own published %s override builtin %s for all users.") % (what_plural, what_plural),
          [ "admin" ])
+
+    config.declare_permission("general.delete_foreign_" + what,
+         _("Delete foreign %s") % what_plural,
+         _("Allows to delete %s created by other users.") % what_plural,
+         [ "admin" ])
