@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -50,6 +50,9 @@ def edit_dictionary(entries, value, **args):
 # Edit a list of several dictionaries. Those can either be dictionary
 # valuespec or just a list of elements. Each entry in dictionaries is
 # a pair of key and either a list of elements or a Dictionary.
+# TODO: As soon as the reports have been migrated to pagetypes.py
+# we can drop edit_dictionaries()? At least the function for editing
+# several dictionaries at once.
 def edit_dictionaries(dictionaries, value, focus=None, hover_help=True,
                     validate=None, buttontext=None, title=None,
                     buttons = None, method="GET", preview=False,
@@ -82,7 +85,7 @@ def edit_dictionaries(dictionaries, value, focus=None, hover_help=True,
                         vs.validate_value(v, keyname + "_" + varprefix + name)
                         new_value[keyname][name] = v
                     except MKUserError, e:
-                        messages.append("%s: %s" % (title, e))
+                        messages.append("%s: %s" % (vs.title(), e))
                         html.add_user_error(e.varname, e)
 
             else:
@@ -91,9 +94,12 @@ def edit_dictionaries(dictionaries, value, focus=None, hover_help=True,
                     edited_value = entries.from_html_vars(keyname)
                     entries.validate_value(edited_value, keyname)
                     new_value[keyname].update(edited_value)
-                except Exception, e:
+                except MKUserError, e:
                     messages.append("%s: %s" % (entries.title() or _("Properties"), e))
                     html.add_user_error(e.varname, e)
+                except Exception, e:
+                    messages.append("%s: %s" % (entries.title() or _("Properties"), e))
+                    html.add_user_error(None, e)
 
             if validate and not html.has_user_errors():
                 try:
@@ -148,6 +154,49 @@ def edit_dictionaries(dictionaries, value, focus=None, hover_help=True,
     html.hidden_fields()
     html.end_form()
 
+# Similar but for editing an arbitrary valuespec
+def edit_valuespec(vs, value, buttontext=None, method="GET", varprefix="",
+                   validate=None, formname="form", consume_transid = True, focus=None):
+
+    if html.var("filled_in") == formname and html.transaction_valid():
+        if consume_transid:
+            html.check_transaction()
+
+        messages = []
+        try:
+            new_value = vs.from_html_vars(varprefix)
+            vs.validate_value(new_value, varprefix)
+
+        except MKUserError, e:
+            messages.append("%s: %s" % (vs.title(), e.message))
+            html.add_user_error(e.varname, e.message)
+
+        if validate and not html.has_user_errors():
+            try:
+                validate(new_value)
+            except MKUserError, e:
+                messages.append(e.message)
+                html.add_user_error(e.varname, e.message)
+
+        if messages:
+            html.show_error("".join(["%s<br>\n" % m for m in messages]))
+        else:
+            return new_value
+
+    html.begin_form(formname, method=method)
+    html.help(vs.help())
+    vs.render_input(varprefix, value)
+    if buttontext == None:
+        buttontext = _("Save")
+    html.button("save", buttontext)
+    html.del_var("filled_in") # Should be ignored be hidden_fields, but I do not dare to change it there
+    html.hidden_fields()
+    if focus:
+        html.set_focus(focus)
+    else:
+        vs.set_focus(varprefix)
+    html.end_form()
+
 # New functions for painting forms
 
 twofivesix = "".join(map(chr, range(0,256)))
@@ -168,6 +217,7 @@ def strip_bad_chars(x):
         return s.translate(twofivesix, "'&;<>\"")
 
 def header(title, isopen = True, table_id = "", narrow = False, css=None):
+    html.guitest_record_output("forms", ("header", title))
     global g_header_open
     global g_section_open
     global g_section_isopen
@@ -202,6 +252,7 @@ def space():
     html.write('<tr><td colspan=2 style="height:15px;"></td></tr>')
 
 def section(title = None, checkbox = None, id = "", simple=False, hide = False, legend = True):
+    html.guitest_record_output("forms", ("section", title))
     global g_section_open
     if g_section_open:
         html.write('</td></tr>')
