@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -27,15 +27,31 @@
 import socket, config, defaults, re, time
 from lib import *
 
-# TODO: make this configurable and thus work for non OMD-users as
-# well.
+
+# ASN1 MIB source directory candidates. Non existing dirs are ok.
+# Please sync these paths with htdocs/mkeventd.py
+mib_dirs = [ ('/usr/share/snmp/mibs', _('System MIBs')) ]
+
 try:
-    socket_path = defaults.omd_root + "/tmp/run/mkeventd/status"
-    pipe_path = defaults.omd_root + "/tmp/run/mkeventd/events"
+    socket_path       = defaults.omd_root + "/tmp/run/mkeventd/status"
+    pipe_path         = defaults.omd_root + "/tmp/run/mkeventd/events"
+
+    compiled_mibs_dir = defaults.omd_root + "/local/share/check_mk/compiled_mibs"
+
+    # Please sync these paths with htdocs/mkeventd.py
+    mib_upload_dir    = defaults.omd_root + "/local/share/snmp/mibs"
+    mib_dirs.insert(0, (defaults.omd_root + "/share/snmp/mibs", _('MIBs shipped with Check_MK')))
+    mib_dirs.insert(0, (mib_upload_dir, _('Custom MIBs')))
 except:
-    run_dir = defaults.livestatus_unix_socket.rsplit("/",1)[0]
-    socket_path = run_dir + "/mkeventd/status"
-    pipe_path = run_dir + "/mkeventd/events"
+    run_dir           = defaults.livestatus_unix_socket.rsplit("/",1)[0]
+    socket_path       = run_dir + "/mkeventd/status"
+    pipe_path         = run_dir + "/mkeventd/events"
+
+    # Please sync these paths with htdocs/mkeventd.py
+    mib_upload_dir    = defaults.var_dir + "/mkeventd/mibs"
+    compiled_mibs_dir = "/var/lib/mkeventd/compiled_mibs"
+    mib_dirs.insert(0, (mib_upload_dir, _('Custom MIBs')))
+
 
 syslog_priorities = [
     (0, "emerg" ),
@@ -126,6 +142,7 @@ def eventd_configuration():
 
     config = {
         "rules"                 : [],
+        "rule_packs"            : [],
         "debug_rules"           : False,
     }
     main_file = defaults.default_config_dir + "/mkeventd.mk"
@@ -144,12 +161,15 @@ def daemon_running():
     return os.path.exists(socket_path)
 
 
+# Note: in order to be able to simulate an original IP address
+# we put hostname|ipaddress into the host name field. The EC
+# recognizes this and unpacks the data correctly.
 def send_event(event):
-    # "<%PRI%>%TIMESTAMP% %HOSTNAME% %syslogtag% %msg%\n"
+    # "<%PRI%>@%TIMESTAMP%;%SL% %HOSTNAME% %syslogtag% %msg%\n"
     prio = (event["facility"] << 3) + event["priority"]
-    timestamp = time.strftime("%b %d %T", time.localtime())
-    rfc = "<%d>%s %s %s: %s\n" % (
-        prio, timestamp, event["host"], event["application"], event["text"])
+    rfc = "<%d>@%s;%d %s|%s %s: %s\n" % (
+        prio, int(time.time()), event["sl"], event["host"],
+        event["ipaddress"], event["application"], event["text"])
     if type(rfc) == unicode:
         rfc = rfc.encode("utf-8")
     pipe = file(pipe_path, "w")
@@ -196,6 +216,20 @@ def replication_mode():
 # does not know anything about the currently configured but not yet activated
 # rules. And also we do not want to have shared code.
 def event_rule_matches(rule, event):
+    result = event_rule_matches_non_inverted(rule, event)
+    if rule.get("invert_matching"):
+        if type(result) == tuple:
+            return _("The rule would match, but matching is inverted.")
+        else:
+            return False, ()
+    else:
+        return result
+
+
+def event_rule_matches_non_inverted(rule, event):
+    if False == match_ipv4_network(rule.get("match_ipaddress", "0.0.0.0/0"), event["ipaddress"]):
+        return _("The source IP address does not match.")
+
     if False == match(rule.get("match_host"), event["host"], complete=True):
         return _("The host name does not match.")
 
@@ -235,6 +269,17 @@ def event_rule_matches(rule, event):
         if p < prio_from or p > prio_to:
             return _("The syslog priority is not in the required range.")
 
+    if "match_sl" in rule:
+        sl_from, sl_to = rule["match_sl"]
+        if sl_from > sl_to:
+            sl_to, sl_from = sl_from, sl_to
+        p = event.get("sl")
+        if p == None:
+            return _("No service level is set in event")
+
+        if p < sl_from or p > sl_to:
+            return _("Wrong service level %d (need %d..%d)" % (p, sl_from, sl_to))
+
     if "match_timeperiod" in rule:
         reason = check_timeperiod(rule["match_timeperiod"])
         if reason:
@@ -257,7 +302,7 @@ def check_timeperiod(tpname):
             return _("The timeperiod %s is currently not active" % tpname)
     except Exception, e:
         return _("Cannot update timeperiod information for %s: %s" % (tpname, e))
-        if opt_debug:
+        if config.debug:
             raise
 
 def match(pattern, text, complete = True):
@@ -274,3 +319,38 @@ def match(pattern, text, complete = True):
             return m.groups()
         else:
             return False
+
+def match_ipv4_network(pattern, ipaddress_text):
+    network, network_bits = parse_ipv4_network(pattern) # is validated by valuespec
+    if network_bits == 0:
+        return True # event if ipaddress is empty
+    try:
+        ipaddress = parse_ipv4_address(ipaddress_text)
+    except:
+        return False # invalid address never matches
+
+    # first network_bits of network and ipaddress must be
+    # identical. Create a bitmask.
+    bitmask = 0
+    for n in range(32):
+        bitmask = bitmask << 1
+        if n < network_bits:
+            bit = 1
+        else:
+            bit = 0
+        bitmask += bit
+
+    return (network & bitmask) == (ipaddress & bitmask)
+
+def parse_ipv4_address(text):
+    parts = map(int, text.split("."))
+    return (parts[0] << 24) + (parts[1] << 16) + (parts[2] << 8) + parts[3]
+
+def parse_ipv4_network(text):
+    if "/" not in text:
+        return parse_ipv4_address(text), 32
+
+    network_text, bits_text = text.split("/")
+    return parse_ipv4_address(network_text), int(bits_text)
+
+
