@@ -22,13 +22,9 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-var browser         = navigator.userAgent.toLowerCase();
-var weAreIEF__k     = ((browser.indexOf("msie") != -1) && (browser.indexOf("opera") == -1));
-var weAreOpera      = browser.indexOf("opera") != -1;
-var weAreFirefox    = browser.indexOf("firefox") != -1 || browser.indexOf("namoroka") != -1;
 var g_content_loc   = null;
 
-var sidebar_folded = false;
+var g_sidebar_folded = false;
 
 //
 // Sidebar styling and scrolling stuff
@@ -51,7 +47,8 @@ if (window.addEventListener) {
     window.addEventListener('DOMMouseScroll', scrollWheel,     false);
   else
     window.addEventListener('mousewheel',     scrollWheel,     false);
-} else {
+}
+else {
   document.documentElement.onmousemove  = function(e) {
     // snapin drag 'n drop
     snapinDrag(e);
@@ -84,13 +81,19 @@ function registerEdgeListeners(obj) {
             continue;
 
         if (window.addEventListener)
-            edges[i].addEventListener("mousemove", stop_snapin_dragging, false);
+            edges[i].addEventListener("mousemove", on_mouse_leave, false);
         else
-            edges[i].onmousemove = stop_snapin_dragging;
+            edges[i].onmousemove = on_mouse_leave;
     }
     edges = null;
 }
 
+function on_mouse_leave(e) {
+    if (typeof(mkSearchClose) != "undefined")
+        mkSearchClose();
+    return stop_snapin_dragging(e);
+}
+
 function stop_snapin_dragging(e) {
     stopDragScroll(e);
     snapinTerminateDrag(e);
@@ -401,22 +404,12 @@ function debug(s) {
 // but without scrolling. The height of the header and footer divs need
 // to be treated here.
 var g_just_resizing = 0;
-function setSidebarHeight() {
+function set_sidebar_size() {
     var oHeader  = document.getElementById('side_header');
     var oContent = document.getElementById('side_content');
     var oFooter  = document.getElementById('side_footer');
     var height   = pageHeight();
 
-    // Resize sidebar frame on Chrome (and other webkit browsers)
-    if (isWebkit()) {
-        var oldcols = parent.document.body.cols.split(",");
-        var oldwidth = parseInt(oldcols[0]);
-        var width = oHeader.clientWidth;
-        var target_width = parseInt(oldwidth * 280.0 / width);
-        var newcols = target_width.toString() + ",*";
-        parent.document.body.cols = newcols;
-    }
-
     // Don't handle zero heights
     if (height == 0)
       return;
@@ -453,12 +446,12 @@ function startDragScroll(event) {
   if (!event)
     event = window.event;
 
-  if (sidebar_folded) {
-      unfoldSidebar();
+  if (g_sidebar_folded) {
+      unfold_sidebar();
       return false;
   }
-  else if (!sidebar_folded && event.clientX < 10) {
-      foldSidebar();
+  else if (!g_sidebar_folded && event.clientX < 10) {
+      fold_sidebar();
       return false;
   }
 
@@ -523,29 +516,34 @@ function dragScroll(event) {
   return false;
 }
 
-function foldSidebar()
+function sidebar_width()
 {
-    sidebar_folded = true;
+    if (g_sidebar_folded)
+        return 10;
+    else
+        return 280;
+}
+
+function fold_sidebar()
+{
+    g_sidebar_folded = true;
     document.getElementById('check_mk_sidebar').style.position = "relative";
     document.getElementById('check_mk_sidebar').style.left = "-265px";
-    if (isWebkit()) {
-        var oldcols = parent.document.body.cols.split(",");
-        var oldwidth = parseInt(oldcols[0]);
-        var new_width = 10.0 / 280.0 * oldwidth;
-        parent.document.body.cols = new_width.toString() + ",*";
-    }
-    else
-        parent.document.body.cols = "10,*";
+    document.getElementById('side_footer').style.display = "none";
+    document.getElementById('side_version').style.display = "none";
+    parent.document.body.cols = sidebar_width() + ",*";
     get_url('sidebar_fold.py?fold=yes');
 }
 
 
-function unfoldSidebar()
+function unfold_sidebar()
 {
+    g_sidebar_folded = false;
     document.getElementById('check_mk_sidebar').style.position = "";
     document.getElementById('check_mk_sidebar').style.left = "0";
-    parent.document.body.cols = "280,*";
-    sidebar_folded = false;
+    document.getElementById('side_footer').style.display = "";
+    document.getElementById('side_version').style.display = "";
+    parent.document.body.cols = sidebar_width() + ",*";
     get_url('sidebar_fold.py?fold=');
 }
 
@@ -660,13 +658,13 @@ function toggle_sidebar_snapin(oH2, url) {
         oContent.style.display = "block";
         oFoot.style.display = "block";
         oHead.className = "head open";
-        oImgMini.src = "images/button_minisnapin_lo.png";
+        oImgMini.src = "images/button_minisnapin.png";
     }
     else {
         oContent.style.display = "none";
         oFoot.style.display = "none";
         oHead.className = "head closed";
-        oImgMini.src = "images/button_maxisnapin_lo.png";
+        oImgMini.src = "images/button_maxisnapin.png";
     }
     /* make this persistent -> save */
     get_url(url + (closed ? "open" : "closed"));
@@ -757,13 +755,6 @@ function sidebar_scheduler() {
     setTimeout(function(){sidebar_scheduler();}, 1000);
 }
 
-function addBookmark() {
-    href = parent.frames[1].location;
-    title = parent.frames[1].document.title;
-    get_url("add_bookmark.py?title=" + encodeURIComponent(title)
-            + "&href=" + encodeURIComponent(href), updateContents, "snapin_bookmarks");
-}
-
 /************************************************
  * Save/Restore scroll position
  *************************************************/
