@@ -7,7 +7,7 @@
 # |           | |___| | | |  __/ (__|   <    | |  | | . \            |
 # |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
 # |                                                                  |
-# | Copyright Mathias Kettner 2013             mk@mathias-kettner.de |
+# | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
 # +------------------------------------------------------------------+
 #
 # This file is part of Check_MK.
@@ -19,19 +19,12 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
 
-import socket, time
-
-# Python 2.3 does not have 'set' in normal namespace.
-# But it can be imported from 'sets'
-try:
-    set()
-except NameError:
-    from sets import Set as set
+import socket, time, re
 
 """MK Livestatus Python API
 
@@ -52,6 +45,9 @@ r2 = conn.query_row("GET status")
 # Keep a global array of persistant connections
 persistent_connections = {}
 
+# Regular expression for removing Cache: headers if caching is not allowed
+remove_cache_regex = re.compile("\nCache:[^\n]*")
+
 # DEBUGGING PERSISTENT CONNECTIONS
 # import os
 # hirn_debug = file("/tmp/live.log", "a")
@@ -106,7 +102,11 @@ class Helpers:
     def query_row(self, query):
         """Issues a query that returns one line of data and returns the elements
            of that line as list"""
-        return self.query(query, "ColumnHeaders: off\n")[0]
+        result = self.query(query, "ColumnHeaders: off\n")
+        try:
+            return result[0]
+        except IndexError:
+            raise MKLivestatusNotFoundError(query)
 
     def query_row_assoc(self, query):
         """Issues a query that returns one line of data and returns the elements
@@ -160,10 +160,11 @@ class Helpers:
 
 
 class BaseConnection:
-    def __init__(self, socketurl, persist = False):
+    def __init__(self, socketurl, persist = False, allow_cache = False):
         """Create a new connection to a MK Livestatus socket"""
         self.add_headers = ""
         self.persist = persist
+        self.allow_cache = allow_cache
         self.socketurl = socketurl
         self.socket = None
         self.timeout = None
@@ -261,6 +262,8 @@ class BaseConnection:
         return self.recv_response(query, add_headers)
 
     def send_query(self, query, add_headers = "", do_reconnect=True):
+        if not self.allow_cache:
+            query = remove_cache_regex.sub("", query)
         orig_query = query
         if self.socket == None:
             self.connect()
@@ -269,6 +272,7 @@ class BaseConnection:
         query += self.auth_header + self.add_headers
         query += "Localtime: %d\nOutputFormat: python\nKeepAlive: on\nResponseHeader: fixed16\n" % int(time.time())
         query += add_headers
+
         if not query.endswith("\n"):
             query += "\n"
         query += "\n"
@@ -349,8 +353,8 @@ class BaseConnection:
 
 
 class SingleSiteConnection(BaseConnection, Helpers):
-    def __init__(self, socketurl, persist = False):
-        BaseConnection.__init__(self, socketurl, persist)
+    def __init__(self, socketurl, persist = False, allow_cache = False):
+        BaseConnection.__init__(self, socketurl, persist, allow_cache)
         self.prepend_site = False
         self.auth_users = {}
         self.deadsites = {} # never filled, just for compatibility
@@ -382,7 +386,7 @@ class SingleSiteConnection(BaseConnection, Helpers):
     def set_auth_user(self, domain, user):
         if user:
             self.auth_users[domain] = user
-        else:
+        elif domain in self.auth_users:
             del self.auth_users[domain]
 
     # Switch future request to new authorization domain
@@ -414,7 +418,7 @@ class MultiSiteConnection(Helpers):
             try:
                 url = site["socket"]
                 persist = not temporary and site.get("persist", False)
-                connection = SingleSiteConnection(url, persist)
+                connection = SingleSiteConnection(url, persist, allow_cache=site.get("cache", False))
                 if "timeout" in site:
                     connection.set_timeout(int(site["timeout"]))
                 connection.connect()
@@ -665,7 +669,7 @@ class MultiSiteConnection(Helpers):
     # Return connection to localhost (UNIX), if available
     def local_connection(self):
         for sitename, site, connection in self.connections:
-            if site["socket"].startswith("unix:"):
+            if site["socket"].startswith("unix:") and "liveproxy" not in site["socket"]:
                 return connection
         raise MKLivestatusConfigError("No livestatus connection to local host")
 
