@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -79,12 +79,19 @@ def load_serial(username):
 # Generates the hash to be added into the cookie value
 def generate_hash(username, now, serial):
     secret = load_secret()
-    return md5(username + now + str(serial) + secret).hexdigest()
+    return md5(username.encode("utf-8") + now + str(serial) + secret).hexdigest()
+
 
 def del_auth_cookie():
-    name = site_cookie_name()
-    if html.has_cookie(name):
-        html.del_cookie(name)
+    # Note: in distributed setups a cookie issued by one site is accepted by
+    # others with the same auth.secret and user serial numbers. When a users
+    # logs out then we need to delete all cookies that are accepted by us -
+    # not just the one that we have issued.
+    for cookie_name in html.get_cookie_names():
+        if cookie_name.startswith("auth_"):
+            if auth_cookie_is_valid(cookie_name):
+                html.del_cookie(cookie_name)
+
 
 def auth_cookie_value(username, serial):
     now = str(time.time())
@@ -101,22 +108,10 @@ def renew_cookie(cookie_name, username, serial):
        and cookie_name == site_cookie_name():
         set_auth_cookie(username, serial)
 
+
 def check_auth_cookie(cookie_name):
-    username, issue_time, cookie_hash = html.cookie(cookie_name, '::').split(':', 2)
-
-    # FIXME: Ablauf-Zeit des Cookies testen
-    #max_cookie_age = 10
-    #if float(issue_time) < time.time() - max_cookie_age:
-    #    del_auth_cookie()
-    #    return ''
-
-    if not userdb.user_exists(username):
-        raise MKAuthException(_('Username is unknown'))
-
-    # Validate the hash
-    serial = load_serial(username)
-    if cookie_hash != generate_hash(username, issue_time, serial):
-        raise MKAuthException(_('Invalid credentials'))
+    username, issue_time, cookie_hash = parse_auth_cookie(cookie_name)
+    serial = check_parsed_auth_cookie(username, issue_time, cookie_hash)
 
     # Once reached this the cookie is a good one. Renew it!
     renew_cookie(cookie_name, username, serial)
@@ -129,44 +124,80 @@ def check_auth_cookie(cookie_name):
     # Return the authenticated username
     return username
 
+
+def parse_auth_cookie(cookie_name):
+    username, issue_time, cookie_hash = html.cookie(cookie_name, '::').split(':', 2)
+    username = username.decode("utf-8")
+    return username, issue_time, cookie_hash
+
+
+def check_parsed_auth_cookie(username, issue_time, cookie_hash):
+    if not userdb.user_exists(username):
+        raise MKAuthException(_('Username is unknown'))
+
+    serial = load_serial(username)
+    if cookie_hash != generate_hash(username, issue_time, serial):
+        raise MKAuthException(_('Invalid credentials'))
+
+    return serial
+
+
+def auth_cookie_is_valid(cookie_name):
+    try:
+        check_parsed_auth_cookie(*parse_auth_cookie(cookie_name))
+        return True
+    except MKAuthException:
+        return False
+
+
 def check_auth_automation():
     secret = html.var("_secret").strip()
-    user = html.var("_username").strip()
+    user_id = html.get_unicode_input("_username").strip()
     html.del_var('_username')
     html.del_var('_secret')
-    if secret and user and "/" not in user:
-        path = defaults.var_dir + "/web/" + user + "/automation.secret"
+    if secret and user_id and "/" not in user_id:
+        path = defaults.var_dir + "/web/" + user_id.encode("utf-8") + "/automation.secret"
         if os.path.isfile(path) and file(path).read().strip() == secret:
             # Auth with automation secret succeeded - mark transid as unneeded in this case
             html.set_ignore_transids()
-            return user
-    raise MKAuthException(_("Invalid automation secret for user %s") % html.attrencode(user))
+            return user_id
+    raise MKAuthException(_("Invalid automation secret for user %s") % html.attrencode(user_id))
+
+# When http header auth is enabled, try to read the user_id from the var
+# and when there is some available, set the auth cookie (for other addons) and proceed.
+def check_auth_http_header():
+    user_id = html.get_request_header(config.auth_by_http_header)
+    if user_id:
+        user_id = user_id.decode("utf-8")
+        serial = load_serial(user_id)
+        renew_cookie(site_cookie_name(), user_id, serial)
+    else:
+        user_id = None
+    return user_id
 
 def check_auth():
-    if html.var("_secret"):
-        return check_auth_automation()
+    user_id = None
+    if html.has_var("_username") and html.has_var("_secret"):
+        user_id = check_auth_automation()
 
-    # When http header auth is enabled, try to read the username from the var
-    # and when there is some available, set the auth cookie (for other addons) and proceed.
-    if config.auth_by_http_header:
-        username = html.req.headers_in.get(config.auth_by_http_header, None)
-        if username:
-            serial = load_serial(username)
-            renew_cookie(site_cookie_name(), username, serial)
-            return username
+    elif config.auth_by_http_header:
+        user_id = check_auth_http_header()
 
-    for cookie_name in html.get_cookie_names():
-        if cookie_name.startswith('auth_'):
-            try:
-                return check_auth_cookie(cookie_name)
-            except Exception, e:
-                #if html.enable_debug:
-                #    html.write('Exception occured while checking cookie %s' % cookie_name)
-                #    raise
-                #else:
-                pass
+    if user_id == None:
+        for cookie_name in html.get_cookie_names():
+            if cookie_name.startswith('auth_'):
+                try:
+                    user_id = check_auth_cookie(cookie_name)
+                    break
+                except Exception, e:
+                    import traceback
+                    html.log("Exception occured while checking cookie '%s': %s" %
+                                                (cookie_name, traceback.format_exc()))
 
-    return ''
+    if (user_id != None and type(user_id) != unicode) or user_id == u'':
+        raise MKInternalError(_("Invalid user authentication"))
+
+    return user_id
 
 
 def do_login():
@@ -174,7 +205,7 @@ def do_login():
     err = None
     if html.var('_login'):
         try:
-            username = html.var('_username', '').rstrip()
+            username = html.get_unicode_input('_username', '').rstrip()
             if username == '':
                 raise MKUserError('_username', _('No username given.'))
 
@@ -223,8 +254,8 @@ def do_login():
                 userdb.on_failed_login(username)
                 raise MKUserError(None, _('Invalid credentials.'))
         except MKUserError, e:
-            html.add_user_error(e.varname, e.message)
-            return e.message
+            html.add_user_error(e.varname, e)
+            return "%s" % e
 
 def page_login(no_html_output = False):
     result = do_login()
@@ -255,7 +286,7 @@ def normal_login_page(called_directly = True):
 }''')
 
     # When someone calls the login page directly and is already authed redirect to main page
-    if html.myfile == 'login' and check_auth() != '':
+    if html.myfile == 'login' and check_auth():
         html.immediate_browser_redirect(0.5, origtarget and origtarget or 'index.py')
         return apache.OK
 
