@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -30,6 +30,8 @@ import views
 
 stylesheets = [ 'pages', 'status', 'logwatch' ]
 
+nagios_illegal_chars  = '`;~!$%^&*|\'"<>?,()='
+
 def level_name(level):
     if   level == 'W': return 'WARN'
     elif level == 'C': return 'CRIT'
@@ -49,13 +51,17 @@ def level_state(level):
 #   |          ___) | | | | (_) \ V  V /  | |__| (_) | (_| \__ \           |
 #   |         |____/|_| |_|\___/ \_/\_/   |_____\___/ \__, |___/           |
 #   |                                                 |___/                |
-#   +----------------------------------------------------------------------+
-#   |                                                                      |
 #   '----------------------------------------------------------------------'
 
 def page_show():
-    host = html.var('host')
-    filename = html.var('file')
+    host = html.var("host", "")
+    filename = html.var("file", "")
+
+    # Fix problem when URL is missing certain illegal characters
+    try:
+        filename = form_file_to_ext(find_matching_logfile(host, form_file_to_int(filename)))
+    except OSError:
+        pass # host log dir does not exist
 
     # Acknowledging logs is supported on
     # a) all logs on all hosts
@@ -148,7 +154,9 @@ def list_logs(host, logfiles):
                         (form_datetime(last_log['datetime']), len(logs)))
 
     if rowno == 0:
-        html.write('<tr><td class="data" colspan=4>'+_('No logs found for this host.')+'</td></tr>\n')
+        html.write('<tr><td class="data" colspan=4>')
+        html.message(_('No logs found for this host.'))
+        html.write('</td></tr>\n')
 
 
 def ack_button(host = None, int_filename = None):
@@ -160,7 +168,30 @@ def ack_button(host = None, int_filename = None):
     else:
         label = _("Clear Logs")
 
-    html.context_button(label, html.makeactionuri([('_ack', '1')]), 'delete')
+    urivars = [('_ack', '1')]
+    if int_filename:
+        urivars.append(("file", int_filename))
+    html.context_button(label, html.makeactionuri(urivars), 'delete')
+
+
+# Tackle problem, where some characters are missing in the service
+# description
+def find_matching_logfile(host, filename):
+    dir_path = defaults.logwatch_dir + '/' + host + '/'
+    if os.path.exists(dir_path + filename):
+        return filename # Most common case
+
+    for logfile_name in os.listdir(dir_path):
+        if remove_illegal_service_characters(logfile_name) == filename:
+            return logfile_name
+
+    # Not found? Fall back to original name. Logfile might be cleared.
+    return filename
+
+
+def remove_illegal_service_characters(filename):
+    return "".join([ c for c in filename if c not in nagios_illegal_chars ])
+
 
 
 def show_file(host, filename):
@@ -331,6 +362,12 @@ def parse_file(host, file, hidecontext = False):
         f = open(file_path, 'r')
         chunk_open = False
         log = None
+
+        # skip hash line. this doesn't exist in older files
+        hash_line = f.readline().rstrip('\n')
+        if not hash_line.startswith('[[[') or not hash_line.endswith(']]]'):
+            f.seek(0)
+
         for line in f.readlines():
             line = line.strip()
             if line == '':
