@@ -19,24 +19,35 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
 
 import defaults, config
 
+import urlparse
+import re
+
 def page_index():
     default_start_url = config.user.get("start_url") or config.start_url
     start_url = html.var("start_url", default_start_url).strip()
 
     # Prevent redirecting to absolute URL which could be used to redirect
     # users to compromised pages.
-    if '://' in start_url:
+    # Also prevent using of "javascript:" URLs which could used to inject code
+    parsed = urlparse.urlparse(start_url)
+
+    # Don't allow the user to set a URL scheme
+    if parsed.scheme != "":
         start_url = default_start_url
 
-    # Also prevent using of "javascript:" URLs which could used to inject code
-    if start_url.lower().startswith('javascript:'):
+    # Don't allow the user to set a network location
+    if parsed.netloc != "":
+        start_url = default_start_url
+
+    # Don't allow bad characters in path
+    if not re.match("[/a-z0-9_\.-]*$", parsed.path):
         start_url = default_start_url
 
     if "%s" in config.page_heading:
@@ -44,12 +55,10 @@ def page_index():
     else:
         heading = config.page_heading
 
-    html.write("""<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">
-<html>
-<head>
- <title>%s</title>
- <meta http-equiv="X-UA-Compatible" content="IE=edge" />
- <link rel="shortcut icon" href="images/favicon.ico" type="image/ico">
+    html.write('<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">\n'
+               '<html><head>\n')
+    html.default_html_headers()
+    html.write("""<title>%s</title>
 </head>
 <frameset cols="280,*" frameborder="0" framespacing="0" border="0">
     <frame src="side.py" name="side" noresize scrolling="no">
