@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -197,7 +197,7 @@ def extract_domains(tar, domains):
         try:
             target_dir = domain.get("prefix")
             if not target_dir:
-                return
+                return []
             # The complete tar.gz file never fits in stringIO buffer..
             tar.extract(tar_member, restore_dir)
 
@@ -217,6 +217,8 @@ def extract_domains(tar, domains):
         except Exception, e:
             return [ "%s - %s" % (domain["title"], str(e)) ]
 
+        return []
+
 
     def execute_restore(domain, is_pre_restore = True):
         if is_pre_restore:
@@ -227,8 +229,9 @@ def extract_domains(tar, domains):
                 return domain["post_restore"]()
         return []
 
-
     total_errors = []
+    logger(LOG_INFO, "Restoring snapshot: %s" % tar.name)
+    logger(LOG_INFO, "Domains: %s" % ", ".join(tar_domains.keys()))
     for what, abort_on_error, handler in [
                             ("Permissions",  True,  lambda domain, tar_member: check_domain(domain, tar_member)),
                             ("Pre-Restore",  True,  lambda domain, tar_member: execute_restore(domain, is_pre_restore = True)),
@@ -239,9 +242,21 @@ def extract_domains(tar, domains):
         errors = []
         for name, tar_member in tar_domains.items():
             if name in domains:
-                dom_errors = handler(domains[name], tar_member)
-                if dom_errors:
-                    errors.extend(dom_errors)
+                try:
+                    dom_errors = handler(domains[name], tar_member)
+                    errors.extend(dom_errors or [])
+                except Exception, e:
+                    # This should NEVER happen
+                    err_info = "Restore-Phase: %s, Domain: %s\nError: %s" % (what, name, format_exception())
+                    errors.append(err_info)
+                    logger(LOG_CRIT, err_info)
+                    if abort_on_error == False:
+                        # At this state, the restored data is broken.
+                        # We still try to apply the rest of the snapshot
+                        # Hopefully the log entry helps in identifying the problem..
+                        logger(LOG_ALERT, "Snapshot restore FAILED! (possible loss of snapshot data)")
+                        continue
+                    break
 
         if errors:
             if what == "Permissions":
@@ -265,7 +280,7 @@ def extract(tar, components):
             try:
                 subtarstream = tar.extractfile(name + ".tar")
             except:
-                pass # may be missing, e.g. sites.tar is only present
+                continue # may be missing, e.g. sites.tar is only present
                      # if some sites have been created.
 
             if what == "dir":
