@@ -19,13 +19,18 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
 
 import pprint, tarfile
 
+try:
+    import simplejson as json
+except ImportError:
+    import json
+
 pac_ext = ".mkp"
 
 class PackageException(Exception):
@@ -53,8 +58,22 @@ package_parts = [ (part, title, perm, ldir and ldir or dir) for part, title, per
   ( "web",           "Multisite extensions",      0644, web_dir,             local_web_dir ),
   ( "pnp-templates", "PNP4Nagios templates",      0644, pnp_templates_dir,   local_pnp_templates_dir ),
   ( "doc",           "Documentation files",       0644, doc_dir,             local_doc_dir ),
+  ( "bin",           "Binaries",                  0755, None,                local_bin_dir ),
+  ( "lib",           "Libraries",                 0644, None,                local_lib_dir),
 ]]
 
+package_ignored_files = {
+    "lib": [
+        "nagios/plugins/README.txt",
+        # it's a symlink to the nagios directory. All files would be doubled.
+        # So better ignore this directory to prevent confusions.
+        "icinga/plugins",
+    ],
+}
+
+def get_package_parts():
+    return [ p for p in package_parts if p[3] != None ]
+
 def packaging_usage():
     sys.stdout.write("""Usage: check_mk [-v] -P|--package COMMAND [ARGS]
 
@@ -76,6 +95,7 @@ Available commands are:
 Package files are located in %s.
 """ % pac_dir)
 
+
 def do_packaging(args):
     if len(args) == 0:
         packaging_usage()
@@ -108,6 +128,7 @@ def do_packaging(args):
                 (", ".join(allc[:-1]), allc[-1]))
         sys.exit(1)
 
+
 def package_list(args):
     if len(args) > 0:
         for name in args:
@@ -115,34 +136,38 @@ def package_list(args):
     else:
         if opt_verbose:
             table = []
-            for pacname in all_packages():
-                package = read_package(pacname)
+            for pacname in all_package_names():
+                package = read_package_info(pacname)
                 table.append((pacname, package["title"], package["num_files"]))
             print_table(["Name", "Title", "Files"], [ tty_bold, "", "" ], table)
         else:
-            for pacname in all_packages():
+            for pacname in all_package_names():
                 sys.stdout.write("%s\n" % pacname)
 
+
 def package_info(args):
     if len(args) == 0:
         raise PackageException("Usage: check_mk -P show NAME|PACKAGE.mkp")
     for name in args:
         show_package_info(name)
 
+
 def show_package_contents(name):
     show_package(name, False)
 
+
 def show_package_info(name):
     show_package(name, True)
 
+
 def show_package(name, show_info = False):
     try:
         if name.endswith(pac_ext):
             tar = tarfile.open(name, "r:gz")
             info = tar.extractfile("info")
-            package = eval(info.read())
+            package = parse_package_info(info.read())
         else:
-            package = read_package(name)
+            package = read_package_info(name)
             if not package:
                 raise PackageException("No such package %s." % name)
             if show_info:
@@ -166,14 +191,14 @@ def show_package(name, show_info = False):
     else:
         if opt_verbose:
             sys.stdout.write("Files in package %s:\n" % name)
-            for part, title, perm, dir in package_parts:
+            for part, title, perm, dir in get_package_parts():
                 files = package["files"].get(part, [])
                 if len(files) > 0:
                     sys.stdout.write("  %s%s%s:\n" % (tty_bold, title, tty_normal))
                     for f in files:
                         sys.stdout.write("    %s\n" % f)
         else:
-            for part, title, perm, dir in package_parts:
+            for part, title, perm, dir in get_package_parts():
                 for fn in package["files"].get(part, []):
                     sys.stdout.write(dir + "/" + fn + "\n")
 
@@ -183,7 +208,7 @@ def package_create(args):
         raise PackageException("Usage: check_mk -P create NAME")
 
     pacname = args[0]
-    if read_package(pacname):
+    if read_package_info(pacname):
         raise PackageException("Package %s already existing." % pacname)
 
     verbose("Creating new package %s...\n" % pacname)
@@ -200,7 +225,7 @@ def package_create(args):
         "files"                : filelists
     }
     num_files = 0
-    for part, title, perm, dir in package_parts:
+    for part, title, perm, dir in get_package_parts():
         files = unpackaged_files_in_dir(part, dir)
         filelists[part] = files
         num_files += len(files)
@@ -210,13 +235,14 @@ def package_create(args):
                 verbose("    %s\n" % f)
 
 
-    write_package(pacname, package)
+    write_package_info(package)
     verbose("New package %s created with %d files.\n" % (pacname, num_files))
     verbose("Please edit package details in %s%s%s\n" % (tty_bold, pac_dir + pacname, tty_normal))
 
+
 def package_find(_no_args):
     first = True
-    for part, title, perm, dir in package_parts:
+    for part, title, perm, dir in get_package_parts():
         files = unpackaged_files_in_dir(part, dir)
         if len(files) > 0:
             if first:
@@ -231,24 +257,31 @@ def package_find(_no_args):
     if first:
         verbose("No unpackaged files found.\n")
 
+
 def package_release(args):
     if len(args) != 1:
         raise PackageException("Usage: check_mk -P release NAME")
 
     pacname = args[0]
     pacpath = pac_dir + pacname
-    if not os.path.exists(pacpath):
+    if not package_exists(pacname):
         raise PackageException("No such package %s." % pacname)
-    package = read_package(pacname)
-    os.unlink(pacpath)
+    package = read_package_info(pacname)
     verbose("Releasing files of package %s into freedom...\n" % pacname)
     if opt_verbose:
-        for part, title, perm, dir in package_parts:
+        for part, title, perm, dir in get_package_parts():
             filenames = package["files"].get(part, [])
             if len(filenames) > 0:
                 verbose("  %s%s%s:\n" % (tty_bold, title, tty_normal))
                 for f in filenames:
                     verbose("    %s\n" % f)
+    remove_package_info(pacname)
+
+
+def package_exists(pacname):
+    pacpath = pac_dir + pacname
+    return os.path.exists(pacpath)
+
 
 def package_pack(args):
     if len(args) != 1:
@@ -256,22 +289,27 @@ def package_pack(args):
 
     # Make sure, user is not in data directories of Check_MK
     p = os.path.abspath(os.curdir)
-    for dir in [var_dir] + [ dir for x,y,perm,dir in package_parts ]:
+    for dir in [var_dir] + [ dir for x,y,perm,dir in get_package_parts() ]:
         if p == dir or p.startswith(dir + "/"):
             raise PackageException("You are in %s!\n"
                                "Please leave the directories of Check_MK before creating\n"
                                "a packet file. Foreign files lying around here will mix up things." % p)
 
     pacname = args[0]
-    package = read_package(pacname)
+    package = read_package_info(pacname)
     if not package:
         raise PackageException("Package %s not existing or corrupt." % pacname)
-    package["version.packaged"] = check_mk_version
     tarfilename = "%s-%s%s" % (pacname, package["version"], pac_ext)
     verbose("Packing %s into %s...\n" % (pacname, tarfilename))
+    create_mkp_file(package, file_name=tarfilename)
+    verbose("Successfully created %s\n" % tarfilename)
+
+
+def create_mkp_file(package, file_name=None, file_object=None):
+    package["version.packaged"] = check_mk_version
 
     def create_info(filename, size):
-        info = tarfile.TarInfo("info")
+        info = tarfile.TarInfo()
         info.mtime = time.time()
         info.uid = 0
         info.gid = 0
@@ -281,13 +319,18 @@ def package_pack(args):
         info.name = filename
         return info
 
-    tar = tarfile.open(tarfilename, "w:gz")
+    tar = tarfile.open(name=file_name, fileobj=file_object, mode="w:gz")
+
     info_file = fake_file(pprint.pformat(package))
     info = create_info("info", info_file.size())
     tar.addfile(info, info_file)
 
+    info_file = fake_file(json.dumps(package))
+    info = create_info("info.json", info_file.size())
+    tar.addfile(info, info_file)
+
     # Now pack the actual files into sub tars
-    for part, title, perm, dir in package_parts:
+    for part, title, perm, dir in get_package_parts():
         filenames = package["files"].get(part, [])
         if len(filenames) > 0:
             verbose("  %s%s%s:\n" % (tty_bold, title, tty_normal))
@@ -297,20 +340,24 @@ def package_pack(args):
             subdata = os.popen("tar cf - --dereference --force-local -C '%s' %s" % (dir, " ".join(filenames))).read()
             info = create_info(subtarname, len(subdata))
             tar.addfile(info, fake_file(subdata))
-
     tar.close()
-    verbose("Successfully created %s\n" % tarfilename)
+
 
 def package_remove(args):
     if len(args) != 1:
         raise PackageException("Usage: check_mk -P remove NAME")
     pacname = args[0]
-    package = read_package(pacname)
+    package = read_package_info(pacname)
     if not package:
         raise PackageException("No such package %s." % pacname)
 
     verbose("Removing package %s...\n" % pacname)
-    for part, title, perm, dir in package_parts:
+    remove_package(package)
+    verbose("Successfully removed package %s.\n" % pacname)
+
+
+def remove_package(package):
+    for part, title, perm, dir in get_package_parts():
         filenames = package["files"].get(part, [])
         if len(filenames) > 0:
             verbose("  %s%s%s\n" % (tty_bold, title, tty_normal))
@@ -321,9 +368,61 @@ def package_remove(args):
                     os.remove(path)
                     verbose("\n")
                 except Exception, e:
-                    sys.stderr.write("cannot remove %s: %s\n" % (path, e))
-    os.remove(pac_dir + pacname)
-    verbose("Successfully removed package %s.\n" % pacname)
+                    if opt_debug:
+                        raise
+                    raise Exception("Cannot remove %s: %s\n" % (path, e))
+
+    os.remove(pac_dir + package["name"])
+
+
+def create_package(package_info):
+    pacname = package_info["name"]
+    if package_exists(pacname):
+        raise PackageException("Packet already exists.")
+
+    validate_package_files(pacname, package_info["files"])
+    write_package_info(package_info)
+
+
+def edit_package(pacname, new_package_info):
+    if not package_exists(pacname):
+        raise PackageException("No such package")
+
+    # Renaming: check for collision
+    if pacname != new_package_info["name"]:
+        if package_exists(new_package_info["name"]):
+            raise PackageException("Cannot rename package: a package with that name already exists.")
+
+    validate_package_files(pacname, new_package_info["files"])
+
+    remove_package_info(pacname)
+    write_package_info(new_package_info)
+
+
+
+# Packaged files must either be unpackaged or already
+# belong to that package
+def validate_package_files(pacname, files):
+    packages = {}
+    for package_name in all_package_names():
+        packages[package_name] = read_package_info(package_name)
+
+    for part, title, perm, dir in get_package_parts():
+        validate_package_files_part(packages, pacname, part, dir, files.get(part, []))
+
+
+def validate_package_files_part(packages, pacname, part, dir, rel_paths):
+    for rel_path in rel_paths:
+        path = dir + "/" + rel_path
+        if not os.path.exists(path):
+            raise PackageException("File %s does not exist." % path)
+
+        for other_pacname, other_package_info in packages.items():
+            for other_rel_path in other_package_info["files"].get(part, []):
+                if other_rel_path == rel_path and other_pacname != pacname:
+                    raise PackageException("File %s does already belong to package %s" % (path, other_pacname))
+
+
 
 def package_install(args):
     if len(args) != 1:
@@ -332,10 +431,17 @@ def package_install(args):
     if not os.path.exists(path):
         raise PackageException("No such file %s." % path)
 
-    tar = tarfile.open(path, "r:gz")
-    package = eval(tar.extractfile("info").read())
+    return install_package(file_name = path)
+
+
+def install_package(file_name=None, file_object=None):
+    tar = tarfile.open(name=file_name, fileobj=file_object, mode="r:gz")
+    package = parse_package_info(tar.extractfile("info").read())
+
+    verify_check_mk_version(package)
+
     pacname = package["name"]
-    old_package = read_package(pacname)
+    old_package = read_package_info(pacname)
     if old_package:
         verbose("Updating %s from version %s to %s.\n" % (pacname, old_package["version"], package["version"]))
         update = True
@@ -345,12 +451,14 @@ def package_install(args):
 
     # Before installing check for conflicts
     keep_files = {}
-    for part, title, perm, dir in package_parts:
+    for part, title, perm, dir in get_package_parts():
         packaged = packaged_files_in_dir(part)
         keep = []
         keep_files[part] = keep
+
         if update:
             old_files = old_package["files"].get(part, [])
+
         for fn in package["files"].get(part, []):
             path = dir + "/" + fn
             if update and fn in old_files:
@@ -360,8 +468,9 @@ def package_install(args):
             elif os.path.exists(path):
                 raise PackageException("File conflict: %s already existing." % path)
 
+
     # Now install files, but only unpack files explicitely listed
-    for part, title, perm, dir in package_parts:
+    for part, title, perm, dir in get_package_parts():
         filenames = package["files"].get(part, [])
         if len(filenames) > 0:
             verbose("  %s%s%s:\n" % (tty_bold, title, tty_normal))
@@ -392,7 +501,7 @@ def package_install(args):
 
     # In case of an update remove files from old_package not present in new one
     if update:
-        for part, title, perm, dir in package_parts:
+        for part, title, perm, dir in get_package_parts():
             filenames = old_package["files"].get(part, [])
             keep = keep_files.get(part, [])
             for fn in filenames:
@@ -405,15 +514,53 @@ def package_install(args):
                         sys.stderr.write("Error removing %s: %s\n" % (path, e))
 
     # Last but not least install package file
-    file(pac_dir + pacname, "w").write(pprint.pformat(package))
+    write_package_info(package)
+    return package
+
+
+# Checks whether or not the minimum required Check_MK version is older than the
+# current Check_MK version. Raises an exception if not. When the Check_MK version
+# can not be parsed or is a daily build, the check is simply passing without error.
+def verify_check_mk_version(package):
+    min_version = package["version.min_required"]
+    cmk_version = check_mk_version
+
+    if is_daily_build_version(min_version):
+        min_branch = branch_of_daily_build(min_version)
+        if min_branch == "master":
+            return # can not check exact version
+        else:
+            # use the branch name (e.g. 1.2.8 as min version)
+            min_version = min_branch
+
+    if is_daily_build_version(cmk_version):
+        branch = branch_of_daily_build(cmk_version)
+        if branch == "master":
+            return # can not check exact version
+        else:
+            # use the branch name (e.g. 1.2.8 as min version)
+            cmk_version = branch
+
+    compatible = True
+    try:
+        compatible = parse_check_mk_version(min_version) <= parse_check_mk_version(cmk_version)
+    except:
+        # Be compatible: When a version can not be parsed, then skip this check
+        if opt_debug:
+            raise
+        return
+
+    if not compatible:
+        raise PackageException("The package requires Check_MK version %s, "
+                               "but you have %s installed." % (min_version, cmk_version))
 
 
 def files_in_dir(part, dir, prefix = ""):
-    if not os.path.exists(dir):
+    if dir == None or not os.path.exists(dir):
         return []
 
     # Handle case where one part-dir lies below another
-    taboo_dirs = [ d for p, t, perm, d in package_parts if p != part ]
+    taboo_dirs = [ d for p, t, perm, d in get_package_parts() if p != part ]
     if dir in taboo_dirs:
         return []
 
@@ -422,6 +569,11 @@ def files_in_dir(part, dir, prefix = ""):
     for f in files:
         if f in [ '.', '..' ] or f.startswith('.') or f.endswith('~'):
             continue
+
+        ignored = package_ignored_files.get(part, [])
+        if prefix + f in ignored:
+            continue
+
         path = dir + "/" + f
         if os.path.isdir(path):
             result += files_in_dir(part, path, prefix + f + "/")
@@ -430,35 +582,76 @@ def files_in_dir(part, dir, prefix = ""):
     result.sort()
     return result
 
+
+def unpackaged_files():
+    unpackaged = {}
+    for part, title, perm, dir in get_package_parts():
+        unpackaged[part] = unpackaged_files_in_dir(part, dir)
+    return unpackaged
+
+
+def package_part_info():
+    part_info = {}
+    for part, title, perm, dir in get_package_parts():
+        part_info[part] = {
+            "title" : title,
+            "permission" : perm,
+            "path" : dir,
+            "files" : os.listdir(dir),
+        }
+    return part_info
+
+
 def unpackaged_files_in_dir(part, dir):
-    all    = files_in_dir(part, dir)
+    all = files_in_dir(part, dir)
     packed = packaged_files_in_dir(part)
     return [ f for f in all if f not in packed ]
 
+
 def packaged_files_in_dir(part):
     result = []
-    for pacname in all_packages():
-        package = read_package(pacname)
+    for pacname in all_package_names():
+        package = read_package_info(pacname)
         if package:
             result += package["files"].get(part, [])
     return result
 
-def read_package(pacname):
+
+def read_package_info(pacname):
     try:
-        package = eval(file(pac_dir + pacname).read())
+        package = parse_package_info(file(pac_dir + pacname).read())
+        package["name"] = pacname # do not trust package content
         num_files = sum([len(fl) for fl in package["files"].values() ])
         package["num_files"] = num_files
         return package
     except IOError:
         return None
     except Exception:
-        sys.stderr.write("Ignoring invalid package file '%s%s'. Please remove it from %s!\n" % (pac_dir, pacname, pac_dir))
+        verbose("Ignoring invalid package file '%s%s'. Please remove it from %s!\n" % (pac_dir, pacname, pac_dir))
         return None
 
-def write_package(pacname, package):
-    file(pac_dir + pacname, "w").write(pprint.pformat(package) + "\n")
 
-def all_packages():
+def write_package_info(package):
+    file(pac_dir + package["name"], "w").write(pprint.pformat(package) + "\n")
+
+
+def remove_package_info(pacname):
+     os.remove(pac_dir + pacname)
+
+
+def all_package_names():
     all = [ p for p in os.listdir(pac_dir) if p not in [ '.', '..' ] ]
     all.sort()
     return all
+
+
+def parse_package_info(python_string):
+    try:
+        # ast.literal_eval does not execute any code, just reads in passive
+        # data structures, so it is safe. But: not available on all supported
+        # Python versions
+        import ast
+    except:
+        return eval(python_string)
+
+    return ast.literal_eval(python_string)
