@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -42,7 +42,9 @@ import userdb
 import notify
 import webapi
 import visuals
-import crashed_check
+import crash_reporting
+import metrics
+import werks
 
 # map URLs to page rendering functions
 
@@ -59,8 +61,11 @@ pagehandlers.update({
    "count_context_button"     : views.ajax_count_button,
    "export_views"             : views.ajax_export,
    "ajax_set_viewoption"      : views.ajax_set_viewoption,
-   "ajax_set_rowselection"    : weblib.ajax_set_rowselection,
    "view"                     : views.page_view,
+   "ajax_inv_render_tree"     : views.ajax_inv_render_tree,
+   "host_service_graph_popup" : metrics.page_host_service_graph_popup,
+   "graph_dashlet"            : metrics.page_graph_dashlet,
+   "ajax_set_rowselection"    : weblib.ajax_set_rowselection,
    "prediction_graph"         : prediction.page_graph,
    "logwatch"                 : logwatch.page_show,
    "side"                     : sidebar.page_side,
@@ -77,10 +82,8 @@ pagehandlers.update({
    "ajax_search"              : sidebar.ajax_search,
    "search_open"              : sidebar.search_open,
    "switch_master_state"      : sidebar.ajax_switch_masterstate,
-   "add_bookmark"             : sidebar.ajax_add_bookmark,
-   "del_bookmark"             : sidebar.ajax_del_bookmark,
+   "add_bookmark"             : lambda: sidebar.ajax_add_bookmark(),
    "tree_openclose"           : weblib.ajax_tree_openclose,
-   "edit_bookmark"            : sidebar.page_edit_bookmark,
    "nagios_action"            : actions.ajax_action,
 
    "dashboard"                : dashboard.page_dashboard,
@@ -99,10 +102,19 @@ pagehandlers.update({
 
    "ajax_userdb_sync"         : userdb.ajax_sync,
    "notify"                   : notify.page_notify,
+
    "ajax_inv_render_tree"     : views.ajax_inv_render_tree,
 
+   "ajax_popup_icon_selector" : views.ajax_popup_icon_selector,
+   "ajax_popup_action_menu"   : views.ajax_popup_action_menu,
+
    "webapi"                   : webapi.page_api,
 
-   "crashed_check"            : crashed_check.page_crashed_check,
+   "crashed_check"            : lambda: crash_reporting.page_crashed("check"),
+   "gui_crash"                : lambda: crash_reporting.page_crashed("gui"),
+   "download_crash_report"    : crash_reporting.page_download_crash_report,
+
+   "version"                  : werks.page_version,
+   "werk"                     : werks.page_werk,
 })
 
