@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -78,19 +78,22 @@ def paint_mkeventd(what, row, tags, custom_vars):
     if getattr(config, 'mkeventd_distributed', False):
         url_prefix = site['url_prefix'] + 'check_mk/'
 
-    title = _('Events of Host %s') % (row["host_name"])
-    url   = 'view.py?' + html.urlencode_vars([
+    url_vars = [
           ("view_name", "ec_events_of_monhost"),
           ("site", row["site"]),
           ("host", row["host_name"]),
-        ])
+    ]
+
+    title = _('Events of Host %s') % (row["host_name"])
 
     if len(args) >= 2:
-        app   = args[1].strip('\'')
+        app   = args[1].strip('\'').replace("\\\\", "\\")
         title = _('Events of Application "%s" on Host %s') % (app, host)
-        url   += '&event_application=' + app
+        url_vars.append(("event_application", app))
 
-    return '<a href="%s">%s</a>' % (url_prefix + url, html.render_icon('mkeventd', title))
+    url = 'view.py?' + html.urlencode_vars(url_vars)
+
+    return 'mkeventd', title, url_prefix + url
 
 if mkeventd_enabled:
     multisite_icons.append({
