@@ -19,13 +19,13 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
 
 import mkeventd
-from  valuespec import *
+from valuespec import *
 
 try:
     mkeventd_enabled = config.mkeventd_enabled
@@ -72,16 +72,21 @@ def table_events(what, columns, add_headers, only_sites, limit, filters):
     # the host_address.
     host_filters = ""
     for host in required_hosts:
+        host_utf8 = host.encode("utf-8")
         host_filters += "Filter: host_name =~ %s\n" \
-                        "Filter: host_address = %s\n" % (host.encode("utf-8"), host.encode("utf-8"))
+                        "Filter: host_alias =~ %s\n" \
+                        "Filter: host_address = %s\n" % \
+                        (host_utf8, host_utf8, host_utf8)
     if len(required_hosts) > 0:
-        host_filters += "Or: %d\n" % (len(required_hosts) * 2)
+        host_filters += "Or: %d\n" % (len(required_hosts) * 3)
 
     # Make sure that the host name is fetched. We need it for
     # joining. The event columns are always fetched all. The event
     # daemon currently does not implement any Columns: header.
     if "host_name" not in columns:
         columns.append("host_name")
+    if "host_alias" not in columns:
+        columns.append("host_alias")
     if "host_address" not in columns:
         columns.append("host_address")
 
@@ -110,7 +115,7 @@ def table_events(what, columns, add_headers, only_sites, limit, filters):
     # Wir können das aber nochmal global steuern über eine Permission.
 
     if not config.may("mkeventd.seeall"):
-        host_contact_groups = {}
+        hosts_contact_groups = {}
         query = "GET hosts\nColumns: name address contact_groups\n" + host_filters
         html.live.set_only_sites(only_sites)
         html.live.set_auth_domain('mkeventd')
@@ -118,17 +123,18 @@ def table_events(what, columns, add_headers, only_sites, limit, filters):
         html.live.set_auth_domain('read')
         html.live.set_only_sites(None)
         for host, address, groups in data:
-            host_contact_groups[host.lower()] = groups
-            host_contact_groups[address] = groups
+            hosts_contact_groups[host.lower()] = groups
+            hosts_contact_groups[address] = groups
 
     else:
-        host_contact_groups = None
+        hosts_contact_groups = None
 
-    # Create lookup dict from hostname/address to the dataset of the host.
+    # Create lookup dict from hostname/alias/address to the dataset of the host.
     # This speeds up the mapping to the events.
     hostdict = {}
     for row in hostrows:
         hostdict[row["host_name"].lower()] = row
+        hostdict[row["host_alias"].lower()] = row
         hostdict[row["host_address"]] = row
 
     # If there is at least one host filter, then we do not show event
@@ -153,52 +159,65 @@ def table_events(what, columns, add_headers, only_sites, limit, filters):
     new_rows = []
     user_contact_groups = None
     for event in rows:
-        host = event["event_host"].lower()
+        host_name_lower = event["event_host"].lower()
+        monitoring_host = hostdict.get(host_name_lower)
 
-        # Users without the mkeventd.seeall permission only may see the host if
-        # they are a contact via the monitoring. In case the host is not known
-        # to the monitoring the permission mkeventd.seeunrelated is being neccessary
-        # as well.
-        if host_contact_groups != None:
-            if host in host_contact_groups:
-                if host not in hostdict:
-                    continue # Host known to monitoring, but user is now allowed
-            else: # Host not known to monitoring
-                # Has the event explicit contact groups assigned? Use them!
-                cgs = event.get("event_contact_groups")
-                if cgs == None:
-                    if not config.may("mkeventd.seeunrelated"):
-                        continue
-                else:
-                    if user_contact_groups == None:
-                        user_contact_groups = get_user_contact_groups()
+        if not user_may_see_event(event, monitoring_host, hosts_contact_groups):
+            continue
 
-                    allowed = False
-                    for g in cgs:
-                        if g in user_contact_groups:
-                            allowed = True
-                    if not allowed:
-                        continue
-
-        if host in hostdict:
-            event.update(hostdict[host])
+        if monitoring_host:
+            event.update(monitoring_host)
             new_rows.append(event)
+
+        # If we have any host filters we cannot add an incomplete host here
+        # since the filters will crash. So simply drop those hosts.
         elif not have_host_filter:
             # This event does not belong to any host known by
             # the monitoring. We need to create the columns nevertheless.
-            # TODO: If there are any host filters, these events should
-            # be dropped.
-            # Hier könnten wir Leerdaten eintragen. Dann
-            # kann man auch Events sehen, die keinem
-            # Host zugeordnet sind. Wenn wir nichts machen,
-            # dann fehlen Spalten und die Painter fallen
-            # auf die Nase.
             event.update(empty_host)
             new_rows.append(event)
 
     return new_rows
 
 
+def user_may_see_event(event, monitoring_host, hosts_contact_groups):
+    if config.may("mkeventd.seeall"):
+        return True
+
+    host_name_lower = event["event_host"].lower()
+
+    # Get contact groups of host from monitoring
+    if hosts_contact_groups and host_name_lower in hosts_contact_groups:
+        host_contact_groups = hosts_contact_groups[host_name_lower]
+    else:
+        host_contact_groups = None
+
+    # Get contact groups specified in event
+    event_contact_groups = event.get("event_contact_groups")
+
+    # Handle precedence
+    if host_contact_groups != None and event_contact_groups != None:
+        if config.mkeventd_contact_group_handling == "host":
+            contact_groups = host_contact_groups
+        else:
+            contact_groups = event_contact_groups
+    elif host_contact_groups:
+        contact_groups = host_contact_groups
+    elif event_contact_groups:
+        contact_groups = event_contact_groups
+    else:
+        contact_groups = None
+
+    if contact_groups == None:
+        return config.may("mkeventd.seeunrelated")
+    else:
+        for user_cg in get_user_contact_groups():
+            if user_cg in contact_groups:
+                return True
+
+        return False
+
+
 def event_hostrows(columns, only_sites, filters, host_filters):
     filter_code = ""
     for filt in filters:
@@ -306,12 +325,6 @@ if mkeventd_enabled:
     #   |                                                                      |
     #   '----------------------------------------------------------------------'
 
-    def paint_event_host(row):
-        if row["host_name"]:
-            return "", row["host_name"]
-        else:
-            return "", row["event_host"]
-
     multisite_painters["event_id"] = {
         "title"   : _("ID of the event"),
         "short"   : _("ID"),
@@ -386,13 +399,26 @@ if mkeventd_enabled:
         "paint"   : mkeventd_paint_sl,
     }
 
+    def paint_event_host(row):
+        if row["host_name"]:
+            return "", row["host_name"]
+        else:
+            return "", row["event_host"]
+
     multisite_painters["event_host"] = {
-        "title"   : _("Hostname/IP-Address"),
+        "title"   : _("Hostname"),
         "short"   : _("Host"),
         "columns" : ["event_host", "host_name"],
         "paint"   : paint_event_host,
     }
 
+    multisite_painters["event_ipaddress"] = {
+        "title"   : _("Original IP-Address"),
+        "short"   : _("Orig. IP"),
+        "columns" : ["event_ipaddress"],
+        "paint"   : lambda row: ("", row["event_ipaddress"]),
+    }
+
     multisite_painters["event_owner"] = {
         "title"   : _("Owner of event"),
         "short"   : _("owner"),
@@ -469,7 +495,7 @@ if mkeventd_enabled:
         "paint"   : lambda row: ("", mkeventd.phase_names.get(row["event_phase"], ''))
     }
 
-    def paint_event_icons(row):
+    def render_event_phase_icons(row):
         phase = row["event_phase"]
         if phase == "ack":
             title = _("This event has been acknowledged.")
@@ -477,9 +503,57 @@ if mkeventd_enabled:
             title = _("This event has not reached the target count yet.")
         elif phase == "delayed":
             title = _("The action of this event is still delayed in the hope of a cancelling event.")
+        else:
+            return ''
+        return html.render_icon(phase, help=title)
+
+    def render_delete_event_icons(row):
+        if config.may("mkeventd.delete"):
+            urlvars = []
+
+            # Found no cleaner way to get the view. Sorry.
+            # TODO: This needs to be cleaned up with the new view implementation.
+            if html.has_var("name") and html.has_var("id"):
+                ident = int(html.var("id"))
+
+                import dashboard
+                dashboard.load_dashboards()
+                view = dashboard.get_dashlet(html.var("name"), ident)
+
+                # These actions are not performed within the dashlet. Assume the title url still
+                # links to the source view where the action can be performed.
+                title_url = view.get("title_url")
+                if title_url:
+                    from urlparse import urlparse, parse_qsl
+                    url = urlparse(title_url)
+                    filename = url.path
+                    urlvars += parse_qsl(url.query)
+            else:
+                # Regular view
+                view = get_view_by_name(html.var("view_name"))
+                target = None
+                filename = None
+
+            urlvars += [
+                ("filled_in", "actions"),
+                ("actions", "yes"),
+                ("_do_actions", "yes"),
+                ("_row_id", row_id(view, row)),
+                ("_delete_event", _("Archive Event")),
+                ("_show_result", "0"),
+            ]
+            url = html.makeactionuri(urlvars, filename=filename)
+            return html.render_icon_button(url, _("Archive this event"), "delete")
+        else:
+            return ''
+
+    def paint_event_icons(row):
+        htmlcode =  render_event_phase_icons(row)
+        htmlcode += render_delete_event_icons(row)
+        if htmlcode:
+            return "icons", htmlcode
         else:
             return "", ""
-        return 'icons', '<img class=icon title="%s" src="images/icon_%s.png">' % (title, phase)
 
     multisite_painters["event_icons"] = {
         "title"   : _("Event Icons"),
@@ -489,6 +563,7 @@ if mkeventd_enabled:
         "paint"   : paint_event_icons,
     }
 
+
     def paint_event_contact_groups(row):
         cgs = row.get("event_contact_groups")
         if cgs == None:
@@ -499,8 +574,8 @@ if mkeventd_enabled:
             return "", "<i>"  + _("none") + "</i>"
 
     multisite_painters["event_contact_groups"] = {
-        "title"   : _("Fallback Contact Groups"),
-        "short"   : _("Contact Groups"),
+        "title"   : _("Contact groups defined in rule"),
+        "short"   : _("Rule Contact Groups"),
         "columns" : [ "event_contact_groups" ],
         "paint"   : paint_event_contact_groups,
     }
@@ -599,11 +674,11 @@ if mkeventd_enabled:
     def command_mkeventd_update(cmdtag, spec, row):
         if html.var('_mkeventd_update'):
             if config.may("mkeventd.update_comment"):
-                comment = html.var_utf8("_mkeventd_comment").strip().replace(";",",")
+                comment = html.get_unicode_input("_mkeventd_comment").strip().replace(";",",")
             else:
                 comment = ""
             if config.may("mkeventd.update_contact"):
-                contact = html.var_utf8("_mkeventd_contact").strip().replace(":",",")
+                contact = html.get_unicode_input("_mkeventd_contact").strip().replace(":",",")
             else:
                 contact = ""
             ack = html.get_checkbox("_mkeventd_acknowledge")
@@ -665,7 +740,7 @@ if mkeventd_enabled:
         for action_id, title in mkeventd.action_choices(omit_hidden = True):
             if html.var("_action_" + action_id):
                 return "ACTION;%s;%s;%s" % (row["event_id"], config.user_id, action_id), \
-                  (_("execute that action &quot;%s&quot") % title)
+                  (_("execute the action \"%s\"") % title)
 
     multisite_commands.append({
         "tables"      : [ "event" ],
@@ -728,7 +803,8 @@ if mkeventd_enabled:
     declare_1to1_sorter("event_last",        cmp_simple_number)
     declare_1to1_sorter("event_comment",     cmp_simple_string)
     declare_1to1_sorter("event_sl",          cmp_simple_number)
-    declare_1to1_sorter("event_host",        cmp_simple_string)
+    declare_1to1_sorter("event_host",        cmp_num_split)
+    declare_1to1_sorter("event_ipaddress",   cmp_num_split)
     declare_1to1_sorter("event_contact",     cmp_simple_string)
     declare_1to1_sorter("event_application", cmp_simple_string)
     declare_1to1_sorter("event_pid",         cmp_simple_number)
@@ -805,6 +881,7 @@ if mkeventd_enabled:
             'event_contact',
             'event_comment',
             'event_host_regex',
+            'event_ipaddress',
             'event_count',
             'event_phase',
             'event_state',
@@ -918,7 +995,9 @@ if mkeventd_enabled:
         'painters': [
             ('event_state', None, ''),
             ('event_host', None, ''),
-            ('host_address', 'hoststatus', ''),
+            ('event_ipaddress', None, ''),
+            ('foobar', None, ''),
+            ('alias', 'hoststatus', ''),
             ('host_contacts', None, ''),
             ('host_icons', None, ''),
             ('event_text', None, ''),
@@ -973,6 +1052,7 @@ if mkeventd_enabled:
             'event_contact',
             'event_comment',
             'event_host_regex',
+            'event_ipaddress',
             'event_count',
             'event_phase',
             'event_state',
@@ -1018,6 +1098,7 @@ if mkeventd_enabled:
             ('history_addinfo', None, ''),
             ('event_state', None, ''),
             ('event_host', 'ec_history_of_host', ''),
+            ('event_ipaddress', None, ''),
             ('event_text', None, ''),
             ('event_match_groups', None, ''),
             ('event_comment', None, ''),
@@ -1114,6 +1195,7 @@ if mkeventd_enabled:
             ('history_who', None, ''),
             ('event_state', None, ''),
             ('event_host', None, ''),
+            ('event_ipaddress', None, ''),
             ('event_application', None, ''),
             ('event_text', None, ''),
             ('event_sl', None, ''),
@@ -1145,6 +1227,7 @@ if mkeventd_enabled:
           'num_columns': 1,
           'painters': [('event_state', None, None),
                        ('event_host', None, None),
+                       ('event_ipaddress', None, ''),
                        ('host_address', 'hoststatus', None),
                        ('host_contacts', None, None),
                        ('host_icons', None, None),
