@@ -18,13 +18,13 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
 
 
-VERSION=1.2.6p12
+VERSION=1.2.8p14
 NAME=check_mk
 LANG=
 LC_ALL=
@@ -468,6 +468,7 @@ create_defaults ()
 {
 
 cat <<EOF
+# encoding: utf-8
 # This file has been created during setup of check_mk at $(date).
 # Do not edit this file. Also do not try to override these settings
 # in main.mk since some of them are hardcoded into several files
@@ -802,6 +803,8 @@ do
 	   fi &&
            mkdir -p $DESTDIR$sharedir &&
            tar xzf $SRCDIR/share.tar.gz -C $DESTDIR$sharedir &&
+           mkdir -p $DESTDIR$sharedir/werks &&
+           tar xzf $SRCDIR/werks.tar.gz -C $DESTDIR$sharedir/werks &&
 	   mkdir -p $DESTDIR$modulesdir &&
 	   create_defaults > $DESTDIR$modulesdir/defaults &&
            mkdir -p $DESTDIR$localedir &&
@@ -836,6 +839,8 @@ do
            fi &&
 	   mkdir -p $DESTDIR$confdir/conf.d &&
 	   if [ -z "$DESTDIR" ] ; then
+	     chgrp -R $wwwgroup $DESTDIR$vardir &&
+	     chmod -R g+w $DESTDIR$vardir &&
 	     chgrp -R $wwwgroup $DESTDIR$vardir/web &&
 	     chmod -R g+w $DESTDIR$vardir/web &&
 	     chgrp -R $wwwgroup $DESTDIR$vardir/log &&
@@ -964,6 +969,14 @@ and change the path there. Restart Apache afterwards."
       Satisfy any
   </Location>
 
+  # Webservice for dynamic creation of PNP templates
+  <Location "${url_prefix}check_mk/pnp_template.py">
+      Order deny,allow
+      Deny from all
+      Allow from 127.0.0.1
+      Satisfy any
+  </Location>
+
 </IfModule>
 
 
