@@ -19,13 +19,13 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
 
-import config, defaults, livestatus, views, pprint, os, copy, userdb
-import notify, urlparse
+import config, defaults, livestatus, views, pprint, os, copy, userdb, pagetypes
+import notify, werks, urlparse
 from lib import *
 
 # Constants to be used in snapins
@@ -37,9 +37,9 @@ loaded_with_language = False
 sidebar_snapins = {}
 search_plugins  = []
 
-def load_plugins():
+def load_plugins(force):
     global loaded_with_language
-    if loaded_with_language == current_language:
+    if loaded_with_language == current_language and not force:
         return
 
     # Load all snapins
@@ -63,6 +63,7 @@ def load_plugins():
             snapin["allowed"])
 
 # Helper functions to be used by snapins
+# FIXME: Clean this up and merge with htmllib
 def link(text, url, target="main", onclick = None):
     # Convert relative links into absolute links. We have three kinds
     # of possible links and we change only [3]
@@ -111,7 +112,9 @@ def iconbutton(what, url, target="side", handler="", name="", css_class = ""):
         href = "%scheck_mk/%s" % (defaults.url_prefix, url)
         tg = "target=%s" % target
     css_class = css_class and " " + css_class or ""
-    html.write("<a href=\"%s\" %s %s><img class=\"iconbutton%s\" onmouseover=\"hilite_icon(this, 1)\" onmouseout=\"hilite_icon(this, 0)\" align=absmiddle src=\"%scheck_mk/images/button_%s_lo.png\"></a>\n " % (href, onclick, tg, css_class, defaults.url_prefix, what))
+    html.write("<a href=\"%s\" %s %s><img class=\"iconbutton%s\" "
+               "align=absmiddle src=\"%scheck_mk/images/button_%s.png\"></a>\n " %
+                  (href, onclick, tg, css_class, defaults.url_prefix, what))
 
 def nagioscgilink(text, target):
     html.write("<li class=sidebar><a target=\"main\" class=link href=\"%snagios/cgi-bin/%s\">%s</a></li>" % \
@@ -148,17 +151,41 @@ def load_user_config():
 
     return user_config
 
+
 def save_user_config(user_config):
     if config.may("general.configure_sidebar"):
         config.save_user_file("sidebar", user_config)
 
+
+def get_check_mk_edition_title():
+    if not defaults.omd_root:
+        return "Raw"
+    version_link = os.readlink("%s/version" % defaults.omd_root)
+    if version_link.endswith(".cee.demo"):
+        return "Enterprise (Demo)"
+    elif "cee" in version_link:
+        return "Enterprise"
+    else:
+        return "Raw"
+
+
 def sidebar_head():
     html.write('<div id="side_header">')
     html.write('<div id="side_fold"></div>')
-    html.write('<a title="%s" target="main" href="%s">'
-               '<div id="side_version">%s</div>'
-               '</a>'
-               '</div>\n' % (_("Go to main overview"), html.attrencode(config.user.get("start_url") or config.start_url), defaults.check_mk_version))
+    html.write('<a title="%s" target="main" href="%s">' %
+          (_("Go to main overview"), html.attrencode(config.user.get("start_url") or config.start_url)))
+    html.write('<img id="side_bg" src="images/sidebar_top.png">')
+    html.write('<div id="side_version">'
+               '<a href="version.py" target="main" title=\"%s\">%s<br>%s' %
+        (_("Open release notes"), get_check_mk_edition_title(), defaults.check_mk_version))
+    if werks.may_acknowledge():
+        num_unacknowledged_werks = werks.num_unacknowledged_incompatible_werks()
+        if num_unacknowledged_werks:
+            html.write("<span title=\"%s\" class=\"unack_werks\">%d</span>" %
+                (_("%d unacknowledged incompatible werks") % num_unacknowledged_werks, num_unacknowledged_werks))
+    html.write('</a></div>')
+    html.write('</a></div>\n')
+
 
 def render_messages():
     for msg in notify.get_gui_messages():
@@ -208,7 +235,7 @@ def sidebar_foot():
     html.write('</div>')
 
     if load_user_config()["fold"]:
-        html.final_javascript("foldSidebar();")
+        html.final_javascript("fold_sidebar();")
 
 # Standalone sidebar
 def page_side():
@@ -222,10 +249,11 @@ def page_side():
     html.write('<body class="side')
     if config.screenshotmode:
         html.write(" screenshotmode")
-    html.write('" onload="initScrollPos(); setSidebarHeight(); init_messages(%s);" '
+    html.write('" onload="initScrollPos(); set_sidebar_size(); init_messages(%s);" '
                'onunload="storeScrollPos()">\n' % interval)
     html.write('<div id="check_mk_sidebar">\n')
 
+    # FIXME: Move this to the code where views are needed (snapins?)
     views.load_views()
     sidebar_head()
     user_config = load_user_config()
@@ -257,31 +285,36 @@ def page_side():
         html.write("sidebar_restart_time = %s\n" % time.time())
     html.write("sidebar_update_interval = %0.2f;\n" % config.sidebar_update_interval)
     html.write("registerEdgeListeners();\n")
-    html.write("setSidebarHeight();\n")
+    html.write("set_sidebar_size();\n")
     html.write("refresh_snapins = %r;\n" % refresh_snapins)
     html.write("restart_snapins = %r;\n" % restart_snapins)
     html.write("sidebar_scheduler();\n")
-    html.write("window.onresize = function() { setSidebarHeight(); };\n")
+    html.write("window.onresize = function() { set_sidebar_size(); };\n")
     html.write("if (contentFrameAccessible()) { update_content_location(); };\n")
     html.write("</script>\n")
 
     html.body_end()
 
-def render_snapin(name, state):
-    snapin = sidebar_snapins.get(name)
+def render_snapin_styles(snapin):
     styles = snapin.get("styles")
     if styles:
         html.write("<style>\n%s\n</style>\n" % styles)
 
+def render_snapin(name, state):
+    snapin = sidebar_snapins.get(name)
+    render_snapin_styles(snapin)
+
     html.write("<div id=\"snapin_container_%s\" class=snapin>\n" % name)
-    if state == "closed":
-        style = ' style="display:none"'
-        headclass = "closed"
-        minimaxi = "maxi"
-    else:
+    # When not permitted to open/close snapins, the snapins are always opened
+    if state == "open" or not config.may("general.configure_sidebar"):
         style = ""
         headclass = "open"
         minimaxi = "mini"
+    else:
+        style = ' style="display:none"'
+        headclass = "closed"
+        minimaxi = "maxi"
+
     toggle_url = "sidebar_openclose.py?name=%s&state=" % name
 
     html.write('<div class="head %s" ' % headclass)
@@ -295,13 +328,13 @@ def render_snapin(name, state):
         html.write(">")
 
 
-    # Icon for mini/maximizing, does not need permission
-    html.write('<div class="minisnapin">')
-    iconbutton(minimaxi + "snapin", None,
-               "side", "toggle_sidebar_snapin(this, '%s')" % toggle_url, 'snapin_'+name)
-    html.write('</div>')
-
     if config.may("general.configure_sidebar"):
+        # Icon for mini/maximizing
+        html.write('<div class="minisnapin">')
+        iconbutton(minimaxi + "snapin", None,
+                   "side", "toggle_sidebar_snapin(this, '%s')" % toggle_url, 'snapin_'+name)
+        html.write('</div>')
+
         # Button for closing (removing) a snapin
         html.write('<div class="closesnapin">')
         iconbutton("closesnapin", "sidebar_openclose.py?name=%s&state=off" % name,
@@ -309,9 +342,13 @@ def render_snapin(name, state):
         html.write('</div>')
 
     # The heading. A click on the heading mini/maximizes the snapin
-    html.write("<b class=heading onclick=\"toggle_sidebar_snapin(this,'%s')\" "
-               "onmouseover=\"this.style.cursor='pointer'\" "
-               "onmouseout=\"this.style.cursor='auto'\">%s</b>" % (toggle_url, snapin["title"]))
+    if config.may("general.configure_sidebar"):
+        toggle_actions = " onclick=\"toggle_sidebar_snapin(this,'%s')\"" \
+                         " onmouseover=\"this.style.cursor='pointer'\"" \
+                         " onmouseout=\"this.style.cursor='auto'\"" % toggle_url
+    else:
+        toggle_actions = ""
+    html.write("<b class=heading%s>%s</b>" % (toggle_actions, snapin["title"]))
 
     # End of header
     html.write("</div>")
@@ -326,18 +363,17 @@ def render_snapin(name, state):
             refresh_url = url
             html.write('<script>get_url("%s", updateContents, "snapin_%s")</script>' % (refresh_url, name))
     except Exception, e:
+        if config.debug:
+            raise
         snapin_exception(e)
     html.write('</div><div class="foot"%s></div>\n' % style)
     html.write('</div>')
     return refresh_url
 
 def snapin_exception(e):
-    if config.debug:
-        raise
-    else:
-        html.write("<div class=snapinexception>\n"
-                "<h2>%s</h2>\n"
-                "<p>%s</p></div>" % (_('Error'), e))
+    html.write("<div class=snapinexception>\n"
+            "<h2>%s</h2>\n"
+            "<p>%s</p></div>" % (_('Error'), e))
 
 def ajax_fold():
     config = load_user_config()
@@ -392,6 +428,8 @@ def ajax_snapin():
             try:
                 snapin["render"]()
             except Exception, e:
+                if config.debug:
+                    raise
                 snapin_exception(e)
             snapin_code.append(html.drain())
 
@@ -400,7 +438,7 @@ def ajax_snapin():
     except Exception, e:
         html.flush()
         html.unplug()
-        html.log('Exception during snapin refresh: %s' % e)
+        logger(LOG_ERR, 'Exception during snapin refresh: %s' % e)
         raise
 
 def move_snapin():
@@ -557,104 +595,6 @@ def ajax_switch_masterstate():
     else:
         html.write(_("Command %s/%d not found") % (html.attrencode(column), state))
 
-def ajax_del_bookmark():
-    try:
-        num = int(html.var("num"))
-    except ValueError:
-        raise MKGeneralException(_("Invalid bookmark id."))
-    bookmarks = load_bookmarks()
-    try:
-        del bookmarks[num]
-    except IndexError:
-        raise MKGeneralException(_("Unknown bookmark id: %d. This is probably a problem with reload or browser history. Please try again.") % html.attrencode(num))
-    save_bookmarks(bookmarks)
-    render_bookmarks()
-
-def ajax_add_bookmark():
-    title = html.var("title")
-    href = html.var("href")
-    if title and href:
-        bookmarks = load_bookmarks()
-        referer = html.req.headers_in.get("Referer")
-
-        if referer:
-            ref_p = urlparse.urlsplit(referer)
-            url_p = urlparse.urlsplit(href)
-
-            # If http/https or user, pw, host, port differ, don't try to shorten
-            # the URL to be linked. Simply use the full URI
-            if ref_p.scheme == url_p.scheme and ref_p.netloc == url_p.netloc:
-                # We try to remove http://hostname/some/path/check_mk from the
-                # URI. That keeps the configuration files (bookmarks) portable.
-                # Problem here: We have not access to our own URL, only to the
-                # path part. The trick: we use the Referrer-field from our
-                # request. That points to the sidebar.
-                referer = ref_p.path
-                href    = url_p.path
-                if url_p.query:
-                    href += '?' + url_p.query
-                removed = 0
-                while '/' in referer and referer.split('/')[0] == href.split('/')[0]:
-                    referer = referer.split('/', 1)[1]
-                    href = href.split('/', 1)[1]
-                    removed += 1
-
-                if removed == 1:
-                    # removed only the first "/". This should be an absolute path.
-                    href = '/' + href
-                elif '/' in referer:
-                    # there is at least one other directory layer in the path, make
-                    # the link relative to the sidebar.py's topdir. e.g. for pnp
-                    # links in OMD setups
-                    href = '../' + href
-
-        bookmarks.append((title, href))
-        save_bookmarks(bookmarks)
-    render_bookmarks()
-
-
-def page_edit_bookmark():
-    html.header(_("Edit Bookmark"))
-    try:
-        n = int(html.var("num"))
-    except ValueError:
-        raise MKGeneralException(_("Invalid bookmark id."))
-    bookmarks = load_bookmarks()
-    if n >= len(bookmarks):
-        raise MKGeneralException(_("Unknown bookmark id: %d. This is probably a problem with reload or browser history. Please try again.") % html.attrencode(n))
-
-    if html.var("save") and html.check_transaction():
-        title = html.var("title")
-        url = html.var("url")
-        bookmarks[n] = (title, url)
-        save_bookmarks(bookmarks)
-        html.reload_sidebar()
-
-    html.begin_form("edit_bookmark")
-    if html.var("save"):
-        title = html.var("title")
-        url = html.var("url")
-        bookmarks[n] = (title, url)
-        save_bookmarks(bookmarks)
-        html.reload_sidebar()
-    else:
-        title, url = bookmarks[n]
-        html.set_var("title", title)
-        html.set_var("url", url)
-
-    html.write("<table class=edit_bookmarks>")
-    html.write("<tr><td>%s</td><td>" % _('Title:'))
-    html.text_input("title", size = 50)
-    html.write("</td></tr><tr><td>%s:</td><td>" % _('URL'))
-    html.text_input("url", size = 50)
-    html.write("</td></tr><tr><td></td><td>")
-    html.button("save", _("Save"))
-    html.write("</td></tr></table>\n")
-    html.hidden_field("num", str(n))
-    html.end_form()
-
-    html.footer()
-
 def ajax_tag_tree():
     newconf = int(html.var("conf"))
     tree_conf = config.load_user_file("virtual_host_tree", {"tree": 0, "cwd": {}})
@@ -713,7 +653,7 @@ def to_regex(s):
         re.compile(s)
     except re.error:
         raise MKGeneralException(_('You search statement is not valid. You need to provide a regular '
-            'expression (regex). For example you need to e use <tt>\\\\</tt> instead of <tt>\\</tt> '
+            'expression (regex). For example you need to use <tt>\\\\</tt> instead of <tt>\\</tt> '
             'if you like to search for a single backslash.'))
     return s
 
@@ -752,7 +692,14 @@ def plugin_matches_filters(plugin, used_filters):
                 return False
     return True
 
-def search_url_tmpl(used_filters, row, exact = True):
+def search_url_tmpl(used_filters, matched_instances):
+    exact = True
+    if matched_instances and len(matched_instances) == 1:
+        row = matched_instances[0]
+    else:
+        row = matched_instances and matched_instances[0] or None
+        exact = False
+
     if not row:
         def find_plugin(filters):
             for entry in search_plugins:
@@ -824,6 +771,15 @@ def search_url_tmpl(used_filters, row, exact = True):
             'site'   : site,
         }
 
+    # This little 'adjustment' adds an extra url parameter for an optional hostnameoralias filter in the target view.
+    # If this filter is not activated it won't have any impact. The search_url_templ function is currently not designed
+    # to handle matches of multiple filter types and probably requires a complete revision to support this.
+    if not exact and matched_instances:
+        found_plugins = set(map(lambda instances: instances[0]["id"], matched_instances))
+        # Only add this extra parameter if there are solely hosts and host_alias matches
+        if "hosts" in found_plugins or "host_alias" in found_plugins:
+            url_tmpl += "&hostnameoralias=%s" % used_filters[0][1]
+
     return url_tmpl
 
 
@@ -908,7 +864,8 @@ def search_livestatus(used_filters):
         data.sort(cmp = sort_fctn)
         return sorted_data
 
-    if len(used_filters) == 1 and used_filters[0][0] != "hosts":
+    search_types = list(set(map(lambda x: x[0], used_filters)))
+    if len(used_filters) > 1 and search_types != ["hosts"]:
         data = sort_data(data)
 
     return data
@@ -969,7 +926,7 @@ def render_search_results(used_filters, objects, format_func = format_result):
         # Find missing urls
         name = get_row_name(row)
         if "url" not in row_options:
-            row_options["url"] = search_url_tmpl(used_filters, row)
+            row_options["url"] = search_url_tmpl(used_filters, [row])
 
         obj_id = (row_options["url"], name)
         if obj_id not in unique:
@@ -992,17 +949,19 @@ def ajax_search():
     if not q:
         return
 
-    data, used_filters = process_search(q)
-    if not data:
-        return
-
     try:
+        data, used_filters = process_search(q)
+        if not data:
+            return
+
         render_search_results(used_filters, data)
+    except MKException, e:
+        html.show_error(e)
     except Exception, e:
-        html.write("error")
+        if config.debug:
+            raise
         import traceback
-        html.write(traceback.format_exc())
-        html.write(repr(e))
+        html.show_error(traceback.format_exc())
 
 
 def search_open():
@@ -1010,14 +969,11 @@ def search_open():
     if not q:
         return
 
-    data, used_filters = process_search(q)
+    matched_instances, used_filters = process_search(q)
     if not used_filters:
         return
 
-    if data and len(data) == 1:
-        url = search_url_tmpl(used_filters, data[0])
-    else:
-        url = search_url_tmpl(used_filters, data and data[0] or None, exact = False)
+    url = search_url_tmpl(used_filters, matched_instances)
 
     html.set_http_header('Location', url)
     from mod_python import apache
