@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -29,7 +29,7 @@ def render_searchform():
     html.write('<input id="mk_side_search_field" type="text" name="search" autocomplete="off" />\n')
     html.icon_button("#", _("Search"), "quicksearch", onclick="mkSearchButton();")
     html.write('</div>\n<div id=mk_side_clear></div>\n')
-    html.write("<script type='text/javascript' src='js/search.js'></script>\n")
+    html.javascript_file(html.javascript_filename_for_browser("search"))
 
 sidebar_snapins["search"] = {
     "title":       _("Quicksearch"),
@@ -58,6 +58,19 @@ sidebar_snapins["search"] = {
     z-index:100;
 }
 
+#mk_side_search img.iconbutton {
+    opacity: 1;
+    filter: alpha(opacity=100); /* For IE8 and earlier */
+}
+
+#mk_side_search img.iconbutton:hover {
+    filter: grayscale(20%);
+    -webkit-filter: grayscale(20%);
+    -moz-filter: grayscale(20%);
+    -ms-filter: grayscale(20%);
+    -o-filter: grayscale(20%);
+}
+
 #mk_side_search input {
     margin:  0;
     padding: 0px 5px;
@@ -94,6 +107,10 @@ sidebar_snapins["search"] = {
     background-color: #BFBFBF;
 }
 
+#mk_search_results div.error {
+    padding: 2px;
+}
+
 """
 }
 
