@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -34,6 +34,16 @@ OID_BIN              = -2  # Complete OID as binary string "\x01\x03\x06\x01..."
 OID_END_BIN          = -3  # Same, but just the end part
 OID_END_OCTET_STRING = -4  # yet same, but omit first byte (assuming that is the length byte)
 
+
+# Wrapper to mark OIDs as being cached for regular checks, but not for discovery
+def CACHED_OID(oid):
+    return "cached", oid
+
+
+def BINARY(oid):
+    return "binary", oid
+
+
 def strip_snmp_value(value, hex_plain = False):
     v = value.strip()
     if v.startswith('"'):
@@ -41,7 +51,11 @@ def strip_snmp_value(value, hex_plain = False):
         if len(v) > 2 and is_hex_string(v):
             return not hex_plain and convert_from_hex(v) or value
         else:
-            return v.strip()
+            # Fix for non hex encoded string which have been somehow encoded by the
+            # netsnmp command line tools. An example:
+            # Checking windows systems via SNMP with hr_fs: disk names like c:\
+            # are reported as c:\\, fix this to single \
+            return v.strip().replace('\\\\', '\\')
     else:
         return v
 
@@ -86,7 +100,20 @@ def oid_to_intlist(oid):
 def cmp_oids(o1, o2):
     return cmp(oid_to_intlist(o1), oid_to_intlist(o2))
 
-def get_snmp_table(hostname, ip, check_type, oid_info):
+def cmp_oid_pairs(pair1, pair2):
+    return cmp(oid_to_intlist(pair1[0].lstrip('.')),
+               oid_to_intlist(pair2[0].lstrip('.')))
+
+def snmpv3_contexts_of_host(hostname):
+    return host_extra_conf(hostname, snmpv3_contexts)
+
+def snmpv3_contexts_of(hostname, check_type):
+    for ty, rules in snmpv3_contexts_of_host(hostname):
+        if ty == None or ty == check_type:
+            return rules
+    return [None]
+
+def get_snmp_table(hostname, ip, check_type, oid_info, use_snmpwalk_cache):
     # oid_info is either ( oid, columns ) or
     # ( oid, suboids, columns )
     # suboids is a list if OID-infixes that are put between baseoid
@@ -105,7 +132,6 @@ def get_snmp_table(hostname, ip, check_type, oid_info):
     all_values = []
     index_column = -1
     index_format = None
-    number_rows = -1
     info = []
     for suboid in suboids:
         colno = -1
@@ -115,18 +141,14 @@ def get_snmp_table(hostname, ip, check_type, oid_info):
         max_len_col = -1
 
         for column in targetcolumns:
-            fetchoid = oid
-            if suboid:
-                fetchoid += "." + str(suboid)
-            if column != "":
-                fetchoid += "." + str(column)
+            fetchoid, value_encoding = compute_fetch_oid(oid, suboid, column)
 
             # column may be integer or string like "1.5.4.2.3"
             colno += 1
             # if column is 0, we do not fetch any data from snmp, but use
             # a running counter as index. If the index column is the first one,
             # we do not know the number of entries right now. We need to fill
-            # in later. If the column in OID_STRING or OID_BIN we do something
+            # in later. If the column is OID_STRING or OID_BIN we do something
             # similar: we fill in the complete OID of the entry, either as
             # string or as binary UTF-8 encoded number string
             if column in [ OID_END, OID_STRING, OID_BIN, OID_END_BIN, OID_END_OCTET_STRING ]:
@@ -134,36 +156,22 @@ def get_snmp_table(hostname, ip, check_type, oid_info):
                     raise MKGeneralException("Invalid SNMP OID specification in implementation of check. "
                         "You can only use one of OID_END, OID_STRING, OID_BIN, OID_END_BIN and OID_END_OCTET_STRING.")
                 index_column = colno
-                columns.append((fetchoid, []))
+                columns.append((fetchoid, [], "string"))
                 index_format = column
                 continue
 
-            if opt_use_snmp_walk or is_usewalk_host(hostname):
-                rowinfo = get_stored_snmpwalk(hostname, fetchoid)
-            elif has_inline_snmp and use_inline_snmp:
-                rowinfo = inline_snmpwalk_on_suboid(hostname, check_type, fetchoid)
-            else:
-                rowinfo = snmpwalk_on_suboid(hostname, ip, fetchoid)
+            rowinfo = get_snmpwalk(hostname, ip, check_type, oid, fetchoid, column, use_snmpwalk_cache)
 
-            # I've seen a broken device (Mikrotik Router), that broke after an
-            # update to RouterOS v6.22. It would return 9 time the same OID when
-            # .1.3.6.1.2.1.1.1.0 was being walked. We try to detect these situations
-            # by removing any duplicate OID information
-            if len(rowinfo) > 1 and rowinfo[0][0] == rowinfo[1][0]:
-                if opt_verbose:
-                    sys.stderr.write("Detected broken SNMP agent. Ignoring duplicate OID %s.\n" % rowinfo[0][0])
-                rowinfo = rowinfo[:1]
-
-            columns.append((fetchoid, rowinfo))
-            number_rows = len(rowinfo)
-            if len(rowinfo) > max_len:
-                max_len = len(rowinfo)
+            columns.append((fetchoid, rowinfo, value_encoding))
+            number_of_rows = len(rowinfo)
+            if number_of_rows > max_len:
+                max_len     = number_of_rows
                 max_len_col = colno
 
         if index_column != -1:
             index_rows = []
             # Take end-oids of non-index columns as indices
-            fetchoid, max_column  = columns[max_len_col]
+            fetchoid, max_column, value_encoding  = columns[max_len_col]
             for o, value in max_column:
                 if index_format == OID_END:
                     index_rows.append((o, extract_end_oid(fetchoid, o)))
@@ -176,74 +184,181 @@ def get_snmp_table(hostname, ip, check_type, oid_info):
                 else: # OID_END_OCTET_STRING:
                     index_rows.append((o, oid_to_bin(extract_end_oid(fetchoid, o))[1:]))
 
-            columns[index_column] = fetchoid, index_rows
+            columns[index_column] = fetchoid, index_rows, value_encoding
 
 
         # prepend suboid to first column
-        if suboid and len(columns) > 0:
-            fetchoid, first_column = columns[0]
+        if suboid and columns:
+            fetchoid, first_column, value_encoding = columns[0]
             new_first_column = []
             for o, val in first_column:
                 new_first_column.append((o, str(suboid) + "." + str(val)))
-            columns[0] = fetchoid, new_first_column
+            columns[0] = fetchoid, new_first_column, value_encoding
 
-        # Swap X and Y axis of table (we want one list of columns per item)
         # Here we have to deal with a nasty problem: Some brain-dead devices
         # omit entries in some sub OIDs. This happens e.g. for CISCO 3650
         # in the interfaces MIB with 64 bit counters. So we need to look at
         # the OIDs and watch out for gaps we need to fill with dummy values.
+        new_columns = sanitize_snmp_table_columns(columns)
 
-        # First compute the complete list of end-oids appearing in the output
-        # by looping all results and putting the endoids to a flat list
-        endoids = []
-        for fetchoid, column in columns:
-            for o, value in column:
-                endoid = extract_end_oid(fetchoid, o)
-                if endoid not in endoids:
-                    endoids.append(endoid)
+        # From all SNMP data sources (stored walk, classic SNMP, inline SNMP) we
+        # get normal python strings. But for Check_MK we need unicode strings now.
+        # Convert them by using the standard Check_MK approach for incoming data
+        sanitized_columns = sanitize_snmp_encoding(new_columns)
 
-        # The list needs to be sorted to prevent problems when the first
-        # column has missing values in the middle of the tree. Since we
-        # work with strings of numerical components, a simple string sort
-        # is not correct. 1.14 must come after 1.2!
-        endoids.sort(cmp = cmp_oids)
-
-        # Now fill gaps in columns where some endois are missing
-        new_columns = []
-        for fetchoid, column in columns:
-            i = 0
-            new_column = []
-            # Loop all lines to fill holes in the middle of the list. All
-            # columns check the following lines for the correct endoid. If
-            # an endoid differs empty values are added until the hole is filled
-            for o, value in column:
-                eo = extract_end_oid(fetchoid, o)
-                if len(column) != len(endoids):
-                    while i < len(endoids) and endoids[i] != eo:
-                        new_column.append("") # (beginoid + '.' +endoids[i], "" ) )
-                        i += 1
-                new_column.append(value)
-                i += 1
-
-            # At the end check if trailing OIDs are missing
-            while i < len(endoids):
-                new_column.append("") # (beginoid + '.' +endoids[i], "") )
-                i += 1
-            new_columns.append(new_column)
-        columns = new_columns
-
-        # Now construct table by swapping X and Y
-        new_info = []
-        index = 0
-        if len(columns) > 0:
-            for item in columns[0]:
-                new_info.append([ c[index] for c in columns ])
-                index += 1
-            info += new_info
+        info += construct_snmp_table_of_rows(sanitized_columns)
 
     return info
 
 
+def get_snmpwalk(hostname, ip, check_type, oid, fetchoid, column, use_snmpwalk_cache):
+    is_cachable = is_snmpwalk_cachable(column)
+    rowinfo = None
+    if is_cachable and use_snmpwalk_cache:
+        # Returns either the cached SNMP walk or None when nothing is cached
+        rowinfo = get_cached_snmpwalk(hostname, fetchoid)
+
+    if rowinfo == None:
+        if opt_use_snmp_walk or is_usewalk_host(hostname):
+            rowinfo = get_stored_snmpwalk(hostname, fetchoid)
+        else:
+            rowinfo = perform_snmpwalk(hostname, ip, check_type, oid, fetchoid)
+
+        if is_cachable:
+            save_snmpwalk_cache(hostname, fetchoid, rowinfo)
+
+    return rowinfo
+
+
+def perform_snmpwalk(hostname, ip, check_type, base_oid, fetchoid):
+    added_oids = set([])
+    rowinfo = []
+    if is_snmpv3_host(hostname):
+        snmp_contexts = snmpv3_contexts_of(hostname, check_type)
+    else:
+        snmp_contexts = [None]
+
+    for context_name in snmp_contexts:
+        if is_inline_snmp_host(hostname):
+            rows = inline_snmpwalk_on_suboid(hostname, check_type, fetchoid, base_oid,
+                                                                  context_name=context_name)
+        else:
+            rows = snmpwalk_on_suboid(hostname, ip, fetchoid, context_name=context_name)
+
+        # I've seen a broken device (Mikrotik Router), that broke after an
+        # update to RouterOS v6.22. It would return 9 time the same OID when
+        # .1.3.6.1.2.1.1.1.0 was being walked. We try to detect these situations
+        # by removing any duplicate OID information
+        if len(rows) > 1 and rows[0][0] == rows[1][0]:
+            vverbose("Detected broken SNMP agent. Ignoring duplicate OID %s.\n" % rows[0][0])
+            rows = rows[:1]
+
+        for row_oid, val in rows:
+            if row_oid in added_oids:
+                vverbose("Duplicate OID found: %s (%s)\n" % (row_oid, val))
+            else:
+                rowinfo.append((row_oid, val))
+                added_oids.add(row_oid)
+
+    return rowinfo
+
+
+def compute_fetch_oid(oid, suboid, column):
+    fetchoid = oid
+    value_encoding = "string"
+
+    if suboid:
+        fetchoid += "." + str(suboid)
+
+    if column != "":
+        if type(column) == tuple:
+            fetchoid += "." + str(column[1])
+            if column[0] == "binary":
+                value_encoding = "binary"
+        else:
+            fetchoid += "." + str(column)
+
+    return fetchoid, value_encoding
+
+
+def sanitize_snmp_encoding(columns):
+    for index, (column, value_encoding) in enumerate(columns):
+        if value_encoding == "string":
+            columns[index] = map(snmp_decode_string, column)
+        else:
+            columns[index] = map(snmp_decode_binary, column)
+    return columns
+
+
+def sanitize_snmp_table_columns(columns):
+    # First compute the complete list of end-oids appearing in the output
+    # by looping all results and putting the endoids to a flat list
+    endoids = []
+    for fetchoid, column, value_encoding in columns:
+        for o, value in column:
+            endoid = extract_end_oid(fetchoid, o)
+            if endoid not in endoids:
+                endoids.append(endoid)
+
+    # The list needs to be sorted to prevent problems when the first
+    # column has missing values in the middle of the tree.
+    if not are_ascending_oids(endoids):
+        endoids.sort(cmp = cmp_oids)
+        need_sort = True
+    else:
+        need_sort = False
+
+    # Now fill gaps in columns where some endois are missing
+    new_columns = []
+    for fetchoid, column, value_encoding in columns:
+        # It might happen that end OIDs are not ordered. Fix the OID sorting to make
+        # it comparable to the already sorted endoids list. Otherwise we would get
+        # some mixups when filling gaps
+        if need_sort:
+            column.sort(cmp = cmp_oid_pairs)
+
+        i = 0
+        new_column = []
+        # Loop all lines to fill holes in the middle of the list. All
+        # columns check the following lines for the correct endoid. If
+        # an endoid differs empty values are added until the hole is filled
+        for o, value in column:
+            eo = extract_end_oid(fetchoid, o)
+            if len(column) != len(endoids):
+                while i < len(endoids) and endoids[i] != eo:
+                    new_column.append("") # (beginoid + '.' +endoids[i], "" ) )
+                    i += 1
+            new_column.append(value)
+            i += 1
+
+        # At the end check if trailing OIDs are missing
+        while i < len(endoids):
+            new_column.append("") # (beginoid + '.' +endoids[i], "") )
+            i += 1
+        new_columns.append((new_column, value_encoding))
+
+    return new_columns
+
+
+def are_ascending_oids(oid_list):
+    for a in range(len(oid_list) - 1):
+        if cmp_oids(oid_list[a], oid_list[a + 1]) > 0: # == 0 should never happen
+            return False
+    return True
+
+
+def construct_snmp_table_of_rows(columns):
+    if not columns:
+        return []
+
+    # Now construct table by swapping X and Y.
+    new_info = []
+    for index in range(len(columns[0])):
+        row = [ c[index] for c in columns ]
+        new_info.append(row)
+    return new_info
+
+
 # SNMP-Helper functions used in various checks
 
 def check_snmp_misc(item, params, info):
@@ -293,6 +408,34 @@ def check_snmp_fixed(item, targetvalue, info):
                 return (0, "OK - %s" % (value,))
     return (3, "Missing item %s in SNMP data" % item)
 
+
+def is_snmpwalk_cachable(column):
+    return type(column) == tuple and column[0] == "cached"
+
+
+def get_cached_snmpwalk(hostname, fetchoid):
+    path = var_dir + "/snmp_cache/" + hostname + "/" + fetchoid
+
+    try:
+        vverbose("  Loading %s from walk cache %s\n" % (fetchoid, path))
+        return eval(file(path).read())
+    except IOError:
+        return None # don't print error when not cached yet
+    except:
+        if opt_debug:
+            raise
+        verbose("Failed to read cached SNMP walk from %s, ignoring.\n" % path)
+        return None
+
+
+def save_snmpwalk_cache(hostname, fetchoid, rowinfo):
+    base_dir = var_dir + "/snmp_cache/" + hostname + "/"
+    if not os.path.exists(base_dir):
+        os.makedirs(base_dir)
+    vverbose("  Caching walk of %s\n" % fetchoid)
+    file(base_dir + fetchoid, "w").write("%r\n" % rowinfo)
+
+
 g_walk_cache = {}
 def get_stored_snmpwalk(hostname, oid):
     if oid.startswith("."):
@@ -307,6 +450,8 @@ def get_stored_snmpwalk(hostname, oid):
 
     path = snmpwalks_dir + "/" + hostname
 
+    vverbose("  Loading %s from %s\n" % (oid, path))
+
     rowinfo = []
 
     # New implementation: use binary search
@@ -331,7 +476,7 @@ def get_stored_snmpwalk(hostname, oid):
         try:
             lines = file(path).readlines()
         except IOError:
-            raise MKGeneralException("No snmpwalk file %s\n" % path)
+            raise MKSNMPError("No snmpwalk file %s" % path)
         g_walk_cache[hostname] = lines
 
     begin = 0
@@ -388,29 +533,27 @@ def get_stored_snmpwalk(hostname, oid):
     rowinfo = collect_until(current, -1)
     rowinfo.reverse()
     rowinfo += collect_until(current + 1, 1)
-    # import pprint ; pprint.pprint(rowinfo)
 
     if dot_star:
         return [ rowinfo[0] ]
     else:
         return rowinfo
 
-# Helper function to be used in checks.  It applies a user-specified
-# character encoding in order to tranlate e.g. latin1 to utf8
 def snmp_decode_string(text):
     encoding = get_snmp_character_encoding(g_hostname)
     if encoding:
-        return text.decode(encoding).encode("utf-8")
+        return text.decode(encoding)
     else:
-        # Try to determine the current string encoding. In case a UTF-8
-        # decoding fails, we decode latin1 and encode it as UTF-8 again.
-        # When UTF-8 decoding works, we assume the string is already
-        # encoded in UTF-8 as we expect it to be.
+        # Try to determine the current string encoding. In case a UTF-8 decoding fails, we decode latin1.
         try:
-            text.decode('utf-8')
-            return text
+            return text.decode('utf-8')
         except:
-            return text.decode('latin1').encode('utf-8')
+            return text.decode('latin1')
+
+
+def snmp_decode_binary(text):
+    return map(ord, text)
+
 
 #   .--Classic SNMP--------------------------------------------------------.
 #   |        ____ _               _        ____  _   _ __  __ ____         |
@@ -423,14 +566,17 @@ def snmp_decode_string(text):
 #   | Non-inline SNMP handling code. Kept for compatibility.               |
 #   '----------------------------------------------------------------------'
 
-def snmpwalk_on_suboid(hostname, ip, oid, hex_plain = False):
+def snmpwalk_on_suboid(hostname, ip, oid, hex_plain = False, context_name = None):
+    protospec = snmp_proto_spec(hostname)
     portspec = snmp_port_spec(hostname)
-    command = snmp_walk_command(hostname) + \
-             " -OQ -OU -On -Ot %s%s %s" % (ip, portspec, oid)
-    if opt_debug:
-        sys.stderr.write('   Running %s\n' % (command,))
+    command = snmp_walk_command(hostname)
+    if context_name != None:
+        command += " -n %s" % quote_shell_string(context_name)
+    command += " -OQ -OU -On -Ot %s%s%s %s" % (protospec, ip, portspec, oid)
+    vverbose('   Running %s\n' % command)
 
-    snmp_process = subprocess.Popen(command, shell = True, stdout = subprocess.PIPE, stderr = subprocess.PIPE)
+    snmp_process = subprocess.Popen(command, shell=True, close_fds=True, stdin=open(os.devnull),
+                                    stdout=subprocess.PIPE, stderr=subprocess.PIPE)
 
     # Ugly(1): in some cases snmpwalk inserts line feed within one
     # dataset. This happens for example on hexdump outputs longer
@@ -467,7 +613,6 @@ def snmpwalk_on_suboid(hostname, ip, oid, hex_plain = False):
     error = snmp_process.stderr.read()
     exitstatus = snmp_process.wait()
     if exitstatus:
-        if opt_verbose:
-            sys.stderr.write(tty_red + tty_bold + "ERROR: " + tty_normal + "SNMP error: %s\n" % error.strip())
+        verbose(tty_red + tty_bold + "ERROR: " + tty_normal + "SNMP error: %s\n" % error.strip())
         raise MKSNMPError("SNMP Error on %s: %s (Exit-Code: %d)" % (ip, error.strip(), exitstatus))
     return rowinfo
