@@ -23,107 +23,82 @@
 // Boston, MA 02110-1301 USA.
 
 #include "AndingFilter.h"
+#include <cinttypes>
 #include "OringFilter.h"
-#include "logger.h"
 #include "Query.h"
+#include "logger.h"
 
-AndingFilter::~AndingFilter()
-{
-    for (_subfilters_t::iterator it = _subfilters.begin();
-            it != _subfilters.end();
-            ++it)
-    {
-        delete *it;
+AndingFilter::~AndingFilter() {
+    for (auto &subfilter : _subfilters) {
+        delete subfilter;
     }
 }
 
-void AndingFilter::addSubfilter(Filter *f)
-{
-    _subfilters.push_back(f);
-}
+void AndingFilter::addSubfilter(Filter *f) { _subfilters.push_back(f); }
 
-
-Filter *AndingFilter::stealLastSubfiler()
-{
-    if (_subfilters.size() == 0)
-        return 0;
-    else {
-        Filter *l = _subfilters.back();
-        _subfilters.pop_back();
-        return l;
+Filter *AndingFilter::stealLastSubfiler() {
+    if (_subfilters.empty()) {
+        return nullptr;
     }
+    Filter *l = _subfilters.back();
+    _subfilters.pop_back();
+    return l;
 }
 
-
-bool AndingFilter::accepts(void *data)
-{
-    for (_subfilters_t::iterator it = _subfilters.begin();
-            it != _subfilters.end();
-            ++it)
-    {
-        Filter *filter = *it;
-        if (!filter->accepts(data))
+bool AndingFilter::accepts(void *data) {
+    for (auto filter : _subfilters) {
+        if (!filter->accepts(data)) {
             return false;
+        }
     }
     return true;
 }
 
-void *AndingFilter::findIndexFilter(const char *columnname)
-{
-    for (_subfilters_t::iterator it = _subfilters.begin();
-            it != _subfilters.end();
-            ++it)
-    {
-        Filter *filter = *it;
+void *AndingFilter::findIndexFilter(const char *columnname) {
+    for (auto filter : _subfilters) {
         void *refvalue = filter->indexFilter(columnname);
-        if (refvalue)
+        if (refvalue != nullptr) {
             return refvalue;
+        }
     }
-    return 0;
+    return nullptr;
 }
 
-void AndingFilter::findIntLimits(const char *columnname, int *lower, int *upper)
-{
-    for (_subfilters_t::iterator it = _subfilters.begin();
-            it != _subfilters.end();
-            ++it)
-    {
-        Filter *filter = *it;
+void AndingFilter::findIntLimits(const char *columnname, int *lower,
+                                 int *upper) {
+    for (auto filter : _subfilters) {
         filter->findIntLimits(columnname, lower, upper);
     }
 }
 
-bool AndingFilter::optimizeBitmask(const char *columnname, uint32_t *mask)
-{
+bool AndingFilter::optimizeBitmask(const char *columnname, uint32_t *mask) {
     bool optimized = false;
-    for (_subfilters_t::iterator it = _subfilters.begin();
-            it != _subfilters.end();
-            ++it)
-    {
-        Filter *filter = *it;
-        if (filter->optimizeBitmask(columnname, mask))
+    for (auto filter : _subfilters) {
+        if (filter->optimizeBitmask(columnname, mask)) {
             optimized = true;
+        }
     }
     return optimized;
 }
 
-void AndingFilter::combineFilters(int count, int andor)
-{
-    if (count > (int)_subfilters.size()) {
-        logger(LG_INFO, "Cannot combine %d filters with '%s': only %d are on stack",
-                count, andor == ANDOR_AND ? "AND" : "OR", _subfilters.size());
+void AndingFilter::combineFilters(int count, int andor) {
+    if (count > static_cast<int>(_subfilters.size())) {
+        logger(LG_INFO, "Cannot combine %d filters with '%s': only %" PRIuMAX
+                        " are on stack",
+               count, andor == ANDOR_AND ? "AND" : "OR",
+               static_cast<uintmax_t>(_subfilters.size()));
         return;
     }
 
-    AndingFilter *andorfilter; // OringFilter is subclassed from AndingFilter
-    if (andor == ANDOR_AND)
+    AndingFilter *andorfilter;  // OringFilter is subclassed from AndingFilter
+    if (andor == ANDOR_AND) {
         andorfilter = new AndingFilter();
-    else
+    } else {
         andorfilter = new OringFilter();
-    while (count--) {
+    }
+    while ((count--) != 0) {
         andorfilter->addSubfilter(_subfilters.back());
         _subfilters.pop_back();
     }
     addSubfilter(andorfilter);
 }
-
