@@ -24,9 +24,8 @@
 
 #include "AttributelistFilter.h"
 #include "AttributelistColumn.h"
-#include "opids.h"
 #include "logger.h"
-
+#include "opids.h"
 
 /* The following operators are defined:
 
@@ -48,25 +47,29 @@
    Also number comparisons
  */
 
-
-bool AttributelistFilter::accepts(void *data)
-{
+bool AttributelistFilter::accepts(void *data) {
     unsigned long act_value = _column->getValue(data);
     bool pass = true;
     switch (_opid) {
         case OP_EQUAL:
-            pass = act_value == _ref; break;
+            pass = act_value == _ref;
+            break;
         case OP_GREATER:
-            pass = act_value > _ref; break;
+            pass = act_value > _ref;
+            break;
         case OP_LESS:
-            pass = act_value < _ref; break;
+            pass = act_value < _ref;
+            break;
         case OP_REGEX:
-            pass = (act_value & _ref) == _ref; break;
+            pass = (act_value & _ref) == _ref;
+            break;
         case OP_REGEX_ICASE:
-            pass = (act_value & _ref) != 0; break;
+            pass = (act_value & _ref) != 0;
+            break;
         default:
-            logger(LG_INFO, "Sorry. Operator %s not implemented for attribute lists", op_names_plus_8[_opid]);
+            logger(LG_INFO,
+                   "Sorry. Operator %s not implemented for attribute lists",
+                   op_names_plus_8[_opid]);
     }
     return pass != _negate;
 }
-
