@@ -25,28 +25,26 @@
 #ifndef ClientQueue_h
 #define ClientQueue_h
 
-#include "config.h"
-
+#include "config.h"  // IWYU pragma: keep
 #include <deque>
-#include <pthread.h>
+#include <memory>
+#include "mk/ConditionVariable.h"
+#include "mk/Mutex.h"
 
-using namespace std;
-
-class ClientQueue
-{
-    typedef deque<int> _queue_t;
-    _queue_t _queue;
+class ClientQueue {
 public:
     ClientQueue();
     ~ClientQueue();
     void addConnection(int);
     int popConnection();
-    void wakeupAll();
+    void terminate();
 
-    pthread_mutex_t _lock;
-    pthread_cond_t _signal;
+private:
+    typedef std::deque<int> _queue_t;
+    _queue_t _queue;
+    mk::mutex _mutex;
+    mk::condition_variable _cond;
+    bool _should_terminate;
 };
 
-
-#endif // ClientQueue_h
-
+#endif  // ClientQueue_h
