@@ -22,36 +22,44 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
+#include <utility>
+
 #include "Column.h"
-#include "logger.h"
 
+using std::string;
 
-Column::Column(string name, string description, int indirect_offset)
-  : _name(name)
-  , _description(description)
-  , _indirect_offset(indirect_offset)
-  , _extra_offset(-1)
-{
-}
-
-void *Column::shiftPointer(void *data)
-{
-    if (!data)
-        return 0;
+Column::Column(string name, string description, int indirect_offset,
+               int extra_offset, int extra_extra_offset)
+    : _name(std::move(name))
+    , _description(std::move(description))
+    , _indirect_offset(indirect_offset)
+    , _extra_offset(extra_offset)
+    , _extra_extra_offset(extra_extra_offset) {}
 
+void *Column::shiftPointer(void *data) {
+    if (data == nullptr) {
+        return nullptr;
+    }
     if (_indirect_offset >= 0) {
-        // add one indirection level
-        // indirect_offset is place in structure, where
-        // pointer to real object is
-        data = *((void **)((char *)data + _indirect_offset));
-        if (!data)
-            return 0;
+        data = *(reinterpret_cast<void **>(reinterpret_cast<char *>(data) +
+                                           _indirect_offset));
     }
 
-    // one optional extra level of indirection
-    if (_extra_offset >= 0)
-        data = *((void **)((char *)data + _extra_offset));
+    if (data == nullptr) {
+        return nullptr;
+    }
+    if (_extra_offset >= 0) {
+        data = *(reinterpret_cast<void **>(reinterpret_cast<char *>(data) +
+                                           _extra_offset));
+    }
+
+    if (data == nullptr) {
+        return nullptr;
+    }
+    if (_extra_extra_offset >= 0) {
+        data = *(reinterpret_cast<void **>(reinterpret_cast<char *>(data) +
+                                           _extra_extra_offset));
+    }
 
     return data;
 }
-
