@@ -23,11 +23,10 @@
 // Boston, MA 02110-1301 USA.
 
 #include "ColumnsColumn.h"
-#include "Column.h"
 #include "TableColumns.h"
+class Column;
 
-char *ColumnsColumn::getValue(void *data)
-{
-    Column *column = (Column *)data;
-    return (char *)_table_columns->getValue(column, _colcol);
+const char *ColumnsColumn::getValue(void *data) {
+    Column *column = static_cast<Column *>(data);
+    return _table_columns->getValue(column, _colcol);
 }
