@@ -23,34 +23,28 @@
 // Boston, MA 02110-1301 USA.
 
 #include "ContactsColumn.h"
-#include "nagios.h"
-#include "TableContacts.h"
-#include "logger.h"
 #include "Query.h"
-#include "tables.h"
+#include "nagios.h"
 
 extern contact *contact_list;
 
-void *ContactsColumn::getNagiosObject(char *name)
-{
-    return (void *)find_contact(name);
-}
+void *ContactsColumn::getNagiosObject(char *name) { return find_contact(name); }
 
-void ContactsColumn::output(void *data, Query *query)
-{
+void ContactsColumn::output(void *data, Query *query) {
     query->outputBeginList();
     data = shiftPointer(data);
 
-    if (data) {
+    if (data != nullptr) {
         bool first = true;
 
         contact *ctc = contact_list;
-        while (ctc) {
+        while (ctc != nullptr) {
             if (isNagiosMember(data, ctc)) {
-                if (first)
+                if (first) {
                     first = false;
-                else
+                } else {
                     query->outputListSeparator();
+                }
                 query->outputString(ctc->name);
             }
             ctc = ctc->next;
@@ -59,15 +53,13 @@ void ContactsColumn::output(void *data, Query *query)
     query->outputEndList();
 }
 
-
-bool ContactsColumn::isEmpty(void *svc)
-{
+bool ContactsColumn::isEmpty(void *svc) {
     contact *ct = contact_list;
-    while (ct) {
-        if (isNagiosMember(svc, ct))
+    while (ct != nullptr) {
+        if (isNagiosMember(svc, ct)) {
             return false;
+        }
         ct = ct->next;
     }
     return true;
 }
-
