@@ -23,17 +23,14 @@
 // Boston, MA 02110-1301 USA.
 
 #include "CountAggregator.h"
-#include "Query.h"
 #include "Filter.h"
+#include "Query.h"
 
-void CountAggregator::consume(void *data, Query *)
-{
+void CountAggregator::consume(void *data, Query * /*unused*/) {
     // _filter is 0 --> no filter, accept all data
-    if (!_filter || _filter->accepts(data))
+    if ((_filter == nullptr) || _filter->accepts(data)) {
         _count++;
+    }
 }
 
-void CountAggregator::output(Query *q)
-{
-    q->outputInteger(_count);
-}
+void CountAggregator::output(Query *q) { q->outputInteger(_count); }
