@@ -23,34 +23,33 @@
 // Boston, MA 02110-1301 USA.
 
 #include "CustomVarsColumn.h"
-#include "nagios.h"
-#include "logger.h"
+#include <string.h>
 #include "CustomVarsFilter.h"
 #include "Query.h"
 
-void CustomVarsColumn::output(void *data, Query *query)
-{
-
-    if (_what == CVT_DICT)
+void CustomVarsColumn::output(void *data, Query *query) {
+    if (_what == CVT_DICT) {
         query->outputBeginDict();
-    else
+    } else {
         query->outputBeginList();
+    }
 
     customvariablesmember *cvm = getCVM(data);
 
     bool first = true;
-    while (cvm) {
-        if (first)
+    while (cvm != nullptr) {
+        if (first) {
             first = false;
-        else if (_what == CVT_DICT)
+        } else if (_what == CVT_DICT) {
             query->outputDictSeparator();
-        else
+        } else {
             query->outputListSeparator();
-        if (_what == CVT_VARNAMES)
+        }
+        if (_what == CVT_VARNAMES) {
             query->outputString(cvm->variable_name);
-        else if (_what == CVT_VALUES)
+        } else if (_what == CVT_VALUES) {
             query->outputString(cvm->variable_value);
-        else {
+        } else {
             query->outputString(cvm->variable_name);
             query->outputDictValueSeparator();
             query->outputString(cvm->variable_value);
@@ -58,46 +57,49 @@ void CustomVarsColumn::output(void *data, Query *query)
         cvm = cvm->next;
     }
 
-    if (_what == CVT_DICT)
+    if (_what == CVT_DICT) {
         query->outputEndDict();
-    else
+    } else {
         query->outputEndList();
+    }
 }
 
-Filter *CustomVarsColumn::createFilter(int opid, char *value)
-{
+Filter *CustomVarsColumn::createFilter(int opid, char *value) {
     return new CustomVarsFilter(this, opid, value);
 }
 
-
-customvariablesmember *CustomVarsColumn::getCVM(void *data)
-{
-    if (!data) return 0;
+customvariablesmember *CustomVarsColumn::getCVM(void *data) {
+    if (data == nullptr) {
+        return nullptr;
+    }
     data = shiftPointer(data);
-    if (!data) return 0;
-    return *(customvariablesmember **)((char *)data + _offset);
+    if (data == nullptr) {
+        return nullptr;
+    }
+    return *reinterpret_cast<customvariablesmember **>(
+        reinterpret_cast<char *>(data) + _offset);
 }
 
-
-bool CustomVarsColumn::contains(void *data, const char *value)
-{
+bool CustomVarsColumn::contains(void *data, const char *value) {
     customvariablesmember *cvm = getCVM(data);
-    while (cvm) {
-        char *ref = _what == CVT_VARNAMES ? cvm->variable_name : cvm->variable_value;
-        if (!strcmp(ref, value))
+    while (cvm != nullptr) {
+        char *ref =
+            _what == CVT_VARNAMES ? cvm->variable_name : cvm->variable_value;
+        if (strcmp(ref, value) == 0) {
             return true;
+        }
         cvm = cvm->next;
     }
     return false;
 }
 
-char *CustomVarsColumn::getVariable(void *data, const char *varname)
-{
+char *CustomVarsColumn::getVariable(void *data, const char *varname) {
     customvariablesmember *cvm = getCVM(data);
-    while (cvm) {
-        if (!strcmp(cvm->variable_name, varname))
+    while (cvm != nullptr) {
+        if (strcmp(cvm->variable_name, varname) == 0) {
             return cvm->variable_value;
+        }
         cvm = cvm->next;
     }
-    return 0;
+    return nullptr;
 }
