@@ -25,36 +25,37 @@
 #ifndef CustomVarsColumn_h
 #define CustomVarsColumn_h
 
-#include "config.h"
-
-#include "Column.h"
+#include "config.h"  // IWYU pragma: keep
 #include <string>
+#include "Column.h"
 #include "nagios.h"
-
-using namespace std;
+class Filter;
+class Query;
 
 #define CVT_VARNAMES 0
-#define CVT_VALUES   1
-#define CVT_DICT     2
+#define CVT_VALUES 1
+#define CVT_DICT 2
 
-class CustomVarsColumn : public Column
-{
-    int _offset; // within data structure (differs from host/service)
+class CustomVarsColumn : public Column {
+    int _offset;  // within data structure (differs from host/service)
     int _what;
 
 public:
-    CustomVarsColumn(string name, string description, int offset, int indirect_offset, int what)
-        : Column(name, description, indirect_offset),  _offset(offset), _what(what) {}
-    int type() { return _what == CVT_DICT ? COLTYPE_DICT : COLTYPE_LIST; }
-    void output(void *, Query *);
-    Filter *createFilter(int opid, char *value);
+    CustomVarsColumn(std::string name, std::string description, int offset,
+                     int indirect_offset, int what, int extra_offset = -1)
+        : Column(name, description, indirect_offset, extra_offset)
+        , _offset(offset)
+        , _what(what) {}
+    int type() override {
+        return _what == CVT_DICT ? COLTYPE_DICT : COLTYPE_LIST;
+    }
+    void output(void *, Query *) override;
+    Filter *createFilter(int opid, char *value) override;
     bool contains(void *data, const char *value);
     char *getVariable(void *data, const char *varname);
+
 private:
     customvariablesmember *getCVM(void *data);
 };
 
-
-#endif // CustomVarsColumn_h
-
-
+#endif  // CustomVarsColumn_h
