@@ -25,22 +25,21 @@
 #ifndef CustomVarsFilter_h
 #define CustomVarsFilter_h
 
-#include "config.h"
-
-#include "CustomVarsColumn.h"
-#include "Filter.h"
+#include "config.h"  // IWYU pragma: keep
 #include <regex.h>
+#include <string>
+#include "Filter.h"
+class CustomVarsColumn;
 
-class CustomVarsFilter : public Filter
-{
+class CustomVarsFilter : public Filter {
     CustomVarsColumn *_column;
     int _opid;
     bool _negate;
-    string _ref_text;
+    std::string _ref_text;
     regex_t *_regex;
     // needed in case of COLTYPE_DICT
-    string _ref_string;
-    string _ref_varname;
+    std::string _ref_string;
+    std::string _ref_varname;
 
 public:
     CustomVarsFilter(CustomVarsColumn *column, int opid, char *value);
@@ -48,5 +47,4 @@ public:
     bool accepts(void *data);
 };
 
-#endif // CustomVarsFilter_h
-
+#endif  // CustomVarsFilter_h
