@@ -22,38 +22,40 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-#include <math.h>
 #include "DoubleAggregator.h"
-#include "StatsColumn.h"
+#include <math.h>
 #include "DoubleColumn.h"
 #include "Query.h"
+#include "StatsColumn.h"
 
 /* SORRY: This file is copy&pasted from IntAggregator.
    I hate copy & paste. But I also dislike complicating
    stuff by using C++ templates and the like.
  */
 
-void DoubleAggregator::consume(void *data, Query *)
-{
+void DoubleAggregator::consume(void *data, Query * /*unused*/) {
     _count++;
     double value = _column->getValue(data);
     switch (_operation) {
         case STATS_OP_SUM:
         case STATS_OP_AVG:
-            _aggr += value; break;
+            _aggr += value;
+            break;
 
         case STATS_OP_MIN:
-            if (_count == 1)
+            if (_count == 1) {
                 _aggr = value;
-            else if (value < _aggr)
+            } else if (value < _aggr) {
                 _aggr = value;
+            }
             break;
 
         case STATS_OP_MAX:
-            if (_count == 1)
+            if (_count == 1) {
                 _aggr = value;
-            else if (value > _aggr)
+            } else if (value > _aggr) {
                 _aggr = value;
+            }
             break;
 
         case STATS_OP_STD:
@@ -68,9 +70,7 @@ void DoubleAggregator::consume(void *data, Query *)
     }
 }
 
-
-void DoubleAggregator::output(Query *q)
-{
+void DoubleAggregator::output(Query *q) {
     switch (_operation) {
         case STATS_OP_SUM:
         case STATS_OP_MIN:
@@ -81,18 +81,20 @@ void DoubleAggregator::output(Query *q)
 
         case STATS_OP_AVG:
         case STATS_OP_AVGINV:
-            if (_count == 0)
+            if (_count == 0) {
                 q->outputDouble(0.0);
-            else
+            } else {
                 q->outputDouble(_aggr / _count);
+            }
             break;
 
         case STATS_OP_STD:
-            if (_count <= 1)
+            if (_count <= 1) {
                 q->outputDouble(0.0);
-            else
-                q->outputDouble(sqrt((_sumq - (_aggr * _aggr) / _count)/(_count - 1)));
+            } else {
+                q->outputDouble(
+                    sqrt((_sumq - (_aggr * _aggr) / _count) / (_count - 1)));
+            }
             break;
     }
 }
-
