@@ -23,21 +23,21 @@
 // Boston, MA 02110-1301 USA.
 
 #include "DoubleColumn.h"
+#include <stdio.h>
 #include "DoubleColumnFilter.h"
 #include "Query.h"
 
-void DoubleColumn::output(void *data, Query *query)
-{
+using std::string;
+
+void DoubleColumn::output(void *data, Query *query) {
     query->outputDouble(getValue(data));
 }
 
-Filter *DoubleColumn::createFilter(int operator_id, char *value)
-{
+Filter *DoubleColumn::createFilter(int operator_id, char *value) {
     return new DoubleColumnFilter(this, operator_id, value);
 }
 
-string DoubleColumn::valueAsString(void *data, Query *query)
-{
+string DoubleColumn::valueAsString(void *data, Query * /*unused*/) {
     char buf[64];
     snprintf(buf, sizeof(buf), "%.10e", getValue(data));
     return buf;
