@@ -22,35 +22,37 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-#include <stdlib.h>
 #include "DoubleColumnFilter.h"
+#include <stdlib.h>
 #include "DoubleColumn.h"
 #include "logger.h"
 #include "opids.h"
 
-DoubleColumnFilter::DoubleColumnFilter(DoubleColumn *column, int opid, char *value)
+DoubleColumnFilter::DoubleColumnFilter(DoubleColumn *column, int opid,
+                                       char *value)
     : _column(column)
     , _ref_value(atof(value))
     , _opid(abs(opid))
-    , _negate(opid < 0)
-{
-}
+    , _negate(opid < 0) {}
 
-bool DoubleColumnFilter::accepts(void *data)
-{
+bool DoubleColumnFilter::accepts(void *data) {
     bool pass = true;
     double act_value = _column->getValue(data);
     switch (_opid) {
         case OP_EQUAL:
-            pass = act_value == _ref_value; break;
+            pass = act_value == _ref_value;
+            break;
         case OP_GREATER:
-            pass = act_value > _ref_value; break;
+            pass = act_value > _ref_value;
+            break;
         case OP_LESS:
-            pass = act_value < _ref_value; break;
+            pass = act_value < _ref_value;
+            break;
         default:
-            logger(LG_INFO, "Sorry. Operator %s for float columns not implemented.", op_names_plus_8[_opid]);
+            logger(LG_INFO,
+                   "Sorry. Operator %s for float columns not implemented.",
+                   op_names_plus_8[_opid]);
             break;
     }
     return pass != _negate;
 }
-
