@@ -25,26 +25,19 @@
 #ifndef DoubleColumnFilter_h
 #define DoubleColumnFilter_h
 
-#include "config.h"
-
-#include <string>
-using namespace std;
-
+#include "config.h"  // IWYU pragma: keep
 #include "Filter.h"
 class DoubleColumn;
 
-class DoubleColumnFilter : public Filter
-{
+class DoubleColumnFilter : public Filter {
     DoubleColumn *_column;
     double _ref_value;
     int _opid;
     bool _negate;
 
 public:
-    DoubleColumnFilter(DoubleColumn *_column, int opid, char *value);
+    DoubleColumnFilter(DoubleColumn *column, int opid, char *value);
     bool accepts(void *data);
 };
 
-
-#endif // DoubleColumnFilter_h
-
+#endif  // DoubleColumnFilter_h
