@@ -23,102 +23,103 @@
 // Boston, MA 02110-1301 USA.
 
 #include "DownCommColumn.h"
+#include <stdint.h>
+#include <stdlib.h>
+#include <map>
+#include <utility>
 #include "DowntimeOrComment.h"
-#include "TableDownComm.h"
-#include "logger.h"
 #include "Query.h"
+#include "TableDownComm.h"
+#include "nagios.h"
 #include "tables.h"
 
-void DownCommColumn::output(void *data, Query *query)
-{
+using std::map;
+using std::pair;
+
+void DownCommColumn::output(void *data, Query *query) {
     TableDownComm *table = _is_downtime ? g_table_downtimes : g_table_comments;
     query->outputBeginList();
-    data = shiftPointer(data); // points to host or service
-    if (data)
-    {
+    data = shiftPointer(data);  // points to host or service
+    if (data != nullptr) {
         bool first = true;
-        bool found_match = false;
 
-        for (map<pair<unsigned long, bool>, DowntimeOrComment *>::iterator it = table->entriesIteratorBegin();
-                it != table->entriesIteratorEnd();
-                ++it)
-        {
-            unsigned long id     = it->first.first;
-            bool is_service       =  it->first.second;
-            DowntimeOrComment *dt =  it->second;
+        for (auto entry : *table) {
+            unsigned long id = entry.first.first;
+            bool is_service = entry.first.second;
+            DowntimeOrComment *dt = entry.second;
 
-            found_match = false;
+            bool found_match = false;
 
-            if (!is_service){
-                if (dt->_host->name == ((host*)data)->name)
+            if (!is_service) {
+                if (dt->_host->name == static_cast<host *>(data)->name) {
                     found_match = true;
+                }
+            } else if (dt->_service->description ==
+                           static_cast<service *>(data)->description &&
+                       dt->_service->host_name ==
+                           static_cast<service *>(data)->host_name) {
+                found_match = true;
             }
-            else
-               if ( dt->_service->description == ((service*)data)->description && dt->_service->host_name == ((service*)data)->host_name )
-                    found_match = true;
 
-            if (found_match)
-            {
-                if (first)
+            if (found_match) {
+                if (first) {
                     first = false;
-                else
+                } else {
                     query->outputListSeparator();
-                if (_with_info)
-                {
+                }
+                if (_with_info) {
                     query->outputBeginSublist();
                     query->outputUnsignedLong(id);
                     query->outputSublistSeparator();
                     query->outputString(dt->_author_name);
                     query->outputSublistSeparator();
                     query->outputString(dt->_comment);
-                    if(_with_extra_info && !_is_downtime) {
+                    if (_with_extra_info && !_is_downtime) {
                         query->outputSublistSeparator();
-                        query->outputInteger(((Comment*)dt)->_entry_type);
+                        query->outputInteger(
+                            static_cast<Comment *>(dt)->_entry_type);
                         query->outputSublistSeparator();
                         query->outputTime(dt->_entry_time);
                     }
                     query->outputEndSublist();
-                }
-                else
+                } else {
                     query->outputUnsignedLong(id);
+                }
             }
         }
     }
     query->outputEndList();
 }
 
-void *DownCommColumn::getNagiosObject(char *name)
-{
-    unsigned int id = strtoul(name, 0, 10);
-    return (void *)id; // Hack. Convert number into pointer.
+void *DownCommColumn::getNagiosObject(char *name) {
+    // Hack. Convert number into pointer.
+    return static_cast<char *>(nullptr) + strtoul(name, nullptr, 10);
 }
 
-bool DownCommColumn::isNagiosMember(void *data, void *member)
-{
+bool DownCommColumn::isNagiosMember(void *data, void *member) {
     TableDownComm *table = _is_downtime ? g_table_downtimes : g_table_comments;
     // data points to a host or service
     // member is not a pointer, but an unsigned int (hack)
-    int64_t id = (int64_t)member; // Hack. Convert it back.
+    unsigned long id = static_cast<unsigned long>(
+        reinterpret_cast<uintptr_t>(member));  // Hack. Convert it back.
     DowntimeOrComment *dt = table->findEntry(id, _is_service);
-    return dt != 0 &&
-        ( dt->_service == (service *)data || (dt->_service == 0 && dt->_host == (host *)data));
+    return dt != nullptr && (dt->_service == static_cast<service *>(data) ||
+                             (dt->_service == nullptr &&
+                              dt->_host == static_cast<host *>(data)));
 }
 
-bool DownCommColumn::isEmpty(void *data)
-{
-    if (!data) return true;
+bool DownCommColumn::isEmpty(void *data) {
+    if (data == nullptr) {
+        return true;
+    }
 
     TableDownComm *table = _is_downtime ? g_table_downtimes : g_table_comments;
-    for (map<pair<unsigned long, bool>, DowntimeOrComment *>::iterator it = table->entriesIteratorBegin();
-            it != table->entriesIteratorEnd();
-            ++it)
-    {
-        DowntimeOrComment *dt = it->second;
-        if ((void *)dt->_service == data ||
-                (dt->_service == 0 && dt->_host == data))
-        {
+    for (auto entry : *table) {
+        DowntimeOrComment *dt = entry.second;
+        if (dt->_service == data ||
+            (dt->_service == nullptr && dt->_host == data)) {
             return false;
         }
     }
-    return true; // empty
+    return true;  // empty
 }
