@@ -25,18 +25,13 @@
 #ifndef DowntimeOrComment_h
 #define DowntimeOrComment_h
 
-#include "config.h"
-
-#include "nagios.h"
-#include <string>
-using namespace std;
+#include "config.h"  // IWYU pragma: keep
+#include <time.h>
+#include "nagios.h"  // IWYU pragma: keep
 
 /* The structs for downtime and comment are so similar, that
    we handle them with the same logic */
 
-
-
-
 /*
    typedef struct nebstruct_downtime_struct{
    int             type;
@@ -83,41 +78,36 @@ using namespace std;
    }nebstruct_comment_data;
  */
 
-struct DowntimeOrComment
-{
-    int           _type;
-    host         *_host;
-    service      *_service;
-    time_t        _entry_time;
-    char *        _author_name;
-    char*         _comment;
+struct DowntimeOrComment {
+    int _type;
+    host *_host;
+    service *_service;
+    time_t _entry_time;
+    char *_author_name;
+    char *_comment;
     unsigned long _id;
-    int           _is_service;
+    int _is_service;
 
-    DowntimeOrComment(nebstruct_downtime_struct *data, unsigned long id);
+    DowntimeOrComment(nebstruct_downtime_struct *dt, unsigned long id);
     virtual ~DowntimeOrComment();
 };
 
-struct Downtime : public DowntimeOrComment
-{
-    time_t        _start_time;
-    time_t        _end_time;
-    int           _fixed;
-    int           _duration;
-    int           _triggered_by;
-    Downtime(nebstruct_downtime_struct *data);
+struct Downtime : public DowntimeOrComment {
+    time_t _start_time;
+    time_t _end_time;
+    int _fixed;
+    int _duration;
+    int _triggered_by;
+    explicit Downtime(nebstruct_downtime_struct *dt);
 };
 
-struct Comment : public DowntimeOrComment
-{
-    time_t        _expire_time;
-    int           _persistent;
-    int           _source;
-    int           _entry_type;
-    int           _expires;
-    Comment(nebstruct_comment_struct *data);
+struct Comment : public DowntimeOrComment {
+    time_t _expire_time;
+    int _persistent;
+    int _source;
+    int _entry_type;
+    int _expires;
+    explicit Comment(nebstruct_comment_struct *co);
 };
 
-
-#endif // Downtime_h
-
+#endif  // DowntimeOrComment_h
