@@ -25,18 +25,19 @@
 #ifndef HostContactsColumn_h
 #define HostContactsColumn_h
 
-#include "config.h"
-
+#include "config.h"  // IWYU pragma: keep
+#include <string>
+#include "Column.h"
 #include "ContactsColumn.h"
 
-class HostContactsColumn : public ContactsColumn
-{
+class HostContactsColumn : public ContactsColumn {
 public:
-    HostContactsColumn(string name, string description, int indirect_offset)
-        : ContactsColumn(name, description, indirect_offset) {}
-    int type() { return COLTYPE_LIST; }
-    bool isNagiosMember(void *data, void *member);
+    HostContactsColumn(std::string name, std::string description,
+                       int indirect_offset, int extra_offset = -1)
+        : ContactsColumn(name, description, indirect_offset,
+                         extra_offset = -1) {}
+    int type() override { return COLTYPE_LIST; }
+    bool isNagiosMember(void *hst, void *ctc) override;
 };
 
-#endif // HostContactsColumn_h
-
+#endif  // HostContactsColumn_h
