@@ -23,31 +23,31 @@
 // Boston, MA 02110-1301 USA.
 
 #include "HostgroupsColumn.h"
-#include "nagios.h"
 #include "Query.h"
 
-objectlist *HostgroupsColumn::getData(void *data)
-{
-    if (data) {
+objectlist *HostgroupsColumn::getData(void *data) {
+    if (data != nullptr) {
         data = shiftPointer(data);
-        if (data)
-            return *(objectlist **)((char *)data + _offset);
+        if (data != nullptr) {
+            return *reinterpret_cast<objectlist **>(
+                reinterpret_cast<char *>(data) + _offset);
+        }
     }
-    return 0;
+    return nullptr;
 }
 
-void HostgroupsColumn::output(void *data, Query *query)
-{
+void HostgroupsColumn::output(void *data, Query *query) {
     query->outputBeginList();
     objectlist *list = getData(data);
-    if (list) {
+    if (list != nullptr) {
         bool first = true;
-        while (list) {
-            hostgroup *sg = (hostgroup *)list->object_ptr;
-            if (!first)
+        while (list != nullptr) {
+            hostgroup *sg = reinterpret_cast<hostgroup *>(list->object_ptr);
+            if (!first) {
                 query->outputListSeparator();
-            else
+            } else {
                 first = false;
+            }
             query->outputString(sg->group_name);
             list = list->next;
         }
@@ -55,30 +55,31 @@ void HostgroupsColumn::output(void *data, Query *query)
     query->outputEndList();
 }
 
-void *HostgroupsColumn::getNagiosObject(char *name)
-{
+void *HostgroupsColumn::getNagiosObject(char *name) {
     return find_hostgroup(name);
 }
 
-bool HostgroupsColumn::isNagiosMember(void *data, void *nagobject)
-{
-    if (!nagobject || !data)
+bool HostgroupsColumn::isNagiosMember(void *data, void *nagobject) {
+    if ((nagobject == nullptr) || (data == nullptr)) {
         return false;
+    }
 
     // data is already shifted (_indirect_offset is taken into account)
     // But _offset needs still to be accounted for
-    objectlist *list = *(objectlist **)((char *)data + _offset);
+    objectlist *list = *reinterpret_cast<objectlist **>(
+        reinterpret_cast<char *>(data) + _offset);
 
-    while (list) {
-        if (list->object_ptr == nagobject)
+    while (list != nullptr) {
+        if (list->object_ptr == nagobject) {
             return true;
+        }
         list = list->next;
     }
     return false;
 }
 
-bool HostgroupsColumn::isEmpty(void *data)
-{
-    objectlist *list = *(objectlist **)((char *)data + _offset);
-    return list == 0;
+bool HostgroupsColumn::isEmpty(void *data) {
+    objectlist *list = *reinterpret_cast<objectlist **>(
+        reinterpret_cast<char *>(data) + _offset);
+    return list == nullptr;
 }
