@@ -24,38 +24,39 @@
 
 #include "HostlistColumn.h"
 #include "HostlistColumnFilter.h"
-#include "nagios.h"
-#include "logger.h"
 #include "Query.h"
 #include "TableHosts.h"
 
 extern TableHosts *g_table_hosts;
 
-hostsmember *HostlistColumn::getMembers(void *data)
-{
+hostsmember *HostlistColumn::getMembers(void *data) {
     data = shiftPointer(data);
-    if (!data) return 0;
+    if (data == nullptr) {
+        return nullptr;
+    }
 
-    return *(hostsmember **)((char *)data + _offset);
+    return *reinterpret_cast<hostsmember **>(reinterpret_cast<char *>(data) +
+                                             _offset);
 }
 
-void HostlistColumn::output(void *data, Query *query)
-{
+void HostlistColumn::output(void *data, Query *query) {
     query->outputBeginList();
     contact *auth_user = query->authUser();
     hostsmember *mem = getMembers(data);
 
     bool first = true;
-    while (mem) {
+    while (mem != nullptr) {
         host *hst = mem->host_ptr;
-        if (!auth_user || g_table_hosts->isAuthorized(auth_user, hst)) {
-            if (!first)
+        if ((auth_user == nullptr) ||
+            g_table_hosts->isAuthorized(auth_user, hst)) {
+            if (!first) {
                 query->outputListSeparator();
-            else
+            } else {
                 first = false;
-            if (!_show_state)
+            }
+            if (!_show_state) {
                 query->outputString(hst->name);
-            else {
+            } else {
                 query->outputBeginSublist();
                 query->outputString(hst->name);
                 query->outputSublistSeparator();
@@ -70,8 +71,6 @@ void HostlistColumn::output(void *data, Query *query)
     query->outputEndList();
 }
 
-Filter *HostlistColumn::createFilter(int opid, char *value)
-{
+Filter *HostlistColumn::createFilter(int opid, char *value) {
     return new HostlistColumnFilter(this, opid, value);
 }
-
