@@ -23,26 +23,28 @@
 // Boston, MA 02110-1301 USA.
 
 #include "HostlistColumnFilter.h"
+#include <stdlib.h>
 #include "HostlistColumn.h"
+#include "logger.h"
 #include "nagios.h"
 #include "opids.h"
-#include "logger.h"
 
-bool HostlistColumnFilter::accepts(void *data)
-{
+bool HostlistColumnFilter::accepts(void *data) {
     // data points to a primary data object. We need to extract
     // a pointer to a host list
     hostsmember *mem = _hostlist_column->getMembers(data);
 
     // test for empty list
-    if (abs(_opid) == OP_EQUAL && _ref_value == "")
-        return (mem == 0) == (_opid == OP_EQUAL);
+    if (abs(_opid) == OP_EQUAL && _ref_value == "") {
+        return (mem == nullptr) == (_opid == OP_EQUAL);
+    }
 
     bool is_member = false;
-    while (mem) {
+    while (mem != nullptr) {
         char *host_name = mem->host_name;
-        if (!host_name)
+        if (host_name == nullptr) {
             host_name = mem->host_ptr->name;
+        }
 
         if (host_name == _ref_value) {
             is_member = true;
@@ -56,8 +58,9 @@ bool HostlistColumnFilter::accepts(void *data)
         case OP_LESS:
             return !is_member;
         default:
-            logger(LG_INFO, "Sorry, Operator %s for host lists lists not implemented.", op_names_plus_8[_opid]);
+            logger(LG_INFO,
+                   "Sorry, Operator %s for host lists lists not implemented.",
+                   op_names_plus_8[_opid]);
             return true;
     }
 }
-
