@@ -23,41 +23,47 @@
 // Boston, MA 02110-1301 USA.
 
 #include "HostlistStateColumn.h"
-#include "ServicelistStateColumn.h"
-#include "nagios.h"
-#include "TableServices.h"
 #include "Query.h"
+#include "TableServices.h"
 
 extern TableServices *g_table_hosts;
 
-
-inline bool hst_state_is_worse(int32_t state1, int32_t state2)
-{
-    if (state1 == 0) return false;        // UP is worse than nothing
-    else if (state2 == 0) return true;    // everything else is worse then UP
-    else if (state2 == 1) return false;   // nothing is worse than DOWN
-    else if (state1 == 1) return true;    // state1 is DOWN, state2 not
-    else return false;                    // both are UNREACHABLE
+static inline bool hst_state_is_worse(int32_t state1, int32_t state2) {
+    if (state1 == 0) {
+        return false;  // UP is worse than nothing
+    }
+    if (state2 == 0) {
+        return true;  // everything else is worse then UP
+    }
+    if (state2 == 1) {
+        return false;  // nothing is worse than DOWN
+    }
+    if (state1 == 1) {
+        return true;  // state1 is DOWN, state2 not
+    }
+    return false;  // both are UNREACHABLE
 }
 
-hostsmember *HostlistStateColumn::getMembers(void *data)
-{
+hostsmember *HostlistStateColumn::getMembers(void *data) {
     data = shiftPointer(data);
-    if (!data) return 0;
+    if (data == nullptr) {
+        return nullptr;
+    }
 
-    return *(hostsmember **)((char *)data + _offset);
+    return *reinterpret_cast<hostsmember **>(reinterpret_cast<char *>(data) +
+                                             _offset);
 }
 
-int32_t HostlistStateColumn::getValue(void *data, Query *query)
-{
+int32_t HostlistStateColumn::getValue(void *data, Query *query) {
     contact *auth_user = query->authUser();
     hostsmember *mem = getMembers(data);
     int32_t result = 0;
     int state;
 
-    while (mem) {
+    while (mem != nullptr) {
         host *hst = mem->host_ptr;
-        if (!auth_user || g_table_hosts->isAuthorized(auth_user, hst)) {
+        if ((auth_user == nullptr) ||
+            g_table_hosts->isAuthorized(auth_user, hst)) {
             switch (_logictype) {
                 case HLSC_NUM_SVC_PENDING:
                 case HLSC_NUM_SVC_OK:
@@ -65,34 +71,42 @@ int32_t HostlistStateColumn::getValue(void *data, Query *query)
                 case HLSC_NUM_SVC_CRIT:
                 case HLSC_NUM_SVC_UNKNOWN:
                 case HLSC_NUM_SVC:
-                    result += ServicelistStateColumn::getValue(_logictype, hst->services, query);
+                    result += ServicelistStateColumn::getValue(
+                        _logictype, hst->services, query);
                     break;
 
                 case HLSC_WORST_SVC_STATE:
-                    state = ServicelistStateColumn::getValue(_logictype, hst->services, query);
-                    if (ServicelistStateColumn::svcStateIsWorse(state, result))
+                    state = ServicelistStateColumn::getValue(
+                        _logictype, hst->services, query);
+                    if (ServicelistStateColumn::svcStateIsWorse(state,
+                                                                result)) {
                         result = state;
+                    }
                     break;
 
                 case HLSC_NUM_HST_UP:
                 case HLSC_NUM_HST_DOWN:
                 case HLSC_NUM_HST_UNREACH:
-                    if (hst->has_been_checked && hst->current_state == _logictype - HLSC_NUM_HST_UP)
-                        result ++;
+                    if ((hst->has_been_checked != 0) &&
+                        hst->current_state == _logictype - HLSC_NUM_HST_UP) {
+                        result++;
+                    }
                     break;
 
                 case HLSC_NUM_HST_PENDING:
-                    if (!hst->has_been_checked)
-                        result ++;
+                    if (hst->has_been_checked == 0) {
+                        result++;
+                    }
                     break;
 
                 case HLSC_NUM_HST:
-                    result ++;
+                    result++;
                     break;
 
                 case HLSC_WORST_HST_STATE:
-                    if (hst_state_is_worse(hst->current_state, result))
+                    if (hst_state_is_worse(hst->current_state, result)) {
                         result = hst->current_state;
+                    }
                     break;
             }
         }
@@ -100,4 +114,3 @@ int32_t HostlistStateColumn::getValue(void *data, Query *query)
     }
     return result;
 }
-
