@@ -22,50 +22,50 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-#include <math.h>
 #include "IntAggregator.h"
-#include "StatsColumn.h"
+#include <math.h>
 #include "IntColumn.h"
 #include "Query.h"
+#include "StatsColumn.h"
 
-void IntAggregator::consume(void *data, Query *query)
-{
+void IntAggregator::consume(void *data, Query *query) {
     _count++;
     int32_t value = _column->getValue(data, query);
     switch (_operation) {
         case STATS_OP_SUM:
         case STATS_OP_AVG:
-            _aggr += value; break;
+            _aggr += value;
+            break;
 
         case STATS_OP_SUMINV:
         case STATS_OP_AVGINV:
-            _sumq += 1.0 / (double)value;
+            _sumq += 1.0 / static_cast<double>(value);
             break;
 
         case STATS_OP_MIN:
-            if (_count == 1)
+            if (_count == 1) {
                 _aggr = value;
-            else if (value < _aggr)
+            } else if (value < _aggr) {
                 _aggr = value;
+            }
             break;
 
         case STATS_OP_MAX:
-            if (_count == 1)
+            if (_count == 1) {
                 _aggr = value;
-            else if (value > _aggr)
+            } else if (value > _aggr) {
                 _aggr = value;
+            }
             break;
 
         case STATS_OP_STD:
             _aggr += value;
-            _sumq += (double)value * (double)value;
+            _sumq += static_cast<double>(value) * static_cast<double>(value);
             break;
     }
 }
 
-
-void IntAggregator::output(Query *q)
-{
+void IntAggregator::output(Query *q) {
     switch (_operation) {
         case STATS_OP_SUM:
         case STATS_OP_MIN:
@@ -86,10 +86,15 @@ void IntAggregator::output(Query *q)
             break;
 
         case STATS_OP_STD:
-            if (_count <= 1)
+            if (_count <= 1) {
                 q->outputDouble(0.0);
-            else
-                q->outputDouble(sqrt((_sumq - ((double)_aggr * (double)_aggr) / _count)/(_count - 1)));
+            } else {
+                q->outputDouble(sqrt(
+                    (_sumq -
+                     (static_cast<double>(_aggr) * static_cast<double>(_aggr)) /
+                         _count) /
+                    (_count - 1)));
+            }
             break;
     }
 }
@@ -108,4 +113,3 @@ void IntAggregator::output(Query *q)
    return ((sumq - sum*sum/n)/(n-1)) ** 0.5
 
  */
-
