@@ -23,22 +23,21 @@
 // Boston, MA 02110-1301 USA.
 
 #include "IntColumn.h"
+#include <stdio.h>
 #include "IntColumnFilter.h"
 #include "Query.h"
 
-void IntColumn::output(void *data, Query *query)
-{
+using std::string;
+
+void IntColumn::output(void *data, Query *query) {
     query->outputInteger(getValue(data, query));
 }
 
-Filter *IntColumn::createFilter(int operator_id, char *value)
-{
+Filter *IntColumn::createFilter(int operator_id, char *value) {
     return new IntColumnFilter(this, operator_id, value);
 }
 
-
-string IntColumn::valueAsString(void *data, Query *query)
-{
+string IntColumn::valueAsString(void *data, Query *query) {
     char i[16];
     snprintf(i, sizeof(i), "%d", getValue(data, query));
     return i;
