@@ -22,26 +22,22 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-#include <stdlib.h>
+#include "ListColumnFilter.h"
 #include <string.h>
+#include "ListColumn.h"
 #include "logger.h"
 #include "opids.h"
-#include "ListColumnFilter.h"
-#include "ListColumn.h"
 
 ListColumnFilter::ListColumnFilter(ListColumn *column, int opid, char *value)
-    : _column(column)
-    , _opid(opid)
-    , _empty_ref(!value[0])
-{
+    : _column(column), _opid(opid), _empty_ref(value[0] == 0) {
     _ref_member = _column->getNagiosObject(value);
 }
 
-bool ListColumnFilter::accepts(void *data)
-{
+bool ListColumnFilter::accepts(void *data) {
     data = _column->shiftPointer(data);
-    if (!data)
+    if (data == nullptr) {
         return false;
+    }
     bool is_member = _column->isNagiosMember(data, _ref_member);
     switch (_opid) {
         case -OP_LESS: /* !< means >= means 'contains' */
@@ -50,21 +46,23 @@ bool ListColumnFilter::accepts(void *data)
             return !is_member;
         case OP_EQUAL:
         case -OP_EQUAL:
-            if (_empty_ref)
+            if (_empty_ref) {
                 return _column->isEmpty(data) == (_opid == OP_EQUAL);
-            logger(LG_INFO, "Sorry, equality for lists implemented only for emptyness");
+            }
+            logger(LG_INFO,
+                   "Sorry, equality for lists implemented only for emptyness");
             return false;
 
         default:
-            logger(LG_INFO, "Sorry, Operator %s for lists not implemented.", op_names_plus_8[_opid]);
+            logger(LG_INFO, "Sorry, Operator %s for lists not implemented.",
+                   op_names_plus_8[_opid]);
             return true;
     }
 }
 
-void *ListColumnFilter::indexFilter(const char *columnname)
-{
-    if (_opid == -OP_LESS && !strcmp(columnname, _column->name()))
+void *ListColumnFilter::indexFilter(const char *columnname) {
+    if (_opid == -OP_LESS && (strcmp(columnname, _column->name()) == 0)) {
         return _ref_member;
-    else
-        return 0;
+    }
+    return nullptr;
 }
