@@ -25,17 +25,15 @@
 #ifndef ListColumnFilter_h
 #define ListColumnFilter_h
 
-#include "config.h"
-
+#include "config.h"  // IWYU pragma: keep
 #include "Filter.h"
 class ListColumn;
 
-class ListColumnFilter : public Filter
-{
+class ListColumnFilter : public Filter {
     ListColumn *_column;
     void *_ref_member;
     int _opid;
-    bool _empty_ref; // distinct from unknown ref
+    bool _empty_ref;  // distinct from unknown ref
 
 public:
     ListColumnFilter(ListColumn *column, int opid, char *value);
@@ -43,6 +41,4 @@ public:
     void *indexFilter(const char *columnname);
 };
 
-
-#endif // ListColumnFilter_h
-
+#endif  // ListColumnFilter_h
