@@ -22,18 +22,18 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-#include "nagios.h"
 #include "OffsetDoubleColumn.h"
+#include <string.h>
 
-double OffsetDoubleColumn::getValue(void *data)
-{
-    if (!data)
+double OffsetDoubleColumn::getValue(void *data) {
+    if (data == nullptr) {
         return 0;
-
-    char *p = (char *)shiftPointer(data);
-    if (p)
-        return *(double *)(p + _offset);
-    else
+    }
+    char *p = static_cast<char *>(shiftPointer(data));
+    if (p == nullptr) {
         return 0;
+    }
+    double d;
+    memcpy(&d, p + _offset, sizeof(d));
+    return d;
 }
-
