@@ -22,19 +22,16 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-#include "nagios.h"
-#include <stdint.h>
 #include "OffsetIntColumn.h"
 
-int32_t OffsetIntColumn::getValue(void *data, Query *)
-{
-    if (!data)
+int32_t OffsetIntColumn::getValue(void *data, Query * /*unused*/) {
+    if (data == nullptr) {
         return 0;
+    }
 
-    char *p = (char *)shiftPointer(data);
-    if (p)
-        return *(int *)(p + _offset);
-    else
-        return 0;
+    char *p = reinterpret_cast<char *>(shiftPointer(data));
+    if (p != nullptr) {
+        return *reinterpret_cast<int *>(p + _offset);
+    }
+    return 0;
 }
-
