@@ -23,22 +23,12 @@
 // Boston, MA 02110-1301 USA.
 
 #include "OffsetStringColumn.h"
-#include "logger.h"
 
-char *OffsetStringColumn::getValue(void *data)
-{
-    if (!data)
-        return (char *)"";
-
-    char *p = (char *)shiftPointer(data);
-    if (p) {
-        const char *s = *(char **)(p + _offset);
-        if (s)
-            return (char *)s;
-        else
-            return (char *)"";
+const char *OffsetStringColumn::getValue(void *data) {
+    char *p = reinterpret_cast<char *>(shiftPointer(data));
+    if (p == nullptr) {
+        return "";
     }
-    else
-        return (char *)"";
+    const char *s = *reinterpret_cast<char **>(p + _offset);
+    return s == nullptr ? "" : s;
 }
-
