@@ -23,129 +23,144 @@
 // Boston, MA 02110-1301 USA.
 
 #include "OffsetStringMacroColumn.h"
+#include <stdlib.h>
+#include <string.h>
 #include "AndingFilter.h"
 #include "Query.h"
 #include "logger.h"
-#include "nagios.h"
-#ifndef NAGIOS4
-#include "nagios/macros.h"
-#endif
-extern char     *macro_user[MAX_USER_MACROS];
+class Filter;
 
-string OffsetStringMacroColumn::valueAsString(void *data, Query *)
-{
-    char *raw = getValue(data);
+using std::string;
+
+extern char *macro_user[MAX_USER_MACROS];
+
+string OffsetStringMacroColumn::valueAsString(void *data, Query * /*unused*/) {
+    const char *raw = getValue(data);
     host *hst = getHost(data);
     service *svc = getService(data);
 
     // search for macro names, beginning with $
     string result = "";
-    char *scan = raw;
+    const char *scan = raw;
 
-    while (*scan) {
-        char *dollar = strchr(scan, '$');
-        if (!dollar) {
+    while (*scan != 0) {
+        const char *dollar = strchr(scan, '$');
+        if (dollar == nullptr) {
             result += scan;
             break;
         }
         result += string(scan, dollar - scan);
-        char *otherdollar = strchr(dollar + 1, '$');
-        if (!otherdollar) { // unterminated macro, do not expand
+        const char *otherdollar = strchr(dollar + 1, '$');
+        if (otherdollar == nullptr) {  // unterminated macro, do not expand
             result += scan;
             break;
         }
         string macroname = string(dollar + 1, otherdollar - dollar - 1);
         const char *replacement = expandMacro(macroname.c_str(), hst, svc);
-        if (replacement)
+        if (replacement != nullptr) {
             result += replacement;
-        else
-            result += string(dollar, otherdollar - dollar + 1); // leave macro unexpanded
+        } else {
+            result += string(
+                dollar, otherdollar - dollar + 1);  // leave macro unexpanded
+        }
         scan = otherdollar + 1;
     }
     return result;
 }
 
-
-void OffsetStringMacroColumn::output(void *data, Query *query)
-{
+void OffsetStringMacroColumn::output(void *data, Query *query) {
     string s = valueAsString(data, query);
     query->outputString(s.c_str());
 }
 
-Filter *OffsetStringMacroColumn::createFilter(int opid __attribute__ ((__unused__)), char *value __attribute__ ((__unused__)))
-{
+Filter *OffsetStringMacroColumn::createFilter(int /*operator_id*/,
+                                              char * /*value*/) {
     logger(LG_INFO, "Sorry. No filtering on macro columns implemented yet");
-    return new AndingFilter(); // always true
+    return new AndingFilter();  // always true
 }
 
-const char *OffsetStringMacroColumn::expandMacro(const char *macroname, host *hst, service *svc)
-{
+const char *OffsetStringMacroColumn::expandMacro(const char *macroname,
+                                                 host *hst, service *svc) {
     // host macros
-    if (!strcmp(macroname, "HOSTNAME"))
+    if (strcmp(macroname, "HOSTNAME") == 0) {
         return hst->name;
-    else if (!strcmp(macroname, "HOSTDISPLAYNAME"))
+    }
+    if (strcmp(macroname, "HOSTDISPLAYNAME") == 0) {
         return hst->display_name;
-    else if (!strcmp(macroname, "HOSTALIAS"))
+    }
+    if (strcmp(macroname, "HOSTALIAS") == 0) {
         return hst->alias;
-    else if (!strcmp(macroname, "HOSTADDRESS"))
+    }
+    if (strcmp(macroname, "HOSTADDRESS") == 0) {
         return hst->address;
-    else if (!strcmp(macroname, "HOSTOUTPUT"))
+    }
+    if (strcmp(macroname, "HOSTOUTPUT") == 0) {
         return hst->plugin_output;
-    else if (!strcmp(macroname, "LONGHOSTOUTPUT"))
+    }
+    if (strcmp(macroname, "LONGHOSTOUTPUT") == 0) {
         return hst->long_plugin_output;
-    else if (!strcmp(macroname, "HOSTPERFDATA"))
+    }
+    if (strcmp(macroname, "HOSTPERFDATA") == 0) {
         return hst->perf_data;
-    else if (!strcmp(macroname, "HOSTCHECKCOMMAND"))
-    #ifndef NAGIOS4
+    }
+    if (strcmp(macroname, "HOSTCHECKCOMMAND") == 0) {
+#ifndef NAGIOS4
         return hst->host_check_command;
-    #else
+#else
         return hst->check_command;
-    #endif // NAGIOS4
-
-    else if (!strncmp(macroname, "_HOST", 5)) // custom macro
+#endif  // NAGIOS4
+    }
+    if (strncmp(macroname, "_HOST", 5) == 0) {  // custom macro
         return expandCustomVariables(macroname + 5, hst->custom_variables);
 
-    // service macros
-    else if (svc) {
-        if (!strcmp(macroname, "SERVICEDESC"))
+        // service macros
+    }
+    if (svc != nullptr) {
+        if (strcmp(macroname, "SERVICEDESC") == 0) {
             return svc->description;
-        else if (!strcmp(macroname, "SERVICEDISPLAYNAME"))
+        }
+        if (strcmp(macroname, "SERVICEDISPLAYNAME") == 0) {
             return svc->display_name;
-        else if (!strcmp(macroname, "SERVICEOUTPUT"))
+        }
+        if (strcmp(macroname, "SERVICEOUTPUT") == 0) {
             return svc->plugin_output;
-        else if (!strcmp(macroname, "LONGSERVICEOUTPUT"))
+        }
+        if (strcmp(macroname, "LONGSERVICEOUTPUT") == 0) {
             return svc->long_plugin_output;
-        else if (!strcmp(macroname, "SERVICEPERFDATA"))
+        }
+        if (strcmp(macroname, "SERVICEPERFDATA") == 0) {
             return svc->perf_data;
-        else if (!strcmp(macroname, "SERVICECHECKCOMMAND"))
-        #ifndef NAGIOS4
+        }
+        if (strcmp(macroname, "SERVICECHECKCOMMAND") == 0) {
+#ifndef NAGIOS4
             return svc->service_check_command;
-        #else
+#else
             return svc->check_command;
-        #endif // NAGIOS4
-        else if (!strncmp(macroname, "_SERVICE", 8)) // custom macro
+#endif  // NAGIOS4
+        }
+        if (strncmp(macroname, "_SERVICE", 8) == 0) {  // custom macro
             return expandCustomVariables(macroname + 8, svc->custom_variables);
+        }
     }
 
     // USER macros
-    if (!strncmp(macroname, "USER", 4)) {
+    if (strncmp(macroname, "USER", 4) == 0) {
         int n = atoi(macroname + 4);
         if (n > 0 && n <= MAX_USER_MACROS) {
             return macro_user[n - 1];
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
-
-const char *OffsetStringMacroColumn::expandCustomVariables(const char *varname, customvariablesmember *custvars)
-{
-    while (custvars)
-    {
-        if (!strcasecmp(varname, custvars->variable_name))
+const char *OffsetStringMacroColumn::expandCustomVariables(
+    const char *varname, customvariablesmember *custvars) {
+    while (custvars != nullptr) {
+        if (strcasecmp(varname, custvars->variable_name) == 0) {
             return custvars->variable_value;
+        }
         custvars = custvars->next;
     }
-    return 0;
+    return nullptr;
 }
