@@ -23,21 +23,15 @@
 // Boston, MA 02110-1301 USA.
 
 #include "OffsetStringServiceMacroColumn.h"
-#include "nagios.h"
 
-host *OffsetStringServiceMacroColumn::getHost(void *data)
-{
+host *OffsetStringServiceMacroColumn::getHost(void *data) {
     service *svc = getService(data);
-    if (svc)
+    if (svc != nullptr) {
         return svc->host_ptr;
-    else
-        return 0;
+    }
+    return nullptr;
 }
 
-service *OffsetStringServiceMacroColumn::getService(void *data)
-{
-    data = shiftPointer(data);
-    return (service *)data;
+service *OffsetStringServiceMacroColumn::getService(void *data) {
+    return static_cast<service *>(shiftPointer(data));
 }
-
-
