@@ -25,17 +25,20 @@
 #ifndef OffsetStringServiceMacroColumn_h
 #define OffsetStringServiceMacroColumn_h
 
-#include "nagios.h"
+#include "config.h"  // IWYU pragma: keep
+#include <string>
 #include "OffsetStringMacroColumn.h"
+#include "nagios.h"  // IWYU pragma: keep
 
-class OffsetStringServiceMacroColumn : public OffsetStringMacroColumn
-{
+class OffsetStringServiceMacroColumn : public OffsetStringMacroColumn {
 public:
-    OffsetStringServiceMacroColumn(string name, string description, int offset, int indirect_offset = -1) :
-        OffsetStringMacroColumn(name, description, offset, indirect_offset) {}
-    host *getHost(void *data);
-    service *getService(void *data);
+    OffsetStringServiceMacroColumn(std::string name, std::string description,
+                                   int offset, int indirect_offset,
+                                   int extra_offset = -1)
+        : OffsetStringMacroColumn(name, description, offset, indirect_offset,
+                                  extra_offset) {}
+    host *getHost(void *data) override;
+    service *getService(void *data) override;
 };
 
-#endif // OffsetStringServiceMacroColumn_h
-
+#endif  // OffsetStringServiceMacroColumn_h
