@@ -23,16 +23,14 @@
 // Boston, MA 02110-1301 USA.
 
 #include "OffsetTimeColumn.h"
-#include "TimeColumnFilter.h"
 #include "Query.h"
+#include "TimeColumnFilter.h"
 
-void OffsetTimeColumn::output(void *data, Query *query)
-{
+void OffsetTimeColumn::output(void *data, Query *query) {
     query->outputTime(getValue(data, query));
 }
 
-Filter *OffsetTimeColumn::createFilter(int operator_id, char *value)
-{
+Filter *OffsetTimeColumn::createFilter(int operator_id, char *value) {
     // The TimeColumnFilter applies the timezone offset
     // from the Localtime: header
     return new TimeColumnFilter(this, operator_id, value);
