@@ -22,40 +22,39 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-
-#include "nagios.h"
-#include <stdint.h>
 #include "OffsetTimeperiodColumn.h"
-#include "logger.h"
 #include "TimeperiodsCache.h"
+#include "nagios.h"
+
+using std::string;
 
 extern TimeperiodsCache *g_timeperiods_cache;
 
+OffsetTimeperiodColumn::OffsetTimeperiodColumn(string name, string description,
+                                               int offset, int indirect_offset,
+                                               int extra_offset)
+    : OffsetIntColumn(name, description, offset, indirect_offset,
+                      extra_offset) {}
 
-OffsetTimeperiodColumn::OffsetTimeperiodColumn(string name, string description, int offset, int indirect_offset)
-    : OffsetIntColumn(name, description, offset, indirect_offset)
-{
-}
-
-
-int32_t OffsetTimeperiodColumn::getValue(void *data, Query *)
-{
+int32_t OffsetTimeperiodColumn::getValue(void *data, Query * /*unused*/) {
     data = shiftPointer(data);
-    if (!data)
+    if (data == nullptr) {
         return 0;
+    }
 
     timeperiod *tp;
-    if (offset() == -1)
-        tp = (timeperiod *)data;
-    else
-        tp = *(timeperiod **)((char *)data + offset());
+    if (offset() == -1) {
+        tp = reinterpret_cast<timeperiod *>(data);
+    } else {
+        tp = *reinterpret_cast<timeperiod **>(reinterpret_cast<char *>(data) +
+                                              offset());
+    }
 
-
-    if (!tp)
-        return 1; // no timeperiod set -> Nagios assumes 7x24
-    else if (g_timeperiods_cache->inTimeperiod(tp))
+    if (tp == nullptr) {
+        return 1;  // no timeperiod set -> Nagios assumes 7x24
+    }
+    if (g_timeperiods_cache->inTimeperiod(tp)) {
         return 1;
-    else
-        return 0;
+    }
+    return 0;
 }
-
