@@ -23,33 +23,32 @@
 // Boston, MA 02110-1301 USA.
 
 #include "OutputBuffer.h"
+#include <errno.h>
+#include <stdarg.h>
+#include <stdint.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/select.h>
+#include <sys/time.h>
 #include <unistd.h>
-#include <stdarg.h>
-#include <errno.h>
-
-#include "logger.h"
+#include <cinttypes>
 #include "Query.h"
+#include "logger.h"
+
+using std::string;
 
 #define WRITE_TIMEOUT_USEC 100000
 
-
-OutputBuffer::OutputBuffer()
-  : _max_size(INITIAL_OUTPUT_BUFFER_SIZE)
-{
-    _buffer = (char *)malloc(_max_size);
+OutputBuffer::OutputBuffer() : _max_size(INITIAL_OUTPUT_BUFFER_SIZE) {
+    _buffer = static_cast<char *>(malloc(_max_size));
     _end = _buffer + _max_size;
     reset();
 }
 
-OutputBuffer::~OutputBuffer()
-{
-    free(_buffer);
-}
+OutputBuffer::~OutputBuffer() { free(_buffer); }
 
-void OutputBuffer::reset()
-{
+void OutputBuffer::reset() {
     _writepos = _buffer;
     _response_header = RESPONSE_HEADER_OFF;
     _response_code = RESPONSE_CODE_OK;
@@ -57,109 +56,104 @@ void OutputBuffer::reset()
     _error_message = "";
 }
 
-void OutputBuffer::addChar(char c)
-{
+void OutputBuffer::addChar(char c) {
     needSpace(1);
     *_writepos++ = c;
 }
 
-void OutputBuffer::addString(const char *s)
-{
+void OutputBuffer::addString(const char *s) {
     int l = strlen(s);
     addBuffer(s, l);
 }
 
-void OutputBuffer::addBuffer(const char *buf, unsigned len)
-{
+void OutputBuffer::addBuffer(const char *buf, unsigned len) {
     needSpace(len);
     memcpy(_writepos, buf, len);
     _writepos += len;
 }
 
-void OutputBuffer::needSpace(unsigned len)
-{
-    if (_writepos + len > _end)
-    {
+// TODO(sp): All this code is highly error-prone due to overflow, failed
+// allocations
+// etc. We should just use vector instead.
+void OutputBuffer::needSpace(unsigned len) {
+    if (_writepos + len > _end) {
         unsigned s = size();
         unsigned needed = s + len;
-        while (_max_size < needed) // double, until enough space
+        while (_max_size < needed) {  // double, until enough space
             _max_size *= 2;
+        }
 
-        _buffer = (char *)realloc(_buffer, _max_size);
+        char *new_buffer = static_cast<char *>(realloc(_buffer, _max_size));
+        // It's better to crash voluntarily than overwriting random memory
+        // later.
+        if (new_buffer == nullptr) {
+            abort();
+        }
+
+        _buffer = new_buffer;
         _writepos = _buffer + s;
         _end = _buffer + _max_size;
     }
 }
 
-void OutputBuffer::flush(int fd, int *termination_flag)
-{
-    if (_response_header == RESPONSE_HEADER_FIXED16)
-    {
+void OutputBuffer::flush(int fd, int *termination_flag) {
+    if (_response_header == RESPONSE_HEADER_FIXED16) {
         const char *buffer = _buffer;
         int s = size();
 
         // if response code is not OK, output error
         // message instead of data
-        if (_response_code != RESPONSE_CODE_OK)
-        {
+        if (_response_code != RESPONSE_CODE_OK) {
             buffer = _error_message.c_str();
             s = _error_message.size();
         }
 
         char header[17];
-        snprintf(header, sizeof(header), "%03d %11d\n", _response_code, s);
+        snprintf(header, sizeof(header), "%03u %11d\n", _response_code, s);
         writeData(fd, termination_flag, header, 16);
         writeData(fd, termination_flag, buffer, s);
-    }
-    else {
+    } else {
         writeData(fd, termination_flag, _buffer, size());
     }
     reset();
 }
 
-
-void OutputBuffer::writeData(int fd, int *termination_flag, const char *write_from, int to_write)
-{
-    struct timeval tv;
-    while (!*termination_flag && to_write > 0)
-    {
-        tv.tv_sec  = WRITE_TIMEOUT_USEC / 1000000;
+void OutputBuffer::writeData(int fd, int *termination_flag, const char *buffer,
+                             size_t bytes_to_write) {
+    while ((*termination_flag == 0) && bytes_to_write > 0) {
+        struct timeval tv;
+        tv.tv_sec = WRITE_TIMEOUT_USEC / 1000000;
         tv.tv_usec = WRITE_TIMEOUT_USEC % 1000000;
 
         fd_set fds;
         FD_ZERO(&fds);
         FD_SET(fd, &fds);
 
-        int retval = select(fd + 1, NULL, &fds, NULL, &tv);
+        int retval = select(fd + 1, nullptr, &fds, nullptr, &tv);
         if (retval > 0 && FD_ISSET(fd, &fds)) {
-            ssize_t w = write(fd, write_from, to_write);
-            if (w < 0) {
-                logger(LG_INFO, "Couldn't write %d bytes to client socket: %s", to_write, strerror(errno));
+            ssize_t bytes_written = write(fd, buffer, bytes_to_write);
+            if (bytes_written == -1) {
+                logger(LG_INFO,
+                       "Couldn't write %" PRIdMAX " bytes to client socket: %s",
+                       static_cast<intmax_t>(bytes_to_write), strerror(errno));
                 break;
             }
-            else if (w == 0)
-                logger(LG_INFO, "Strange: wrote 0 bytes inspite of positive select()");
-            else {
-                to_write -= w;
-            }
+            buffer += bytes_written;
+            bytes_to_write -= bytes_written;
         }
     }
 }
 
-void OutputBuffer::setError(unsigned code, const char *format, ...)
-{
+void OutputBuffer::setError(unsigned code, const char *format, ...) {
     // only the first error is being returned
-    if (_error_message == "")
-    {
+    if (_error_message == "") {
         char buffer[8192];
         va_list ap;
         va_start(ap, format);
         vsnprintf(buffer, sizeof(buffer) - 1, format, ap);
         logger(LG_INFO, "error: %s", buffer);
-        strcat(buffer, "\n");
         va_end(ap);
-        _error_message = buffer;
+        _error_message = string(buffer) + "\n";
         _response_code = code;
     }
 }
-
