@@ -23,31 +23,32 @@
 // Boston, MA 02110-1301 USA.
 
 #include "ServicegroupsColumn.h"
-#include "nagios.h"
 #include "Query.h"
 
-objectlist *ServicegroupsColumn::getData(void *data)
-{
-    if (data) {
+objectlist *ServicegroupsColumn::getData(void *data) {
+    if (data != nullptr) {
         data = shiftPointer(data);
-        if (data)
-            return *(objectlist **)((char *)data + _offset);
+        if (data != nullptr) {
+            return *reinterpret_cast<objectlist **>(
+                reinterpret_cast<char *>(data) + _offset);
+        }
     }
-    return 0;
+    return nullptr;
 }
 
-void ServicegroupsColumn::output(void *data, Query *query)
-{
+void ServicegroupsColumn::output(void *data, Query *query) {
     query->outputBeginList();
     objectlist *list = getData(data);
-    if (list) {
+    if (list != nullptr) {
         bool first = true;
-        while (list) {
-            servicegroup *sg = (servicegroup *)list->object_ptr;
-            if (!first)
+        while (list != nullptr) {
+            servicegroup *sg =
+                reinterpret_cast<servicegroup *>(list->object_ptr);
+            if (!first) {
                 query->outputListSeparator();
-            else
+            } else {
                 first = false;
+            }
             query->outputString(sg->group_name);
             list = list->next;
         }
@@ -55,25 +56,25 @@ void ServicegroupsColumn::output(void *data, Query *query)
     query->outputEndList();
 }
 
-void *ServicegroupsColumn::getNagiosObject(char *name)
-{
+void *ServicegroupsColumn::getNagiosObject(char *name) {
     return find_servicegroup(name);
 }
 
-bool ServicegroupsColumn::isNagiosMember(void *data, void *nagobject)
-{
+bool ServicegroupsColumn::isNagiosMember(void *data, void *nagobject) {
     // data is already shifted
-    objectlist *list = *(objectlist **)((char *)data + _offset);
-    while (list) {
-        if (list->object_ptr == nagobject)
+    objectlist *list = *reinterpret_cast<objectlist **>(
+        reinterpret_cast<char *>(data) + _offset);
+    while (list != nullptr) {
+        if (list->object_ptr == nagobject) {
             return true;
+        }
         list = list->next;
     }
     return false;
 }
 
-bool ServicegroupsColumn::isEmpty(void *data)
-{
-    objectlist *list = *(objectlist **)((char *)data + _offset);
-    return list == 0;
+bool ServicegroupsColumn::isEmpty(void *data) {
+    objectlist *list = *reinterpret_cast<objectlist **>(
+        reinterpret_cast<char *>(data) + _offset);
+    return list == nullptr;
 }
