@@ -23,40 +23,44 @@
 // Boston, MA 02110-1301 USA.
 
 #include "ServicelistColumn.h"
-#include "ServicelistColumnFilter.h"
-#include "nagios.h"
+#include <string.h>
 #include "Query.h"
+#include "ServicelistColumnFilter.h"
 #include "TableServices.h"
+#include "TimeperiodsCache.h"
 
+extern TimeperiodsCache *g_timeperiods_cache;
 extern TableServices *g_table_services;
 
-servicesmember *ServicelistColumn::getMembers(void *data)
-{
+servicesmember *ServicelistColumn::getMembers(void *data) {
     data = shiftPointer(data);
-    if (!data) return 0;
+    if (data == nullptr) {
+        return nullptr;
+    }
 
-    return *(servicesmember **)((char *)data + _offset);
+    return *reinterpret_cast<servicesmember **>(reinterpret_cast<char *>(data) +
+                                                _offset);
 }
 
-void ServicelistColumn::output(void *data, Query *query)
-{
+void ServicelistColumn::output(void *data, Query *query) {
     query->outputBeginList();
     contact *auth_user = query->authUser();
     servicesmember *mem = getMembers(data);
 
     bool first = true;
-    while (mem) {
+    while (mem != nullptr) {
         service *svc = mem->service_ptr;
-        if (!auth_user || g_table_services->isAuthorized(auth_user, svc)) {
-            if (!first)
+        if ((auth_user == nullptr) ||
+            g_table_services->isAuthorized(auth_user, svc)) {
+            if (!first) {
                 query->outputListSeparator();
-            else
+            } else {
                 first = false;
+            }
             // show only service name => no sublist
-            if (!_show_host && _info_depth == 0)
+            if (!_show_host && _info_depth == 0) {
                 query->outputString(svc->description);
-            else
-            {
+            } else {
                 query->outputBeginSublist();
                 if (_show_host) {
                     query->outputString(svc->host_name);
@@ -84,6 +88,9 @@ void ServicelistColumn::output(void *data, Query *query)
                     query->outputInteger(svc->scheduled_downtime_depth);
                     query->outputSublistSeparator();
                     query->outputInteger(svc->problem_has_been_acknowledged);
+                    query->outputSublistSeparator();
+                    query->outputInteger(
+                        inCustomTimeperiod(svc, "SERVICE_PERIOD"));
                 }
                 query->outputEndSublist();
             }
@@ -93,8 +100,18 @@ void ServicelistColumn::output(void *data, Query *query)
     query->outputEndList();
 }
 
-Filter *ServicelistColumn::createFilter(int opid, char *value)
-{
+Filter *ServicelistColumn::createFilter(int opid, char *value) {
     return new ServicelistColumnFilter(this, opid, value);
 }
 
+int ServicelistColumn::inCustomTimeperiod(service *svc, const char *varname) {
+    customvariablesmember *cvm = svc->custom_variables;
+    while (cvm != nullptr) {
+        if ((strcmp(cvm->variable_name, varname)) == 0) {
+            return static_cast<int>(
+                g_timeperiods_cache->inTimeperiod(cvm->variable_value));
+        }
+        cvm = cvm->next;
+    }
+    return 1;  // assume 7X24
+}
