@@ -25,26 +25,21 @@
 #ifndef ServicelistColumnFilter_h
 #define ServicelistColumnFilter_h
 
-#include "config.h"
-
-#include "Filter.h"
+#include "config.h"  // IWYU pragma: keep
 #include <string>
-using namespace std;
-
+#include "Filter.h"
 class ServicelistColumn;
 
-class ServicelistColumnFilter : public Filter
-{
+class ServicelistColumnFilter : public Filter {
     ServicelistColumn *_servicelist_column;
     int _opid;
-    string _ref_host;
-    string _ref_service;
+    std::string _ref_host;
+    std::string _ref_service;
 
 public:
-    ServicelistColumnFilter(ServicelistColumn *column, int opid, char *refvalue);
+    ServicelistColumnFilter(ServicelistColumn *column, int opid,
+                            char *refvalue);
     bool accepts(void *data);
 };
 
-
-#endif // ServicelistColumnFilter_h
-
+#endif  // ServicelistColumnFilter_h
