@@ -25,67 +25,68 @@
 #ifndef Store_h
 #define Store_h
 
-#include "config.h"
-
-#include "TableServices.h"
-#include "TableHosts.h"
-#include "TableHostgroups.h"
-#include "TableServicegroups.h"
-#include "TableContacts.h"
-#include "TableCommands.h"
-#include "TableTimeperiods.h"
-#include "TableContactgroups.h"
-#include "TableDownComm.h"
-#include "TableStatus.h"
-#include "TableLog.h"
-#include "TableStateHistory.h"
-#include "TableColumns.h"
-#include "OutputBuffer.h"
-#include "InputBuffer.h"
+#include "config.h"  // IWYU pragma: keep
+#include <list>
+#include <map>
+#include <string>
 #include "LogCache.h"
+#include "TableColumns.h"
+#include "TableCommands.h"
+#include "TableContactgroups.h"
+#include "TableContacts.h"
+#include "TableDownComm.h"
+#include "TableHostgroups.h"
+#include "TableHosts.h"
+#include "TableLog.h"
+#include "TableServicegroups.h"
+#include "TableServices.h"
+#include "TableStateHistory.h"
+#include "TableStatus.h"
+#include "TableTimeperiods.h"
+#include "mk/Mutex.h"
+#include "nagios.h"
+class InputBuffer;
+class OutputBuffer;
+class Table;
 
-class Store
-{
-    LogCache           _log_cache;
-    TableContacts      _table_contacts;
-    TableCommands      _table_commands;
-    TableHostgroups    _table_hostgroups;
-    TableHosts         _table_hosts;
-    TableHosts         _table_hostsbygroup;
+class Store {
+    LogCache _log_cache;
+    TableContacts _table_contacts;
+    TableCommands _table_commands;
+    TableHostgroups _table_hostgroups;
+    TableHosts _table_hosts;
+    TableHosts _table_hostsbygroup;
     TableServicegroups _table_servicegroups;
-    TableServices      _table_services;
-    TableServices      _table_servicesbygroup;
-    TableServices      _table_servicesbyhostgroup;
-    TableTimeperiods   _table_timeperiods;
+    TableServices _table_services;
+    TableServices _table_servicesbygroup;
+    TableServices _table_servicesbyhostgroup;
+    TableTimeperiods _table_timeperiods;
     TableContactgroups _table_contactgroups;
-    TableDownComm      _table_downtimes;
-    TableDownComm      _table_comments;
-    TableStatus        _table_status;
-    TableLog           _table_log;
-    TableStateHistory  _table_statehistory;
-    TableColumns       _table_columns;
+    TableDownComm _table_downtimes;
+    TableDownComm _table_comments;
+    TableStatus _table_status;
+    TableLog _table_log;
+    TableStateHistory _table_statehistory;
+    TableColumns _table_columns;
 
-    typedef map<string, Table *> _tables_t;
+    typedef std::map<std::string, Table *> _tables_t;
     _tables_t _tables;
 
-    pthread_mutex_t    _command_mutex;
+    mk::mutex _command_mutex;
 
 public:
     Store();
     ~Store();
-    LogCache* logCache() { return &_log_cache; };
     void registerHostgroup(hostgroup *);
     void registerComment(nebstruct_comment_data *);
     void registerDowntime(nebstruct_downtime_data *);
     bool answerRequest(InputBuffer *, OutputBuffer *);
 
 private:
-    Table *findTable(string name);
-    void answerGetRequest(InputBuffer *, OutputBuffer *, const char *);
+    Table *findTable(std::string name);
+    void answerGetRequest(const std::list<std::string> &lines, OutputBuffer *,
+                          const char *);
     void answerCommandRequest(const char *);
 };
 
-
-#endif // Store_h
-
-
+#endif  // Store_h
