@@ -23,20 +23,17 @@
 // Boston, MA 02110-1301 USA.
 
 #include "StringColumn.h"
-#include "StringColumnFilter.h"
 #include "Query.h"
+#include "StringColumnFilter.h"
 
-void StringColumn::output(void *data, Query *query)
-{
-    if (data)
+void StringColumn::output(void *data, Query *query) {
+    if (data != nullptr) {
         query->outputString(getValue(data));
-    else
-        query->outputString(0);
+    } else {
+        query->outputString(nullptr);
+    }
 }
 
-Filter *StringColumn::createFilter(int operator_id, char *value)
-{
+Filter *StringColumn::createFilter(int operator_id, char *value) {
     return new StringColumnFilter(this, operator_id, value);
 }
-
-
