@@ -22,77 +22,88 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-#include <stdlib.h>
-#include <strings.h>
-#include <string.h>
-
 #include "StringColumnFilter.h"
-#include "StringColumn.h"
-#include "opids.h"
-#include "logger.h"
+#include <stdlib.h>
+#include <string.h>
 #include "OutputBuffer.h"
+#include "StringColumn.h"
+#include "logger.h"
+#include "opids.h"
 
-StringColumnFilter::StringColumnFilter(StringColumn *column, int opid, char *value)
+StringColumnFilter::StringColumnFilter(StringColumn *column, int opid,
+                                       char *value)
     : _column(column)
     , _ref_string(value)
     , _opid(abs(opid))
     , _negate(opid < 0)
-    , _regex(0)
-{
+    , _regex(nullptr) {
     if (_opid == OP_REGEX || _opid == OP_REGEX_ICASE) {
-        if (strchr(value, '{') || strchr(value, '}')) {
-            setError(RESPONSE_CODE_INVALID_HEADER, "disallowed regular expression '%s': must not contain { or }", value);
-        }
-        else {
+        if ((strchr(value, '{') != nullptr) ||
+            (strchr(value, '}') != nullptr)) {
+            setError(
+                RESPONSE_CODE_INVALID_HEADER,
+                "disallowed regular expression '%s': must not contain { or }",
+                value);
+        } else {
             _regex = new regex_t();
-            if (0 != regcomp(_regex, value, REG_EXTENDED | REG_NOSUB | (_opid == OP_REGEX_ICASE ? REG_ICASE : 0)))
-            {
-                setError(RESPONSE_CODE_INVALID_HEADER, "invalid regular expression '%s'", value);
+            if (0 != regcomp(_regex, value,
+                             REG_EXTENDED | REG_NOSUB |
+                                 (_opid == OP_REGEX_ICASE ? REG_ICASE : 0))) {
+                setError(RESPONSE_CODE_INVALID_HEADER,
+                         "invalid regular expression '%s'", value);
                 delete _regex;
-                _regex = 0;
+                _regex = nullptr;
             }
         }
     }
 }
 
-StringColumnFilter::~StringColumnFilter()
-{
-    if (_regex) {
+StringColumnFilter::~StringColumnFilter() {
+    if (_regex != nullptr) {
         regfree(_regex);
         delete _regex;
     }
 }
 
-
-bool StringColumnFilter::accepts(void *data)
-{
+bool StringColumnFilter::accepts(void *data) {
     bool pass = true;
-    char *act_string = _column->getValue(data);
+    const char *act_string = _column->getValue(data);
+    if (act_string == nullptr) {
+        act_string =
+            "";  // e.g. current_service_perf_data in host entry in log table
+    }
     switch (_opid) {
         case OP_EQUAL:
-            pass = _ref_string == act_string; break;
+            pass = _ref_string == act_string;
+            break;
         case OP_EQUAL_ICASE:
-            pass = !strcasecmp(_ref_string.c_str(), act_string); break;
+            pass = (strcasecmp(_ref_string.c_str(), act_string) == 0);
+            break;
         case OP_REGEX:
         case OP_REGEX_ICASE:
-            pass = _regex != 0 && 0 == regexec(_regex, act_string, 0, 0, 0);
+            pass = _regex != nullptr &&
+                   0 == regexec(_regex, act_string, 0, nullptr, 0);
             break;
         case OP_GREATER:
-            pass = 0 > strcmp(_ref_string.c_str(), act_string); break;
+            pass = 0 > strcmp(_ref_string.c_str(), act_string);
+            break;
         case OP_LESS:
-            pass = 0 < strcmp(_ref_string.c_str(), act_string); break;
+            pass = 0 < strcmp(_ref_string.c_str(), act_string);
+            break;
         default:
             // this should never be reached, all operators are handled
-            logger(LG_INFO, "Sorry. Operator %s for strings not implemented.", op_names_plus_8[_opid]);
+            logger(LG_INFO, "Sorry. Operator %s for strings not implemented.",
+                   op_names_plus_8[_opid]);
             break;
     }
     return pass != _negate;
 }
 
-void *StringColumnFilter::indexFilter(const char *column)
-{
-    if (_opid == OP_EQUAL && !strcmp(column, _column->name()))
-        return (void *)_ref_string.c_str();
-    else
-        return 0;
+void *StringColumnFilter::indexFilter(const char *column) {
+    if (_opid == OP_EQUAL && (strcmp(column, _column->name()) == 0)) {
+        // TODO(sp) The cast looks very dubious, but the whole void* story is
+        // quite dangerous...
+        return const_cast<char *>(_ref_string.c_str());
+    }
+    return nullptr;
 }
