@@ -22,65 +22,72 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-#include <string.h>
-
 #include "Table.h"
+#include <string.h>
+#include <utility>
 #include "Column.h"
+#include "DynamicColumn.h"
 #include "Query.h"
-#include "logger.h"
 
-void Table::addColumn(Column *col)
-{
+using std::make_pair;
+using std::string;
+
+void Table::addColumn(Column *col) {
     // do not insert column if one with that name
     // already exists. Delete that column in that
     // case. (For example needed for TableLog->TableHosts,
     // which both define host_name.
-    if (column(col->name())) {
+    if (column(col->name()) != nullptr) {
         delete col;
-    }
-    else {
+    } else {
         _columns.insert(make_pair(col->name(), col));
     }
 }
 
+void Table::addDynamicColumn(DynamicColumn *dyncol) {
+    _dynamic_columns.insert(make_pair(dyncol->name(), dyncol));
+}
 
+Table::~Table() {
+    for (auto &column : _columns) {
+        delete column.second;
+    }
 
-Table::~Table()
-{
-    for (_columns_t::iterator it = _columns.begin();
-            it != _columns.end();
-            ++it)
-    {
-        delete it->second;
+    for (auto &dynamic_column : _dynamic_columns) {
+        delete dynamic_column.second;
     }
 }
 
-
-void Table::addAllColumnsToQuery(Query *q)
-{
-    for (_columns_t::iterator it = _columns.begin();
-            it != _columns.end();
-            ++it)
-    {
-        q->addColumn(it->second);
+void Table::addAllColumnsToQuery(Query *q) {
+    for (auto &column : _columns) {
+        q->addColumn(column.second);
     }
 }
 
+Column *Table::column(const char *colname) {
+    // We allow the name of the table to be
+    // prefixed to the column name. So if we
+    // detect this prefix, we simply remove it.
+    int prefix_len = strlen(prefixname());  // replace 's' with '_'
+
+    // Multisite seems to query "service_service_description". We can fix this
+    // in newer versions, but need to be compatible. So we need a "while" here,
+    // not just an "if".
+    while ((strncmp(colname, prefixname(), prefix_len - 1) == 0) &&
+           colname[prefix_len - 1] == '_') {
+        colname += prefix_len;
+    }
+
+    // If the colum name contains a ':' then we have a dynamic
+    // column with column arguments
+    if (strchr(colname, ':') != nullptr) {
+        return dynamicColumn(colname);
+    }
 
-Column *Table::column(const char *colname)
-{
     // First try exact match
-    _columns_t::iterator it = _columns.find(string(colname));
-    if (it != _columns.end())
+    auto it = _columns.find(string(colname));
+    if (it != _columns.end()) {
         return it->second;
-
-    // Second allow column names to bear prefix like
-    // the tablename (e.g. service_ for table services, or log_ for table log)
-    int prefix_len = strlen(prefixname()); // replace 's' with '_'
-    if (!strncmp(colname, prefixname(), prefix_len - 1) && \
-            colname[prefix_len - 1] == '_')
-    {
-        return column(colname + prefix_len);
     }
 
     // Now we try to readd the removed prefix. That way we tackle the
@@ -91,24 +98,31 @@ Column *Table::column(const char *colname)
     with_prefix += colname;
 
     it = _columns.find(with_prefix);
-    if (it != _columns.end())
+    if (it != _columns.end()) {
         return it->second;
-    else
-        return 0;
+    }
+    return nullptr;
 }
 
+Column *Table::dynamicColumn(const char *colname_with_args) {
+    const char *sep_pos = strchr(colname_with_args, ':');
+    string name(colname_with_args, sep_pos - colname_with_args);
 
-bool Table::hasColumn(Column *col)
-{
+    const char *argstring = sep_pos + 1;
+
+    auto it = _dynamic_columns.find(name);
+    if (it != _dynamic_columns.end()) {
+        return it->second->createColumn(argstring);
+    }
+    return nullptr;
+}
+
+bool Table::hasColumn(Column *col) {
     // this is not very efficient but seldomly used
-    for (_columns_t::iterator it = _columns.begin();
-            it != _columns.end();
-            ++it)
-    {
-        if (col == it->second)
+    for (auto &column : _columns) {
+        if (col == column.second) {
             return true;
+        }
     }
     return false;
 }
-
-
