@@ -23,49 +23,41 @@
 // Boston, MA 02110-1301 USA.
 
 #include "TableColumns.h"
+#include <utility>
+#include "Column.h"
 #include "ColumnsColumn.h"
 #include "Query.h"
 
-TableColumns::TableColumns()
-{
-    addColumn(new ColumnsColumn("table",
-                "The name of the table",       COLCOL_TABLE, this));
-    addColumn(new ColumnsColumn("name",
-                "The name of the column within the table",        COLCOL_NAME,  this));
-    addColumn(new ColumnsColumn("description",
-                "A description of the column", COLCOL_DESCR, this));
-    addColumn(new ColumnsColumn("type",
-                "The data type of the column (int, float, string, list)",        COLCOL_TYPE,  this));
+TableColumns::TableColumns() {
+    addColumn(new ColumnsColumn("table", "The name of the table", COLCOL_TABLE,
+                                this));
+    addColumn(new ColumnsColumn(
+        "name", "The name of the column within the table", COLCOL_NAME, this));
+    addColumn(new ColumnsColumn("description", "A description of the column",
+                                COLCOL_DESCR, this));
+    addColumn(new ColumnsColumn(
+        "type", "The data type of the column (int, float, string, list)",
+        COLCOL_TYPE, this));
 }
 
-void TableColumns::addTable(Table *table)
-{
-    _tables.push_back(table);
-}
+void TableColumns::addTable(Table *table) { _tables.push_back(table); }
 
-void TableColumns::answerQuery(Query *query)
-{
-    for (_tables_t::iterator it = _tables.begin();
-            it != _tables.end();
-            ++it)
-    {
-        Table *table = *it;
+void TableColumns::answerQuery(Query *query) {
+    for (auto table : _tables) {
         Table::_columns_t *columns = table->columns();
-        for (Table::_columns_t::iterator it = columns->begin();
-                it != columns->end();
-                ++it)
-        {
-            if (!query->processDataset(it->second)) break;
+        for (auto &column : *columns) {
+            if (!query->processDataset(column.second)) {
+                break;
+            }
         }
     }
 }
 
-const char *TableColumns::getValue(Column *column, int colcol)
-{
-    static const char *typenames[6] = { "int", "float", "string", "list", "time", "dict" };
+const char *TableColumns::getValue(Column *column, int colcol) {
+    static const char *typenames[8] = {"int",  "float", "string", "list",
+                                       "time", "dict",  "blob",   "null"};
 
-    switch (colcol)
-    {
+    switch (colcol) {
         case COLCOL_TABLE:
             return tableNameOf(column);
         case COLCOL_NAME:
@@ -79,17 +71,11 @@ const char *TableColumns::getValue(Column *column, int colcol)
     return "";
 }
 
-const char *TableColumns::tableNameOf(Column *column)
-{
-    for (_tables_t::iterator it = _tables.begin();
-            it != _tables.end();
-            ++it)
-    {
-        Table *table = *it;
+const char *TableColumns::tableNameOf(Column *column) {
+    for (auto table : _tables) {
         if (table->hasColumn(column)) {
             return table->name();
         }
     }
-    return ""; // never reached if no bug
+    return "";  // never reached if no bug
 }
-
