@@ -22,40 +22,36 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-#include <cstddef>
-
-#define NSCORE
-#include "nagios.h"
-#include "Query.h"
-#include "OffsetStringColumn.h"
 #include "TableCommands.h"
+#include "OffsetStringColumn.h"
+#include "Query.h"
+#include "nagios.h"
 
-
+using std::string;
 
 extern command *command_list;
 
-TableCommands::TableCommands()
-{
-    addColumns(this, "", -1);
-}
+TableCommands::TableCommands() { addColumns(this, "", -1); }
 
-
-void TableCommands::addColumns(Table *table, string prefix, int indirect_offset)
-{
+// static
+void TableCommands::addColumns(Table *table, string prefix,
+                               int indirect_offset) {
     command cmd;
-    char *ref = (char *)&cmd;
-    table->addColumn(new OffsetStringColumn(prefix + "name",
-                "The name of the command", (char *)(&cmd.name) - ref, indirect_offset));
-    table->addColumn(new OffsetStringColumn(prefix + "line",
-                "The shell command line", (char *)(&cmd.command_line) - ref, indirect_offset));
+    char *ref = reinterpret_cast<char *>(&cmd);
+    table->addColumn(new OffsetStringColumn(
+        prefix + "name", "The name of the command",
+        reinterpret_cast<char *>(&cmd.name) - ref, indirect_offset));
+    table->addColumn(new OffsetStringColumn(
+        prefix + "line", "The shell command line",
+        reinterpret_cast<char *>(&cmd.command_line) - ref, indirect_offset));
 }
 
-
-void TableCommands::answerQuery(Query *query)
-{
+void TableCommands::answerQuery(Query *query) {
     command *cmd = command_list;
-    while (cmd) {
-        if (!query->processDataset(cmd)) break;
+    while (cmd != nullptr) {
+        if (!query->processDataset(cmd)) {
+            break;
+        }
         cmd = cmd->next;
     }
 }
