@@ -25,22 +25,20 @@
 #ifndef TableServicegroups_h
 #define TableServicegroups_h
 
-#include "config.h"
-
-#include <set>
+#include "config.h"  // IWYU pragma: keep
+#include <string>
 #include "Table.h"
-#include "nagios.h"
+#include "nagios.h"  // IWYU pragma: keep
+class Query;
 
-class TableServicegroups : public Table
-{
+class TableServicegroups : public Table {
 public:
     TableServicegroups();
-    const char *name() { return "servicegroups"; }
-    void *findObject(char *objectspec);
-    bool isAuthorized(contact *, void *);
-    void addColumns(Table *, string prefix, int indirect_offset);
-    void answerQuery(Query *query);
+    const char *name() override { return "servicegroups"; }
+    void *findObject(char *objectspec) override;
+    bool isAuthorized(contact *, void *) override;
+    static void addColumns(Table *, std::string prefix, int indirect_offset);
+    void answerQuery(Query *query) override;
 };
 
-#endif // TableServicegroups_h
-
+#endif  // TableServicegroups_h
