@@ -22,39 +22,41 @@
 // to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 // Boston, MA 02110-1301 USA.
 
-#include "nagios.h"
-#include "Query.h"
+#include "TableTimeperiods.h"
 #include "OffsetStringColumn.h"
 #include "OffsetTimeperiodColumn.h"
-#include "TableTimeperiods.h"
+#include "Query.h"
+#include "nagios.h"
+
+using std::string;
 
 extern timeperiod *timeperiod_list;
 
-TableTimeperiods::TableTimeperiods()
-{
-    addColumns(this, "", -1);
-}
+TableTimeperiods::TableTimeperiods() { addColumns(this, "", -1); }
 
-
-void TableTimeperiods::addColumns(Table *table, string prefix, int indirect_offset)
-{
+// static
+void TableTimeperiods::addColumns(Table *table, string prefix,
+                                  int indirect_offset) {
     timeperiod tp;
-    char *ref = (char *)&tp;
-    table->addColumn(new OffsetStringColumn(prefix + "name",
-                "The name of the timeperiod", (char *)(&tp.name) - ref, indirect_offset));
-    table->addColumn(new OffsetStringColumn(prefix + "alias",
-                "The alias of the timeperiod", (char *)(&tp.alias) - ref, indirect_offset));
-    table->addColumn(new OffsetTimeperiodColumn(prefix + "in",
-                "Wether we are currently in this period (0/1)", -1, indirect_offset));
-    // TODO: add days and exceptions
+    char *ref = reinterpret_cast<char *>(&tp);
+    table->addColumn(new OffsetStringColumn(
+        prefix + "name", "The name of the timeperiod",
+        reinterpret_cast<char *>(&tp.name) - ref, indirect_offset));
+    table->addColumn(new OffsetStringColumn(
+        prefix + "alias", "The alias of the timeperiod",
+        reinterpret_cast<char *>(&tp.alias) - ref, indirect_offset));
+    table->addColumn(new OffsetTimeperiodColumn(
+        prefix + "in", "Wether we are currently in this period (0/1)", -1,
+        indirect_offset));
+    // TODO(mk): add days and exceptions
 }
 
-
-void TableTimeperiods::answerQuery(Query *query)
-{
+void TableTimeperiods::answerQuery(Query *query) {
     timeperiod *tp = timeperiod_list;
-    while (tp) {
-        if (!query->processDataset(tp)) break;
+    while (tp != nullptr) {
+        if (!query->processDataset(tp)) {
+            break;
+        }
         tp = tp->next;
     }
 }
