@@ -25,14 +25,14 @@
 #ifndef auth_h
 #define auth_h
 
-#include "nagios.h"
+#include "config.h"  // IWYU pragma: keep
+#include "nagios.h"  // IWYU pragma: keep
 
-#define AUTH_LOOSE  0
+#define AUTH_LOOSE 0
 #define AUTH_STRICT 1
 
 // Dummy pointer for unknown user (not no user)
-#define UNKNOWN_AUTH_USER ((contact *)0xdeadbeaf)
-
+#define UNKNOWN_AUTH_USER reinterpret_cast<contact *>(0xdeadbeaf)
 
 extern int g_service_authorization;
 extern int g_group_authorization;
@@ -40,10 +40,9 @@ extern int g_group_authorization;
 #ifdef __cplusplus
 extern "C" {
 #endif
-  int is_authorized_for(contact *ctc, host *host, service *svc);
+int is_authorized_for(contact *ctc, host *hst, service *svc);
 #ifdef __cplusplus
 }
 #endif
 
-#endif // auth_h
-
+#endif  // auth_h
