@@ -25,44 +25,37 @@
 #ifndef logger_h
 #define logger_h
 
-#include "config.h"
+#include "config.h"  // IWYU pragma: keep
+#include <syslog.h>
 
 #ifdef CMC
-#include <syslog.h>
 #define LG_DEBUG LOG_INFO
-#define LG_INFO  LOG_NOTICE
-#define LG_WARN  LOG_WARNING
-#define LG_ERR   LOG_ERR
-#define LG_CRIT  LOG_CRIT
+#define LG_INFO LOG_NOTICE
+#define LG_WARN LOG_WARNING
+#define LG_ERR LOG_ERR
+#define LG_CRIT LOG_CRIT
 #define LG_ALERT LOG_ALERT
 #else
-#ifdef NAGIOS4
-#include <syslog.h>
-#endif
 // TODO: Really use log levels
 #define LG_INFO 262144
-#define LG_WARN  LOG_INFO
-#define LG_ERR   LOG_INFO
-#define LG_CRIT  LOG_INFO
+#define LG_WARN LOG_INFO
+#define LG_ERR LOG_INFO
+#define LG_CRIT LOG_INFO
 #define LG_DEBUG LOG_INFO
 #define LG_ALERT LOG_INFO
 #endif
 
 #ifdef __cplusplus
-#ifndef CMC
 extern "C" {
 #endif
-#endif
 
-void logger(int priority, const char *loginfo, ...);
+void logger(int priority, const char *loginfo, ...)
+    __attribute__((format(printf, 2, 3)));
 void open_logfile();
 void close_logfile();
 
 #ifdef __cplusplus
-#ifndef CMC
 }
 #endif
-#endif
-
-#endif // logger_h
 
+#endif  // logger_h
