@@ -19,25 +19,30 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
 
 import config, defaults, hooks
 from lib import *
-import time, os, pprint, shutil
+import time, os, pprint, shutil, traceback
 from valuespec import *
 
 # Datastructures and functions needed before plugins can be loaded
 loaded_with_language = False
 
 # Custom user attributes
-user_attributes = {}
+user_attributes  = {}
 builtin_user_attribute_names = []
 
+# Connection configuration
+connection_dict = {}
+# Connection object dictionary
+g_connections   = {}
+
 # Load all userdb plugins
-def load_plugins():
+def load_plugins(force):
     global user_attributes
     global multisite_user_connectors
     global builtin_user_attribute_names
@@ -51,18 +56,30 @@ def load_plugins():
                 del user_attributes[attr_name]
         declare_custom_user_attrs()
 
+    connection_dict.clear()
+    for connection in config.user_connections:
+        connection_dict[connection['id']] = connection
+
+    # Cleanup eventual still open connections
+    if g_connections:
+        g_connections.clear()
+
     global loaded_with_language
-    if loaded_with_language == current_language:
+    if loaded_with_language == current_language and not force:
         return
 
     # declare & initialize global vars
     user_attributes = {}
-    multisite_user_connectors = []
+    multisite_user_connectors = {}
 
     load_web_plugins("userdb", globals())
     builtin_user_attribute_names = user_attributes.keys()
     declare_custom_user_attrs()
-    hook_load()
+
+    # Connectors have the option to perform migration of configuration options
+    # while the initial loading is performed
+    for connector_class in multisite_user_connectors.values():
+        connector_class.migrate_config()
 
     # This must be set after plugin loading to make broken plugins raise
     # exceptions all the time and not only the first time (when the plugins
@@ -70,73 +87,140 @@ def load_plugins():
     loaded_with_language = current_language
 
 
-def list_user_connectors():
-    return [ (c['id'], c['title']) for c in multisite_user_connectors ]
+# Cleans up at the end of a request: Cleanup eventual open connections
+def finalize():
+    if g_connections:
+        g_connections.clear()
 
-def connector_enabled(connector_id):
-    return connector_id in config.user_connectors
 
-def enabled_connectors():
-    connectors = []
-    for connector in multisite_user_connectors:
-        if connector['id'] in config.user_connectors:
-            connectors.append(connector)
-    return connectors
+# Returns a list of two part tuples where the first element is the unique
+# connection id and the second element the connector specification dict
+def get_connections(only_enabled=False):
+    connections = []
+    for connector_id, connector_class in multisite_user_connectors.items():
+        if connector_id == 'htpasswd':
+            # htpasswd connector is enabled by default and always executed first
+            connections.insert(0, ('htpasswd', connector_class({})))
+        else:
+            for connection_config in config.user_connections:
+                if not only_enabled or not connection_config.get('disabled'):
+                    connections.append((connection_config['id'], connector_class(connection_config)))
+    return connections
 
-def get_connector_id(connector_id):
-    if connector_id is None:
-        connector_id = 'htpasswd'
-    return connector_id
 
-# Returns the connector dictionary of the given id
-def get_connector(connector_id):
-    connector_id = get_connector_id(connector_id)
-    for connector in enabled_connectors():
-        if connector['id'] == connector_id:
-            return connector
-    return {}
+def active_connections():
+    return get_connections(only_enabled=True)
 
-# Returns a list of locked attributes
-def locked_attributes(connector_id):
-    connector = get_connector(connector_id)
-    return connector.get('locked_attributes', lambda: [])()
 
-# Returns a list of multisite attributes
-def multisite_attributes(connector_id):
-    connector = get_connector(connector_id)
-    return connector.get('multisite_attributes', lambda: [])()
+# When at least one LDAP connection is defined and active a sync is possible
+def sync_possible():
+    for connection_id, connection in active_connections():
+        if connection.type() == "ldap":
+            return True
+    return False
 
-# Returns a list of non contact attributes
-def non_contact_attributes(connector_id):
-    connector = get_connector(connector_id)
-    return connector.get('non_contact_attributes', lambda: [])()
 
-def new_user_template(connector_id):
+def cleanup_connection_id(connection_id):
+    if connection_id is None:
+        connection_id = 'htpasswd'
+
+    # Old Check_MK used a static "ldap" connector id for all LDAP users.
+    # Since Check_MK now supports multiple LDAP connections, the ID has
+    # been changed to "default". But only transform this when there is
+    # no connection existing with the id LDAP.
+    if connection_id == 'ldap' and not get_connection('ldap'):
+        connection_id = 'default'
+
+    return connection_id
+
+
+# Returns the connection object of the requested connection id. This function
+# maintains a cache that for a single connection_id only one object per request
+# is created.
+def get_connection(connection_id):
+    if connection_id in g_connections:
+        return g_connections[connection_id]
+
+    connection = dict(get_connections()).get(connection_id)
+
+    if connection:
+        g_connections[connection_id] = connection
+
+    return connection
+
+
+# Returns a list of connection specific locked attributes
+def locked_attributes(connection_id):
+    return get_attributes(connection_id, "locked_attributes")
+
+
+# Returns a list of connection specific multisite attributes
+def multisite_attributes(connection_id):
+    return get_attributes(connection_id, "multisite_attributes")
+
+
+# Returns a list of connection specific non contact attributes
+def non_contact_attributes(connection_id):
+    return get_attributes(connection_id, "non_contact_attributes")
+
+
+def get_attributes(connection_id, what):
+    connection = get_connection(connection_id)
+    if connection:
+        return getattr(connection, what)()
+    else:
+        return []
+
+
+def new_user_template(connection_id):
     new_user = {
         'serial':        0,
-        'connector':     connector_id,
+        'connector':     connection_id,
     }
 
     # Apply the default user profile
     new_user.update(config.default_user_profile)
     return new_user
 
-def create_non_existing_user(connector_id, username):
+
+def create_non_existing_user(connection_id, username):
     users = load_users(lock = True)
     if username in users:
         return # User exists. Nothing to do...
 
-    users[username] = new_user_template(connector_id)
+    users[username] = new_user_template(connection_id)
     save_users(users)
 
     # Call the sync function for this new user
-    hook_sync(connector_id = connector_id, only_username = username)
+    hook_sync(connection_id = connection_id, only_username = username)
 
-# FIXME: Can we improve this easily? Would be nice not to have to call "load_users".
-# Maybe a directory listing of profiles or a list of a small file would perform better
-# than having to load the users, contacts etc. during each http request to multisite
+
+# This function is called very often during regular page loads so it has to be efficient
+# even when having a lot of users.
+#
+# When using the multisite authentication with just by WATO created users it would be
+# easy, but we also need to deal with users which are only existant in the htpasswd
+# file and don't have a profile directory yet.
 def user_exists(username):
-    return username in load_users().keys()
+    if _user_exists_according_to_profile(username):
+        return True
+
+    return _user_exists_htpasswd(username)
+
+
+def _user_exists_according_to_profile(username):
+    base_path = config.config_dir + "/" + username.encode("utf-8") + "/"
+    return os.path.exists(base_path + "transids.mk") \
+            or os.path.exists(base_path + "serial.mk")
+
+
+def _user_exists_htpasswd(username):
+    for line in open(defaults.htpasswd_file):
+        l = line.decode("utf-8")
+        if l.startswith("%s:" % username):
+            return True
+    return False
+
 
 def user_locked(username):
     users = load_users()
@@ -191,6 +275,33 @@ def on_failed_login(username):
 root_dir      = defaults.check_mk_configdir + "/wato/"
 multisite_dir = defaults.default_config_dir + "/multisite.d/wato/"
 
+# Old vs:
+#ListChoice(
+#    title = _('Automatic User Synchronization'),
+#    help  = _('By default the users are synchronized automatically in several situations. '
+#              'The sync is started when opening the "Users" page in configuration and '
+#              'during each page rendering. Each connector can then specify if it wants to perform '
+#              'any actions. For example the LDAP connector will start the sync once the cached user '
+#              'information are too old.'),
+#    default_value = [ 'wato_users', 'page', 'wato_pre_activate_changes', 'wato_snapshot_pushed' ],
+#    choices       = [
+#        ('page',                      _('During regular page processing')),
+#        ('wato_users',                _('When opening the users\' configuration page')),
+#        ('wato_pre_activate_changes', _('Before activating the changed configuration')),
+#        ('wato_snapshot_pushed',      _('On a remote site, when it receives a new configuration')),
+#    ],
+#    allow_empty   = True,
+#),
+def transform_userdb_automatic_sync(val):
+    if val == []:
+        return None
+
+    elif type(val) == list and val:
+        return "all"
+
+    else:
+        return val
+
 #.
 #   .-Users----------------------------------------------------------------.
 #   |                       _   _                                          |
@@ -249,7 +360,7 @@ def load_users(lock = False):
             raise MKGeneralException(_("Cannot read configuration file %s: %s" %
                           (filename, e)))
         else:
-            html.log('load_users: Problem while loading contacts (%s - %s). '
+            logger(LOG_ERR, 'load_users: Problem while loading contacts (%s - %s). '
                      'Initializing structure...' % (filename, e))
         contacts = {}
 
@@ -266,7 +377,7 @@ def load_users(lock = False):
             raise MKGeneralException(_("Cannot read configuration file %s: %s" %
                           (filename, e)))
         else:
-            html.log('load_users: Problem while loading users (%s - %s). '
+            logger(LOG_ERR, 'load_users: Problem while loading users (%s - %s). '
                      'Initializing structure...' % (filename, e))
         users = {}
 
@@ -278,6 +389,10 @@ def load_users(lock = False):
         profile.update(user)
         result[id] = profile
 
+        # Convert non unicode mail addresses
+        if type(profile.get("email")) == str:
+            profile["email"] = profile["email"].decode("utf-8")
+
     # This loop is only neccessary if someone has edited
     # contacts.mk manually. But we want to support that as
     # far as possible.
@@ -301,11 +416,13 @@ def load_users(lock = False):
         except IOError:
             return []
 
+    # FIXME TODO: Consolidate with htpasswd user connector
     filename = defaults.htpasswd_file
     for line in readlines(filename):
         line = line.strip()
         if ':' in line:
             id, password = line.strip().split(":")[:2]
+            id = id.decode("utf-8")
             if password.startswith("!"):
                 locked = True
                 password = password[1:]
@@ -332,6 +449,7 @@ def load_users(lock = False):
         line = line.strip()
         if ':' in line:
             user_id, serial = line.split(':')[:2]
+            user_id = user_id.decode("utf-8")
             if user_id in result:
                 result[user_id]['serial'] = saveint(serial)
 
@@ -339,7 +457,7 @@ def load_users(lock = False):
     dir = defaults.var_dir + "/web/"
     for d in os.listdir(dir):
         if d[0] != '.':
-            id = d
+            id = d.decode("utf-8")
 
             # read special values from own files
             if id in result:
@@ -374,14 +492,14 @@ def load_users(lock = False):
     return result
 
 def load_custom_attr(userid, key, conv_func, default = None):
-    basedir = defaults.var_dir + "/web/" + userid
+    basedir = defaults.var_dir + "/web/" + make_utf8(userid)
     try:
         return conv_func(file(basedir + '/' + key + '.mk').read().strip())
     except IOError:
         return default
 
 def save_custom_attr(userid, key, val):
-    basedir = defaults.var_dir + "/web/" + userid
+    basedir = defaults.var_dir + "/web/" + make_utf8(userid)
     make_nagios_directory(basedir)
     create_user_file('%s/%s.mk' % (basedir, key), 'w').write('%s\n' % val)
 
@@ -397,12 +515,11 @@ def split_dict(d, keylist, positive):
     return dict([(k,v) for (k,v) in d.items() if (k in keylist) == positive])
 
 def save_users(profiles):
-
     # Add custom macros
     core_custom_macros =  [ k for k,o in user_attributes.items() if o.get('add_custom_macro') ]
     for user in profiles.keys():
         for macro in core_custom_macros:
-            if profiles[user].get(macro):
+            if macro in profiles[user]:
                 profiles[user]['_'+macro] = profiles[user][macro]
 
     multisite_custom_values = [ k for k,v in user_attributes.items() if v["domain"] == "multisite" ]
@@ -476,59 +593,57 @@ def save_users(profiles):
         rename_file = False
         out = create_user_file(serials_file[:-4], "w")
 
-    def encode_utf8(value):
-        if type(value) == unicode:
-            value = value.encode("utf-8")
-        return value
-
     for user_id, user in profiles.items():
-        out.write('%s:%d\n' % (encode_utf8(user_id), user.get('serial', 0)))
+        out.write('%s:%d\n' % (make_utf8(user_id), user.get('serial', 0)))
     out.close()
     if rename_file:
         os.rename(serials_file, serials_file[:-4])
 
     # Write user specific files
-    for id, user in profiles.items():
-        user_dir = defaults.var_dir + "/web/" + id
+    for user_id, user in profiles.items():
+        user_dir = defaults.var_dir + "/web/" + user_id
         make_nagios_directory(user_dir)
 
         # authentication secret for local processes
         auth_file = user_dir + "/automation.secret"
         if "automation_secret" in user:
             create_user_file(auth_file, "w").write("%s\n" % user["automation_secret"])
-        elif os.path.exists(auth_file):
-            os.remove(auth_file)
+        else:
+            remove_user_file(auth_file)
 
         # Write out user attributes which are written to dedicated files in the user
         # profile directory. The primary reason to have separate files, is to reduce
         # the amount of data to be loaded during regular page processing
-        save_custom_attr(id, 'serial', str(user.get('serial', 0)))
-        save_custom_attr(id, 'num_failed', str(user.get('num_failed', 0)))
-        save_custom_attr(id, 'enforce_pw_change', str(int(user.get('enforce_pw_change', False))))
-        save_custom_attr(id, 'last_pw_change', str(user.get('last_pw_change', int(time.time()))))
+        save_custom_attr(user_id, 'serial', str(user.get('serial', 0)))
+        save_custom_attr(user_id, 'num_failed', str(user.get('num_failed', 0)))
+        save_custom_attr(user_id, 'enforce_pw_change', str(int(user.get('enforce_pw_change', False))))
+        save_custom_attr(user_id, 'last_pw_change', str(user.get('last_pw_change', int(time.time()))))
 
         # Write out the last seent time
         if 'last_seen' in user:
-            save_custom_attr(id, 'last_seen', repr(user['last_seen']))
+            save_custom_attr(user_id, 'last_seen', repr(user['last_seen']))
 
-    # Remove settings directories of non-existant users.
-    # Beware: we removed this since it leads to violent destructions
-    # if the user database is out of the scope of Check_MK. This is
-    # e.g. the case, if mod_ldap is used for user authentication.
-    # dir = defaults.var_dir + "/web"
-    # for e in os.listdir(dir):
-    #     if e not in ['.', '..'] and e not in profiles:
-    #         entry = dir + "/" + e
-    #         if os.path.isdir(entry):
-    #             shutil.rmtree(entry)
-    # But for the automation.secret this is ok, since automation users are not
-    # created by other sources in common cases
+    # During deletion of users we don't delete files which might contain user settings
+    # and e.g. customized views which are not easy to reproduce. We want to keep the
+    # files which are the result of a lot of work even when e.g. the LDAP sync deletes
+    # a user by accident. But for some internal files it is ok to delete them.
+    #
+    # Be aware: The user_exists() function relies on these files to be deleted.
+    profile_files_to_delete = [
+        "automation.secret",
+        "transids.mk",
+        "serial.mk",
+    ]
     dir = defaults.var_dir + "/web"
     for user_dir in os.listdir(defaults.var_dir + "/web"):
-        if user_dir not in ['.', '..'] and user_dir not in profiles:
+        if user_dir not in ['.', '..'] and user_dir.decode("utf-8") not in profiles:
             entry = dir + "/" + user_dir
-            if os.path.isdir(entry) and os.path.exists(entry + '/automation.secret'):
-                os.unlink(entry + '/automation.secret')
+            if not os.path.isdir(entry):
+                continue
+
+            for to_delete in profile_files_to_delete:
+                if os.path.exists(entry + '/' + to_delete):
+                    os.unlink(entry + '/' + to_delete)
 
     # Release the lock to make other threads access possible again asap
     # This lock is set by load_users() only in the case something is expected
@@ -541,6 +656,19 @@ def save_users(profiles):
     # Call the users_saved hook
     hooks.call("users-saved", profiles)
 
+
+def rewrite_users():
+    users = load_users(lock = True)
+    save_users(users)
+
+def contactgroups_of_user(user_id):
+    users = load_users()
+    if user_id not in users:
+        return []
+    else:
+        return users[user_id].get("contactgroups", [])
+
+
 #.
 #   .-Roles----------------------------------------------------------------.
 #   |                       ____       _                                   |
@@ -591,7 +719,7 @@ def load_roles():
             raise MKGeneralException(_("Cannot read configuration file %s: %s" %
                           (filename, e)))
         else:
-            html.log('load_roles: Problem while loading roles (%s - %s). '
+            logger(LOG_ERR, 'load_roles: Problem while loading roles (%s - %s). '
                      'Initializing structure...' % (filename, e))
         return roles
 
@@ -647,7 +775,7 @@ def load_group_information():
             raise MKGeneralException(_("Cannot read configuration file %s: %s" %
                           (filename, e)))
         else:
-            html.log('load_group_information: Problem while loading groups (%s - %s). '
+            logger(LOG_ERR, 'load_group_information: Problem while loading groups (%s - %s). '
                      'Initializing structure...' % (filename, e))
         return {}
 
@@ -684,7 +812,7 @@ def load_custom_attrs():
             raise MKGeneralException(_("Cannot read configuration file %s: %s" %
                           (filename, e)))
         else:
-            html.log('load_custom_attrs: Problem while loading custom attributes (%s - %s). '
+            logger(LOG_ERR, 'load_custom_attrs: Problem while loading custom attributes (%s - %s). '
                      'Initializing structure...' % (filename, e))
         return {}
 
@@ -700,6 +828,132 @@ def declare_custom_user_attrs():
             add_custom_macro = attr.get('add_custom_macro', False )
         )
 
+#.
+#   .--ConnectorCfg--------------------------------------------------------.
+#   |    ____                            _              ____  __           |
+#   |   / ___|___  _ __  _ __   ___  ___| |_ ___  _ __ / ___|/ _| __ _     |
+#   |  | |   / _ \| '_ \| '_ \ / _ \/ __| __/ _ \| '__| |   | |_ / _` |    |
+#   |  | |__| (_) | | | | | | |  __/ (__| || (_) | |  | |___|  _| (_| |    |
+#   |   \____\___/|_| |_|_| |_|\___|\___|\__\___/|_|   \____|_|  \__, |    |
+#   |                                                            |___/     |
+#   +----------------------------------------------------------------------+
+#   | The user can enable and configure a list of user connectors which    |
+#   | are then used by the userdb to fetch user / group information from   |
+#   | external sources like LDAP servers.                                  |
+#   '----------------------------------------------------------------------'
+
+def load_connection_config():
+    user_connections = []
+
+    filename = multisite_dir + "user_connections.mk"
+    if not os.path.exists(filename):
+        return user_connections
+
+    try:
+        context = {
+            "user_connections": user_connections,
+        }
+        execfile(filename, context, context)
+        return context["user_connections"]
+
+    except Exception, e:
+        if config.debug:
+            raise MKGeneralException(_("Cannot read configuration file %s: %s" %
+                          (filename, e)))
+        return user_connections
+
+
+def save_connection_config(connections):
+    make_nagios_directory(multisite_dir)
+    out = create_user_file(multisite_dir + "user_connections.mk", "w")
+    out.write("# Written by Multisite UserDB\n# encoding: utf-8\n\n")
+    out.write("user_connections = \\\n%s\n\n" % pprint.pformat(connections))
+
+#.
+#   .--ConnectorAPI--------------------------------------------------------.
+#   |     ____                            _              _    ____ ___     |
+#   |    / ___|___  _ __  _ __   ___  ___| |_ ___  _ __ / \  |  _ \_ _|    |
+#   |   | |   / _ \| '_ \| '_ \ / _ \/ __| __/ _ \| '__/ _ \ | |_) | |     |
+#   |   | |__| (_) | | | | | | |  __/ (__| || (_) | | / ___ \|  __/| |     |
+#   |    \____\___/|_| |_|_| |_|\___|\___|\__\___/|_|/_/   \_\_|  |___|    |
+#   |                                                                      |
+#   +----------------------------------------------------------------------+
+#   | Implements the base class for User Connector classes. It implements  |
+#   | basic mechanisms and default methods which might/should be           |
+#   | overridden by the specific connector classes.                        |
+#   '----------------------------------------------------------------------'
+
+# FIXME: How to declare methods/attributes forced to be overridden?
+class UserConnector(object):
+    def __init__(self, config):
+        super(UserConnector, self).__init__()
+        self._config = config
+
+    @classmethod
+    def type(self):
+        return None
+
+    # The string representing this connector to humans
+    @classmethod
+    def title(self):
+        return None
+
+
+    @classmethod
+    def short_title(self):
+        return _('htpasswd')
+
+    #
+    # USERDB API METHODS
+    #
+
+    @classmethod
+    def migrate_config(self):
+        pass
+
+    # Optional: Hook function can be registered here to be executed
+    # to validate a login issued by a user.
+    # Gets parameters: username, password
+    # Has to return either:
+    #     '<user_id>' -> Login succeeded
+    #     False       -> Login failed
+    #     None        -> Unknown user
+    def check_credentials(self, user_id, password):
+        return None
+
+    # Optional: Hook function can be registered here to be executed
+    # to synchronize all users.
+    def do_sync(self, add_to_changelog, only_username):
+        pass
+
+    # Optional: Tells whether or not the given user is currently
+    # locked which would mean that he is not allowed to login.
+    def is_locked(self, user_id):
+        return False
+
+    # Optional: Hook function can be registered here to be executed
+    # on each call to the multisite cron job page which is normally
+    # executed once a minute.
+    def on_cron_job(self):
+        pass
+
+    # Optional: Hook function can be registered here to be xecuted
+    # to save all users.
+    def save_users(self, users):
+        pass
+
+    # List of user attributes locked for all users attached to this
+    # connection. Those locked attributes are read-only in WATO.
+    def locked_attributes(self):
+        return []
+
+    def multisite_attributes(self):
+        return []
+
+    def non_contact_attributes(self):
+        return []
+
+
 #.
 #   .-Hooks----------------------------------------------------------------.
 #   |                     _   _             _                              |
@@ -710,24 +964,21 @@ def declare_custom_user_attrs():
 #   |                                                                      |
 #   +----------------------------------------------------------------------+
 
+
 # This hook is called to validate the login credentials provided by a user
 def hook_login(username, password):
-    for connector in enabled_connectors():
-        handler = connector.get('login', None)
-        if not handler:
-            continue
-
-        result = handler(username, password)
+    for connection_id, connection in active_connections():
+        result = connection.check_credentials(username, password)
         # None        -> User unknown, means continue with other connectors
         # '<user_id>' -> success
         # False       -> failed
         if result not in [ False, None ]:
             username = result
-            if type(username) != str:
+            if type(username) not in [ str, unicode ]:
                 raise MKInternalError(_("The username returned by the %s "
-                    "connector is not of type string (%r).") % (connector['id'], username))
+                    "connector is not of type string (%r).") % (connection_id, username))
             # Check wether or not the user exists (and maybe create it)
-            create_non_existing_user(connector['id'], username)
+            create_non_existing_user(connection_id, username)
 
             # Now, after successfull login (and optional user account
             # creation), check wether or not the user is locked.
@@ -735,8 +986,7 @@ def hook_login(username, password):
             # password against the hash in the htpasswd file prefixed with
             # a "!". But when using other conectors it might be neccessary
             # to validate the user "locked" attribute.
-            lock_handler = connector.get('locked', None)
-            if lock_handler and lock_handler(username):
+            if connection.is_locked(username):
                 return False # The account is locked
 
             return result
@@ -744,77 +994,57 @@ def hook_login(username, password):
         elif result == False:
             return result
 
+
+def show_exception(connection_id, title, e, debug=True):
+    html.show_error(
+        "<b>" + connection_id + ' - ' + title + "</b>"
+        "<pre>%s</pre>" % (debug and traceback.format_exc() or e)
+    )
+
+
 # Hook function can be registered here to be executed to synchronize all users.
 # Is called on:
 #   a) before rendering the user management page in WATO
 #   b) a user is created during login (only for this user)
 #   c) Before activating the changes in WATO
-def hook_sync(connector_id = None, add_to_changelog = False, only_username = None, raise_exc = False):
-    if connector_id:
-        connectors = [ get_connector(connector_id) ]
+def hook_sync(connection_id = None, add_to_changelog = False, only_username = None, raise_exc = False):
+    if connection_id:
+        connections = [ (connection_id, get_connection(connection_id)) ]
     else:
-        connectors = enabled_connectors()
+        connections = active_connections()
 
     no_errors = True
-    for connector in connectors:
-        handler = connector.get('sync', None)
-        if handler:
-            try:
-                handler(add_to_changelog, only_username)
-            except MKLDAPException, e:
-                if raise_exc:
-                    raise
-                if config.debug:
-                    import traceback
-                    html.show_error(
-                        "<h3>" + _("Error during sync") + "</h3>"
-                        "<pre>%s</pre>" % (traceback.format_exc())
-                    )
-                else:
-                    html.show_error(
-                        "<h3>" + _("Error during sync") + "</h3>"
-                        "<pre>%s</pre>" % (e)
-                    )
-                no_errors = False
-            except:
-                if raise_exc:
-                    raise
-                import traceback
-                html.show_error(
-                    "<h3>" + _("Error during sync") + "</h3>"
-                    "<pre>%s</pre>" % (traceback.format_exc())
-                )
-                no_errors = False
+    for connection_id, connection in connections:
+        try:
+            connection.do_sync(add_to_changelog, only_username)
+        except MKLDAPException, e:
+            if raise_exc:
+                raise
+            show_exception(connection_id, _("Error during sync"), e, debug=config.debug)
+            no_errors = False
+        except Exception, e:
+            if raise_exc:
+                raise
+            show_exception(connection_id, _("Error during sync"), e)
+            no_errors = False
     return no_errors
 
 # Hook function can be registered here to be executed during saving of the
 # new user construct
 def hook_save(users):
-    for connector in enabled_connectors():
-        handler = connector.get('save', None)
-        if not handler:
-            continue
+    for connection_id, connection in active_connections():
         try:
-            handler(users)
-        except:
+            connection.save_users(users)
+        except Exception, e:
             if config.debug:
-                import traceback
-                html.show_error(
-                    "<h3>" + _("Error during saving") + "</h3>"
-                    "<pre>%s</pre>" % (traceback.format_exc())
-                )
-            else:
                 raise
+            else:
+                show_exception(connection_id, _("Error during saving"), e)
 
-def hook_load():
-    for connector in enabled_connectors():
-        handler = connector.get('load', None)
-        if handler:
-            handler()
 
 # This function registers general stuff, which is independet of the single
-# connectors to each page load. It is exectued AFTER all other page hooks.
-def general_page_hook():
+# connectors to each page load. It is exectued AFTER all other connections jobs.
+def general_userdb_job():
     # Working around the problem that the auth.php file needed for multisite based
     # authorization of external addons might not exist when setting up a new installation
     # We assume: Each user must visit this login page before using the multisite based
@@ -829,29 +1059,40 @@ def general_page_hook():
     if not os.path.exists(serials_file) or os.path.getsize(serials_file) == 0:
         save_users(load_users(lock = True))
 
+
 # Hook function can be registered here to execute actions on a "regular" base without
 # user triggered action. This hook is called on each page load.
 # Catch all exceptions and log them to apache error log. Let exceptions raise trough
 # when debug mode is enabled.
-def hook_page():
-    if 'page' not in config.userdb_automatic_sync:
+def execute_userdb_job():
+    if not userdb_sync_job_enabled():
         return
 
-    for connector in enabled_connectors():
-        handler = connector.get('page', None)
-        if not handler:
-            continue
+    for connection_id, connection in active_connections():
         try:
-            handler()
+            connection.on_cron_job()
         except:
             if config.debug:
                 raise
             else:
                 import traceback
-                html.log('Exception (%s, page handler): %s' %
-                            (connector['id'], traceback.format_exc()))
+                logger(LOG_ERR, 'Exception (%s, userdb_job): %s' %
+                            (connection_id, traceback.format_exc()))
+
+    general_userdb_job()
+
+
+def userdb_sync_job_enabled():
+    cfg = transform_userdb_automatic_sync(config.userdb_automatic_sync)
+    if cfg == None:
+        return False # not enabled at all
+
+    import wato # FIXME: Cleanup!
+    if cfg == "master" and wato.is_wato_slave_site():
+        return False
+
+    return True
 
-    general_page_hook()
 
 def ajax_sync():
     try:
