@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -36,7 +36,16 @@
 # - function that outputs the HTML input fields
 # - function that creates the nagios command and title
 
-# RESCHEDULE ACTIVE CHECKS
+
+#   .--Reschedule----------------------------------------------------------.
+#   |          ____                _              _       _                |
+#   |         |  _ \ ___  ___  ___| |__   ___  __| |_   _| | ___           |
+#   |         | |_) / _ \/ __|/ __| '_ \ / _ \/ _` | | | | |/ _ \          |
+#   |         |  _ <  __/\__ \ (__| | | |  __/ (_| | |_| | |  __/          |
+#   |         |_| \_\___||___/\___|_| |_|\___|\__,_|\__,_|_|\___|          |
+#   |                                                                      |
+#   '----------------------------------------------------------------------'
+
 def command_reschedule(cmdtag, spec, row, row_nr, total_rows):
     if html.var("_resched_checks"):
         spread = saveint(html.var("_resched_spread"))
@@ -73,7 +82,22 @@ multisite_commands.append({
 })
 
 
-# ENABLE/DISABLE NOTIFICATIONS
+#.
+#   .--Enable/Disable Notifications----------------------------------------.
+#   |           _____          ______  _           _     _                 |
+#   |          | ____|_ __    / /  _ \(_)___  __ _| |__ | | ___            |
+#   |          |  _| | '_ \  / /| | | | / __|/ _` | '_ \| |/ _ \           |
+#   |          | |___| | | |/ / | |_| | \__ \ (_| | |_) | |  __/           |
+#   |          |_____|_| |_/_/  |____/|_|___/\__,_|_.__/|_|\___|           |
+#   |                                                                      |
+#   |       _   _       _   _  __ _           _   _                        |
+#   |      | \ | | ___ | |_(_)/ _(_) ___ __ _| |_(_) ___  _ __  ___        |
+#   |      |  \| |/ _ \| __| | |_| |/ __/ _` | __| |/ _ \| '_ \/ __|       |
+#   |      | |\  | (_) | |_| |  _| | (_| (_| | |_| | (_) | | | \__ \       |
+#   |      |_| \_|\___/ \__|_|_| |_|\___\__,_|\__|_|\___/|_| |_|___/       |
+#   |                                                                      |
+#   '----------------------------------------------------------------------'
+
 config.declare_permission("action.notifications",
         _("Enable/disable notifications"),
         _("Enable and disable notifications on hosts and services"),
@@ -98,7 +122,22 @@ multisite_commands.append({
 })
 
 
-# ENABLE/DISABLE ACTIVE CHECKS
+#.
+#   .--Enable/Disable Active Checks----------------------------------------.
+#   |           _____          ______  _           _     _                 |
+#   |          | ____|_ __    / /  _ \(_)___  __ _| |__ | | ___            |
+#   |          |  _| | '_ \  / /| | | | / __|/ _` | '_ \| |/ _ \           |
+#   |          | |___| | | |/ / | |_| | \__ \ (_| | |_) | |  __/           |
+#   |          |_____|_| |_/_/  |____/|_|___/\__,_|_.__/|_|\___|           |
+#   |                                                                      |
+#   |       _        _   _              ____ _               _             |
+#   |      / \   ___| |_(_)_   _____   / ___| |__   ___  ___| | _____      |
+#   |     / _ \ / __| __| \ \ / / _ \ | |   | '_ \ / _ \/ __| |/ / __|     |
+#   |    / ___ \ (__| |_| |\ V /  __/ | |___| | | |  __/ (__|   <\__ \     |
+#   |   /_/   \_\___|\__|_| \_/ \___|  \____|_| |_|\___|\___|_|\_\___/     |
+#   |                                                                      |
+#   '----------------------------------------------------------------------'
+
 config.declare_permission("action.enablechecks",
         _("Enable/disable checks"),
         _("Enable and disable active or passive checks on hosts and services"),
@@ -123,7 +162,22 @@ multisite_commands.append({
 })
 
 
-# ENABLE/DISABLE PASSIVE CHECKS
+#.
+#   .--Enable/Disable Passive Checks---------------------------------------.
+#   |           _____          ______  _           _     _                 |
+#   |          | ____|_ __    / /  _ \(_)___  __ _| |__ | | ___            |
+#   |          |  _| | '_ \  / /| | | | / __|/ _` | '_ \| |/ _ \           |
+#   |          | |___| | | |/ / | |_| | \__ \ (_| | |_) | |  __/           |
+#   |          |_____|_| |_/_/  |____/|_|___/\__,_|_.__/|_|\___|           |
+#   |                                                                      |
+#   |   ____               _              ____ _               _           |
+#   |  |  _ \ __ _ ___ ___(_)_   _____   / ___| |__   ___  ___| | _____    |
+#   |  | |_) / _` / __/ __| \ \ / / _ \ | |   | '_ \ / _ \/ __| |/ / __|   |
+#   |  |  __/ (_| \__ \__ \ |\ V /  __/ | |___| | | |  __/ (__|   <\__ \   |
+#   |  |_|   \__,_|___/___/_| \_/ \___|  \____|_| |_|\___|\___|_|\_\___/   |
+#   |                                                                      |
+#   '----------------------------------------------------------------------'
+
 def command_enable_passive(cmdtag, spec, row):
     if html.var("_enable_passive_checks"):
         return ("ENABLE_PASSIVE_" + cmdtag + "_CHECKS;%s" % spec,
@@ -144,7 +198,22 @@ multisite_commands.append({
 
 
 
-# CLEAR MODIFIED ATTRIBUTES
+#.
+#   .--Clear Modified Attributes-------------------------------------------.
+#   |            ____ _                   __  __           _               |
+#   |           / ___| | ___  __ _ _ __  |  \/  | ___   __| |              |
+#   |          | |   | |/ _ \/ _` | '__| | |\/| |/ _ \ / _` |              |
+#   |          | |___| |  __/ (_| | |    | |  | | (_) | (_| |_             |
+#   |           \____|_|\___|\__,_|_|    |_|  |_|\___/ \__,_(_)            |
+#   |                                                                      |
+#   |              _   _   _        _ _           _                        |
+#   |             / \ | |_| |_ _ __(_) |__  _   _| |_ ___  ___             |
+#   |            / _ \| __| __| '__| | '_ \| | | | __/ _ \/ __|            |
+#   |           / ___ \ |_| |_| |  | | |_) | |_| | ||  __/\__ \            |
+#   |          /_/   \_\__|\__|_|  |_|_.__/ \__,_|\__\___||___/            |
+#   |                                                                      |
+#   '----------------------------------------------------------------------'
+
 config.declare_permission("action.clearmodattr",
         _("Reset modified attributes"),
         _("Reset all manually modified attributes of a host or service (like disabled notifications)"),
@@ -162,7 +231,17 @@ multisite_commands.append({
          _("<b>clear the modified attributes</b> of"))),
 })
 
-# FAKE CHECKS
+
+#.
+#   .--Fake Checks---------------------------------------------------------.
+#   |         _____     _           ____ _               _                 |
+#   |        |  ___|_ _| | _____   / ___| |__   ___  ___| | _____          |
+#   |        | |_ / _` | |/ / _ \ | |   | '_ \ / _ \/ __| |/ / __|         |
+#   |        |  _| (_| |   <  __/ | |___| | | |  __/ (__|   <\__ \         |
+#   |        |_|  \__,_|_|\_\___|  \____|_| |_|\___|\___|_|\_\___/         |
+#   |                                                                      |
+#   '----------------------------------------------------------------------'
+
 config.declare_permission("action.fakechecks",
         _("Fake check results"),
         _("Manually submit check results for host and service checks"),
@@ -172,7 +251,7 @@ def command_fake_checks(cmdtag, spec, row):
     for s in [0, 1, 2, 3]:
         statename = html.var("_fake_%d" % s)
         if statename:
-            pluginoutput = html.var_utf8("_fake_output").strip()
+            pluginoutput = html.get_unicode_input("_fake_output").strip()
             if not pluginoutput:
                 pluginoutput = _("Manually set to %s by %s") % (html.attrencode(statename), config.user_id)
             perfdata = html.var("_fake_perfdata")
@@ -195,12 +274,11 @@ def render_fake_form(what):
     html.write("</td><td>")
     html.text_input("_fake_perfdata", "", size=50)
     html.write("</td></tr><tr><td>")
-    html.write(_("Set to:"))
+    html.write(_("Result:"))
     html.write("</td><td>")
     if what == "host":
         html.button("_fake_0", _("Up"))
-        html.button("_fake_1", _("Down"))
-        html.button("_fake_2", _("Unreachable"))
+        html.button("_fake_2", _("Down"))
     else:
         html.button("_fake_0", _("OK"))
         html.button("_fake_1", _("Warning"))
@@ -226,7 +304,23 @@ multisite_commands.append({
     "action"      : command_fake_checks,
 })
 
-# SEND CUSTOM NOTIFICATION
+
+#.
+#   .--Custom Notifications------------------------------------------------.
+#   |                   ____          _                                    |
+#   |                  / ___|   _ ___| |_ ___  _ __ ___                    |
+#   |                 | |  | | | / __| __/ _ \| '_ ` _ \                   |
+#   |                 | |__| |_| \__ \ || (_) | | | | | |                  |
+#   |                  \____\__,_|___/\__\___/|_| |_| |_|                  |
+#   |                                                                      |
+#   |       _   _       _   _  __ _           _   _                        |
+#   |      | \ | | ___ | |_(_)/ _(_) ___ __ _| |_(_) ___  _ __  ___        |
+#   |      |  \| |/ _ \| __| | |_| |/ __/ _` | __| |/ _ \| '_ \/ __|       |
+#   |      | |\  | (_) | |_| |  _| | (_| (_| | |_| | (_) | | | \__ \       |
+#   |      |_| \_|\___/ \__|_|_| |_|\___\__,_|\__|_|\___/|_| |_|___/       |
+#   |                                                                      |
+#   '----------------------------------------------------------------------'
+
 config.declare_permission("action.customnotification",
         _("Send custom notification"),
         _("Manually let the core send a notification to a host or service in order "
@@ -235,7 +329,7 @@ config.declare_permission("action.customnotification",
 
 def command_custom_notification(cmdtag, spec, row):
     if html.var("_customnotification"):
-        comment = html.var_utf8("_cusnot_comment")
+        comment = html.get_unicode_input("_cusnot_comment")
         broadcast = html.get_checkbox("_cusnot_broadcast") and 1 or 0
         forced = html.get_checkbox("_cusnot_forced") and 2 or 0
         command = "SEND_CUSTOM_%s_NOTIFICATION;%s;%s;%s;%s" % \
@@ -259,15 +353,36 @@ multisite_commands.append({
     "action"      : command_custom_notification,
 })
 
-# ACKNOWLEDGE
+
+#.
+#   .--Acknowledge---------------------------------------------------------.
+#   |       _        _                        _          _                 |
+#   |      / \   ___| | ___ __   _____      _| | ___  __| | __ _  ___      |
+#   |     / _ \ / __| |/ / '_ \ / _ \ \ /\ / / |/ _ \/ _` |/ _` |/ _ \     |
+#   |    / ___ \ (__|   <| | | | (_) \ V  V /| |  __/ (_| | (_| |  __/     |
+#   |   /_/   \_\___|_|\_\_| |_|\___/ \_/\_/ |_|\___|\__,_|\__, |\___|     |
+#   |                                                      |___/           |
+#   '----------------------------------------------------------------------'
+
 config.declare_permission("action.acknowledge",
         _("Acknowledge"),
         _("Acknowledge host and service problems and remove acknowledgements"),
         [ "user", "admin" ])
 
 def command_acknowledgement(cmdtag, spec, row):
+    if "aggr_tree" in row: # BI mode
+        specs = []
+        for site, host, service in bi.find_all_leaves(row["aggr_tree"]):
+            if service:
+                spec = "%s;%s" % (host, service)
+                cmdtag = "SVC"
+            else:
+                spec = host
+                cmdtag = "HOST"
+            specs.append((site, spec, cmdtag))
+
     if html.var("_acknowledge"):
-        comment = html.var_utf8("_ack_comment")
+        comment = html.get_unicode_input("_ack_comment")
         if not comment:
             raise MKUserError("_ack_comment", _("You need to supply a comment."))
         if ";" in comment:
@@ -279,24 +394,38 @@ def command_acknowledgement(cmdtag, spec, row):
         expire_secs = Age().from_html_vars("_ack_expire")
         if expire_secs:
             expire = int(time.time()) + expire_secs
+            expire_text = ";%d" % expire
         else:
-            expire = 0
+            expire_text = ""
+
+        def make_command(spec, cmdtag):
+            return "ACKNOWLEDGE_" + cmdtag + "_PROBLEM;%s;%d;%d;%d;%s" % \
+                          (spec, sticky, sendnot, perscomm, config.user_id) + (";%s" % lqencode(comment)) \
+                          + expire_text
+
+        if "aggr_tree" in row: # BI mode
+            commands = [(site, make_command(spec, cmdtag)) for (site, spec, cmdtag) in specs ]
+        else:
+            commands = [ make_command(spec, cmdtag) ]
 
-        command = "ACKNOWLEDGE_" + cmdtag + "_PROBLEM;%s;%d;%d;%d;%s" % \
-                      (spec, sticky, sendnot, perscomm, config.user_id) + (";%s" % lqencode(comment)) \
-                      + (";%d" % expire)
         title = _("<b>acknowledge the problems%s</b> of") % \
-                    (expire and (_(" for a period of %s") % Age().value_to_text(expire_secs)) or "")
-        return command, title
+                    (expire_text and (_(" for a period of %s") % Age().value_to_text(expire_secs)) or "")
+        return commands, title
 
     elif html.var("_remove_ack"):
-        command = "REMOVE_" + cmdtag + "_ACKNOWLEDGEMENT;%s" % spec
+        def make_command(spec, cmdtag):
+            return "REMOVE_" + cmdtag + "_ACKNOWLEDGEMENT;%s" % spec
+
+        if "aggr_tree" in row: # BI mode
+            commands = [(site, make_command(spec, cmdtag)) for (site, spec, cmdtag) in specs ]
+        else:
+            commands = [ make_command(spec, cmdtag) ]
         title = _("<b>remove acknowledgements</b> from")
-        return command, title
+        return commands, title
 
 
 multisite_commands.append({
-    "tables"      : [ "host", "service" ],
+    "tables"      : [ "host", "service", "aggr" ],
     "permission"  : "action.acknowledge",
     "title"       : _("Acknowledge Problems"),
     "render"      : lambda: \
@@ -317,7 +446,16 @@ multisite_commands.append({
 })
 
 
-# COMMENTS
+#.
+#   .--Comments------------------------------------------------------------.
+#   |           ____                                     _                 |
+#   |          / ___|___  _ __ ___  _ __ ___   ___ _ __ | |_ ___           |
+#   |         | |   / _ \| '_ ` _ \| '_ ` _ \ / _ \ '_ \| __/ __|          |
+#   |         | |__| (_) | | | | | | | | | | |  __/ | | | |_\__ \          |
+#   |          \____\___/|_| |_| |_|_| |_| |_|\___|_| |_|\__|___/          |
+#   |                                                                      |
+#   '----------------------------------------------------------------------'
+
 config.declare_permission("action.addcomment",
         _("Add comments"),
         _("Add comments to hosts or services, and remove comments"),
@@ -325,7 +463,7 @@ config.declare_permission("action.addcomment",
 
 def command_comment(cmdtag, spec, row):
     if html.var("_add_comment"):
-        comment = html.var_utf8("_comment")
+        comment = html.get_unicode_input("_comment")
         if not comment:
             raise MKUserError("_comment", _("You need to supply a comment."))
         command = "ADD_" + cmdtag + "_COMMENT;%s;1;%s" % \
@@ -345,7 +483,17 @@ multisite_commands.append({
     "action"      : command_comment,
 })
 
-# DOWNTIMES
+
+#.
+#   .--Downtimes-----------------------------------------------------------.
+#   |         ____                      _   _                              |
+#   |        |  _ \  _____      ___ __ | |_(_)_ __ ___   ___  ___          |
+#   |        | | | |/ _ \ \ /\ / / '_ \| __| | '_ ` _ \ / _ \/ __|         |
+#   |        | |_| | (_) \ V  V /| | | | |_| | | | | | |  __/\__ \         |
+#   |        |____/ \___/ \_/\_/ |_| |_|\__|_|_| |_| |_|\___||___/         |
+#   |                                                                      |
+#   '----------------------------------------------------------------------'
+
 config.declare_permission("action.downtimes",
         _("Set/Remove Downtimes"),
         _("Schedule and remove downtimes on hosts and services"),
@@ -355,14 +503,20 @@ def command_downtime(cmdtag, spec, row):
     down_from = int(time.time())
     down_to = None
 
+    if has_recurring_downtimes() and html.get_checkbox("_down_do_recur"):
+        recurring_type = int(html.var("_down_recurring"))
+        title_start = _("schedule a periodic downtime every %s") % wato.recurring_downtimes_types[recurring_type]
+    else:
+        title_start = _("schedule an immediate downtime")
+
     if html.var("_down_2h"):
         down_to = down_from + 7200
-        title = _("<b>schedule an immediate 2-hour downtime</b> on")
+        title = _("<b>%s of 2 hours length</b> on") % title_start
 
     elif html.var("_down_today"):
         br = time.localtime(down_from)
         down_to = time.mktime((br.tm_year, br.tm_mon, br.tm_mday, 23, 59, 59, 0, 0, br.tm_isdst)) + 1
-        title = _("<b>schedule an immediate downtime until 24:00:00</b> on")
+        title = _("<b>%s until 24:00:00</b> on") % title_start
 
     elif html.var("_down_week"):
         br = time.localtime(down_from)
@@ -370,7 +524,7 @@ def command_downtime(cmdtag, spec, row):
         days_plus = 6 - wday
         down_to = time.mktime((br.tm_year, br.tm_mon, br.tm_mday, 23, 59, 59, 0, 0, br.tm_isdst)) + 1
         down_to += days_plus * 24 * 3600
-        title = _("<b>schedule an immediate downtime until sunday night</b> on")
+        title = _("<b>%s until sunday night</b> on") % title_start
 
     elif html.var("_down_month"):
         br = time.localtime(down_from)
@@ -381,12 +535,12 @@ def command_downtime(cmdtag, spec, row):
         else:
             new_year = br.tm_year
         down_to = time.mktime((new_year, new_month, 1, 0, 0, 0, 0, 0, br.tm_isdst))
-        title = _("<b>schedule an immediate downtime until end of month</b> on")
+        title = _("<b>%s until end of month</b> on") % title_start
 
     elif html.var("_down_year"):
         br = time.localtime(down_from)
         down_to = time.mktime((br.tm_year, 12, 31, 23, 59, 59, 0, 0, br.tm_isdst)) + 1
-        title = _("<b>schedule an immediate downtime until end of %d</b> on") % br.tm_year
+        title = _("<b>%s until end of %d</b> on") % (title_start, br.tm_year)
 
     elif html.var("_down_from_now"):
         try:
@@ -398,12 +552,12 @@ def command_downtime(cmdtag, spec, row):
             raise MKUserError("_down_minutes", _("Please enter a positive number of minutes."))
 
         down_to = time.time() + minutes * 60
-        title = _("<b>schedule an immediate downtime for the next %d minutes</b> on" % minutes)
+        title = _("<b>%s for the next %d minutes</b> on" % (title_start, minutes))
 
     elif html.var("_down_adhoc"):
         minutes = config.adhoc_downtime.get("duration",0)
         down_to = time.time() + minutes * 60
-        title = _("<b>schedule an immediate downtime for the next %d minutes</b> on" % minutes)
+        title = _("<b>%s for the next %d minutes</b> on" % (title_start, minutes))
 
     elif html.var("_down_custom"):
         down_from = html.get_datetime_input("_down_from")
@@ -412,6 +566,9 @@ def command_downtime(cmdtag, spec, row):
             raise MKUserError("_down_to", _("You cannot set a downtime that ends in the past. "
                          "This incident will be reported."))
 
+        if down_to < down_from:
+            raise MKUserError("_down_to", _("Your end date is before your start date."))
+
         title = _("<b>schedule a downtime from %s to %s</b> on ") % (
             time.asctime(time.localtime(down_from)),
             time.asctime(time.localtime(down_to)))
@@ -439,7 +596,7 @@ def command_downtime(cmdtag, spec, row):
         if html.var("_down_adhoc"):
             comment = config.adhoc_downtime.get("comment","")
         else:
-            comment = html.var_utf8("_down_comment")
+            comment = html.get_unicode_input("_down_comment")
         if not comment:
             raise MKUserError("_down_comment", _("You need to supply a comment for your downtime."))
         if html.var("_down_flexible"):
@@ -449,18 +606,38 @@ def command_downtime(cmdtag, spec, row):
             fixed = 1
             duration = 0
 
-        if html.var("_include_childs"): # only for hosts
-            specs = [ spec ] + get_child_hosts(row["site"], [spec], recurse = not not html.var("_include_childs_recurse"))
-        elif html.var("_on_hosts"): # set on hosts instead of services
-            specs = [ spec.split(";")[0] ]
-            title += " the hosts of"
-            cmdtag = "HOST"
+        if html.get_checkbox("_down_do_recur"):
+            fixed_and_recurring = recurring_type * 2 + fixed
         else:
-            specs = [ spec ]
+            fixed_and_recurring = fixed
+
+        def make_command(spec, cmdtag):
+            return ("SCHEDULE_" + cmdtag + "_DOWNTIME;%s;" % spec ) \
+                   + ("%d;%d;%d;0;%d;%s;" % (down_from, down_to, fixed_and_recurring, duration, config.user_id)) \
+                   + lqencode(comment)
+
+        if "aggr_tree" in row: # BI mode
+            commands = []
+            for site, host, service in bi.find_all_leaves(row["aggr_tree"]):
+                if service:
+                    spec = "%s;%s" % (host, service)
+                    cmdtag = "SVC"
+                else:
+                    spec = host
+                    cmdtag = "HOST"
+                commands.append((site, make_command(spec, cmdtag)))
+        else:
+            if html.var("_include_childs"): # only for hosts
+                specs = [ spec ] + get_child_hosts(row["site"], [spec], recurse = not not html.var("_include_childs_recurse"))
+            elif html.var("_on_hosts"): # set on hosts instead of services
+                specs = [ spec.split(";")[0] ]
+                title += " the hosts of"
+                cmdtag = "HOST"
+            else:
+                specs = [ spec ]
+
+            commands = [ make_command(spec, cmdtag) for spec in  specs ]
 
-        commands = [(("SCHEDULE_" + cmdtag + "_DOWNTIME;%s;" % spec ) \
-                   + ("%d;%d;%d;0;%d;%s;" % (down_from, down_to, fixed, duration, config.user_id)) \
-                   + lqencode(comment)) for spec in specs]
         return commands, title
 
 
@@ -483,7 +660,6 @@ def get_child_hosts(site, hosts, recurse):
 
 
 def paint_downtime_buttons(what):
-
     html.write(_('Downtime Comment')+": ")
     html.text_input("_down_comment", "", size=60, submit="")
     html.write("<hr>")
@@ -497,8 +673,9 @@ def paint_downtime_buttons(what):
     html.button("_down_week", _("This week"))
     html.button("_down_month", _("This month"))
     html.button("_down_year", _("This year"))
-    html.write(" &nbsp; - &nbsp;")
-    html.button("_down_remove", _("Remove all"))
+    if what != "aggr":
+        html.write(" &nbsp; - &nbsp;")
+        html.button("_down_remove", _("Remove all"))
     html.write("<hr>")
     if config.adhoc_downtime and config.adhoc_downtime.get("duration"):
         adhoc_duration = config.adhoc_downtime.get("duration")
@@ -514,17 +691,39 @@ def paint_downtime_buttons(what):
     html.write("&nbsp; "+_('to')+" &nbsp;")
     html.datetime_input("_down_to", time.time() + 7200, submit="_down_custom")
     html.write("<hr>")
-    html.checkbox("_down_flexible", False, label=_('flexible with max. duration')+" ")
+    html.checkbox("_down_flexible", False, label=_('flexible with duration')+" ")
     html.time_input("_down_duration", 2, 0)
     html.write(" "+_('(HH:MM)'))
-    html.write("<hr>")
     if what == "host":
+        html.write("<hr>")
         html.checkbox("_include_childs", False, label=_('Also set downtime on child hosts'))
         html.write("  ")
         html.checkbox("_include_childs_recurse", False, label=_('Do this recursively'))
-    else:
-        html.checkbox("_on_hosts", False, label=_('Schedule downtimes on the affected <b>hosts</b> instead of their services'))
+    elif what == "service":
+        html.write("<hr>")
+        html.checkbox("_on_hosts", False, label=_('Schedule downtimes on the affected '
+                                                  '<b>hosts</b> instead of on the individual '
+                                                  'services'))
 
+    if has_recurring_downtimes():
+        html.write("<hr>")
+        html.checkbox("_down_do_recur", False,
+                      label=_("Repeat this downtime on a regular base every"))
+        html.write(" ")
+        recurring_selections = [ (str(k), v) for (k,v) in
+                                 sorted(wato.recurring_downtimes_types.items())]
+        html.select("_down_recurring", recurring_selections, "3")
+        html.write(_("(This only works when using CMC)"))
+
+
+def has_recurring_downtimes():
+    try:
+        wato.recurring_downtimes_types # Check if this exists
+        return True
+    except AttributeError:
+        return False
+    except NameError:
+        return False
 
 
 multisite_commands.append({
@@ -545,33 +744,50 @@ multisite_commands.append({
     "group"       : _("Downtimes"),
 })
 
+multisite_commands.append({
+    "tables"      : [ "aggr" ],
+    "permission"  : "action.downtimes",
+    "title"       : _("Schedule downtimes"),
+    "render"      : lambda: paint_downtime_buttons("aggr"),
+    "action"      : command_downtime,
+    "group"       : _("Downtimes"),
+})
+
 # REMOVE DOWNTIMES (table downtimes)
 multisite_commands.append({
     "tables"      : [ "downtime" ],
     "permission"  : "action.downtimes",
-    "title"       : _("Downtimes"),
-    "render"      : lambda: \
-        html.button("_remove_downtimes", _("Remove")),
-    "action"      : lambda cmdtag, spec, row: \
-      html.has_var("_remove_downtimes") and \
-      ( "DEL_%s_DOWNTIME;%d" % (cmdtag, spec),
-        _("remove"))
+    "title"       : _("Remove downtimes"),
+    "render"      : lambda: html.button("_remove_downtimes", _("Remove")),
+    "action"      : lambda cmdtag, spec, row: html.has_var("_remove_downtimes") and \
+                           ( "DEL_%s_DOWNTIME;%d" % (cmdtag, spec), _("remove"))
 })
 
 # REMOVE COMMENTS (table comments)
+
+def remove_comments(cmdtag, spec, row):
+    if html.has_var("_remove_comments"):
+        commands = [("DEL_%s_COMMENT;%d" % (cmdtag, spec))]
+        if row.get("comment_entry_type") == 4:
+            if row.get("service_description"):
+                commands.append(("REMOVE_%s_ACKNOWLEDGEMENT;%s;%s" %\
+                                (cmdtag, row["host_name"], row["service_description"])))
+            else:
+                commands.append(("REMOVE_%s_ACKNOWLEDGEMENT;%s" %\
+                                (cmdtag, row["host_name"])))
+
+        return commands, _("remove")
+
 multisite_commands.append({
     "tables"      : [ "comment" ],
     "permission"  : "action.addcomment",
-    "title"       : _("Comments"),
-    "render"      : lambda: \
-        html.button("_remove_comments", _("Remove")),
-    "action"      : lambda cmdtag, spec, row: \
-      html.has_var("_remove_comments") and \
-      ( "DEL_%s_COMMENT;%d" % (cmdtag, spec),
-        _("remove"))
+    "title"       : _("Remove comments"),
+    "render"      : lambda: html.button("_remove_comments", _("Remove")),
+    "action"      : remove_comments
 })
 
-#   .--Stars *-------------------------------------------------------------.
+#.
+#   .--Stars * (Favorites)-------------------------------------------------.
 #   |                   ____  _                                            |
 #   |                  / ___|| |_ __ _ _ __ ___  __/\__                    |
 #   |                  \___ \| __/ _` | '__/ __| \    /                    |
