@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -53,7 +53,7 @@
 # needed for constructing Nagios commands)
 # those columns are always fetched from the datasource for each item
 #
-# idkeys: these are used to generate a key which is uniq for each data row
+# idkeys: these are used to generate a key which is unique for each data row
 # is used to identify an item between http requests
 #
 # join: A view can display e.g. host-rows and include information from e.g.
@@ -84,6 +84,13 @@ multisite_datasources["hosts"] = {
     # to handle the data provided by the single_spec value of the "hostgroup"
     # info, which is in fact the name of the wanted hostgroup
     "link_filters" : { "hostgroup": "opthostgroup" },
+    # When these filters are set, the site hint will not be added to urls
+    # which link to views using this datasource, because the resuling view
+    # should show the objects spread accross the sites
+    "multiple_site_filters" : [
+        "hostgroup",
+        "servicegroup",
+    ],
 }
 
 multisite_datasources["hostsbygroup"] = {
@@ -110,6 +117,13 @@ multisite_datasources["services"] = {
         "hostgroup"    : "opthostgroup",
         "servicegroup" : "optservicegroup",
     },
+    # When these filters are set, the site hint will not be added to urls
+    # which link to views using this datasource, because the resuling view
+    # should show the objects spread accross the sites
+    "multiple_site_filters" : [
+        "hostgroup",
+        "servicegroup",
+    ],
 }
 
 multisite_datasources["servicesbygroup"] = {
@@ -168,7 +182,7 @@ multisite_datasources["comments"] = {
     "title"    : _("Host- and Servicecomments"),
     "table"    : "comments",
     "infos"    : [ "comment", "host", "service" ],
-    "keys"     : [ "comment_id", "comment_type" ],
+    "keys"     : [ "comment_id", "comment_type", "host_name", "service_description" ],
     "idkeys"   : [ "comment_id" ],
 }
 
