@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -129,28 +129,13 @@ multisite_sorters['servicelevel'] = {
     'cmp'     : lambda r1, r2: cmp_custom_variable(r1, r2, 'EC_SL', cmp_simple_number)
 }
 
-def cmp_service_name_equiv(r):
-    if r == "Check_MK":
-        return -5
-    elif r == "Check_MK Discovery":
-        return -4
-    elif r == "Check_MK inventory":
-        return -3 # FIXME: Remove old name one day
-    elif r == "Check_MK HW/SW Inventory":
-        return -2
-    else:
-        return 0
-
 def cmp_service_name(column, r1, r2):
-    o = cmp(cmp_service_name_equiv(r1[column]), cmp_service_name_equiv(r2[column]))
-    if o == 0:
-        return cmp_simple_string(column, r1, r2)
-    else:
-        return o
+    return cmp(cmp_service_name_equiv(r1[column]), cmp_service_name_equiv(r2[column])) or \
+           cmp_num_split(column, r1, r2)
 
-#                      name           title                    column                       sortfunction
+#                      name                      title                              column                       sortfunction
 declare_simple_sorter("svcdescr",                _("Service description"),         "service_description",        cmp_service_name)
-declare_simple_sorter("svcdispname",             _("Service alternative display name"),   "service_display_name",  cmp_simple_string)
+declare_simple_sorter("svcdispname",             _("Service alternative display name"), "service_display_name",  cmp_simple_string)
 declare_simple_sorter("svcoutput",               _("Service plugin output"),       "service_plugin_output",      cmp_simple_string)
 declare_simple_sorter("svc_long_plugin_output",  _("Long output of check plugin"), "service_long_plugin_output", cmp_simple_string)
 declare_simple_sorter("site",                    _("Site"),                        "site",                       cmp_simple_string)
@@ -182,7 +167,7 @@ declare_1to1_sorter("svc_staleness",              cmp_simple_number)
 declare_1to1_sorter("svc_servicelevel",           cmp_simple_number)
 
 def cmp_perfdata_nth_value(r1, r2, n):
-    return cmp(savefloat(get_perfdata_nth_value(r1, n)), savefloat(get_perfdata_nth_value(r2, n)))
+    return cmp(savefloat(get_perfdata_nth_value(r1, n, True)), savefloat(get_perfdata_nth_value(r2, n, True)))
 
 multisite_sorters['svc_perf_val01'] = {
     "title"   : _("Service performance data - value number %02d" % 1),
@@ -239,6 +224,7 @@ multisite_sorters['svc_perf_val10'] = {
 # Host
 declare_1to1_sorter("alias",                  cmp_num_split)
 declare_1to1_sorter("host_address",           cmp_ip_address)
+declare_1to1_sorter("host_address_family",    cmp_simple_number)
 declare_1to1_sorter("host_plugin_output",     cmp_simple_string)
 declare_1to1_sorter("host_perf_data",         cmp_simple_string)
 declare_1to1_sorter("host_check_command",     cmp_simple_string)
@@ -270,6 +256,30 @@ declare_1to1_sorter("host_contacts",          cmp_string_list)
 declare_1to1_sorter("host_contact_groups",    cmp_string_list)
 declare_1to1_sorter("host_servicelevel",      cmp_simple_number)
 
+
+def cmp_host_ipv4_address(r1, r2):
+    def get_address(row):
+        custom_vars = dict(zip(row["host_custom_variable_names"],
+                               row["host_custom_variable_values"]))
+        return custom_vars.get("ADDRESS_4", "")
+
+    def split_ip(ip):
+        try:
+            return tuple(int(part) for part in ip.split('.'))
+        except:
+            return ip
+
+    v1, v2 = split_ip(get_address(r1)), split_ip(get_address(r2))
+    return cmp(v1, v2)
+
+
+multisite_sorters["host_ipv4_address"] = {
+    "title"   : _("Host IPv4 address"),
+    "cmp"     : cmp_host_ipv4_address,
+    "columns" : [ "host_custom_variable_names", "host_custom_variable_values"],
+}
+
+
 def cmp_host_problems(r1, r2):
     return cmp(r1["host_num_services"] - r1["host_num_services_ok"] - r1["host_num_services_pending"],
                r2["host_num_services"] - r2["host_num_services_ok"] - r2["host_num_services_pending"])
