@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -33,7 +33,8 @@ except ImportError:
 
 from lib import *
 from valuespec import *
-import config, table
+import config, table, userdb
+import pagetypes # That will replace visuals.py one day
 
 #   .--Plugins-------------------------------------------------------------.
 #   |                   ____  _             _                              |
@@ -48,9 +49,9 @@ import config, table
 
 loaded_with_language = False
 
-def load_plugins():
+def load_plugins(force):
     global loaded_with_language
-    if loaded_with_language == current_language:
+    if loaded_with_language == current_language and not force:
         return
 
     global visual_types
@@ -95,15 +96,19 @@ def load_plugins():
 #   |                                                                      |
 #   '----------------------------------------------------------------------'
 
-def save(what, visuals):
+def save(what, visuals, user_id = None):
+    if user_id == None:
+        user_id = config.user_id
+
     uservisuals = {}
-    for (user_id, name), visual in visuals.items():
-        if config.user_id == user_id:
+    for (owner_id, name), visual in visuals.items():
+        if user_id == owner_id:
             uservisuals[name] = visual
-    config.save_user_file('user_' + what, uservisuals)
+    config.save_user_file('user_' + what, uservisuals, user = user_id, unlock=True)
 
-
-def load(what, builtin_visuals, skip_func = None):
+# FIXME: Currently all user visual files of this type are locked. We could optimize
+# this not to lock all files but only lock the files the user is about to modify.
+def load(what, builtin_visuals, skip_func = None, lock=False):
     visuals = {}
 
     # first load builtins. Set username to ''
@@ -119,7 +124,7 @@ def load(what, builtin_visuals, skip_func = None):
 
         visuals[('', name)] = visual
 
-    # Now scan users subdirs for files "visuals.mk"
+    # Now scan users subdirs for files "user_*.mk"
     subdirs = os.listdir(config.config_dir)
     for user in subdirs:
         try:
@@ -137,6 +142,12 @@ def load(what, builtin_visuals, skip_func = None):
             if not os.path.exists(path):
                 continue
 
+            if not userdb.user_exists(user):
+                continue
+
+            if lock:
+                aquire_lock(path)
+
             user_visuals = eval(file(path).read())
             for name, visual in user_visuals.items():
                 visual["owner"] = user
@@ -156,15 +167,15 @@ def load(what, builtin_visuals, skip_func = None):
                         if attr not in visual and attr in builtin_visual:
                             visual[attr] = builtin_visual[attr]
 
+                # Repair visuals with missing 'title' or 'description'
+                visual.setdefault("title", name)
+                visual.setdefault("description", "")
+
                 # Declare custom permissions
                 declare_visual_permission(what, name, visual)
 
                 visuals[(user, name)] = visual
 
-                # Repair visuals with missing 'title' or 'description'
-                for key in [ "title", "description" ]:
-                    if key not in visual:
-                        visual[key] = _("Missing %s") % key
 
         except SyntaxError, e:
             raise MKGeneralException(_("Cannot load %s from %s: %s") % (what, path, e))
@@ -249,6 +260,9 @@ def available(what, all_visuals):
 #   | Show a list of all visuals with actions to delete/clone/edit         |
 #   '----------------------------------------------------------------------'
 
+# TODO: This code has been copied to a new live into htdocs/pagetypes.py
+# We need to convert all existing page types (views, dashboards, reports)
+# to pagetypes.py and then remove this function!
 def page_list(what, title, visuals, custom_columns = [],
     render_custom_buttons = None,
     render_custom_columns = None,
@@ -268,28 +282,41 @@ def page_list(what, title, visuals, custom_columns = [],
     for other_what, info in visual_types.items():
         if what != other_what:
             html.context_button(info["plural_title"].title(), 'edit_%s.py' % other_what, other_what[:-1])
+
+    # TODO: We hack in those visuals that already have been moved to pagetypes here
+    if pagetypes.has_page_type("graph_collection"):
+        html.context_button(_("Graph Collections"), "graph_collections.py", "graph_collection")
+    if pagetypes.has_page_type("custom_graph"):
+        html.context_button(_("Custom Graphs"), "custom_graphs.py", "custom_graph")
+    html.context_button(_("Bookmark Lists"), "bookmark_lists.py", "bookmark_list")
+
     html.end_context_buttons()
 
     # Deletion of visuals
     delname  = html.var("_delete")
     if delname and html.transaction_valid():
-        deltitle = visuals[(config.user_id, delname)]['title']
+        if config.may('general.delete_foreign_%s' % what):
+            user_id = html.var('_user_id', config.user_id)
+        else:
+            user_id = config.user_id
+
+        deltitle = visuals[(user_id, delname)]['title']
 
         try:
             if check_deletable_handler:
-                check_deletable_handler(visuals, delname)
+                check_deletable_handler(visuals, user_id, delname)
 
             c = html.confirm(_("Please confirm the deletion of \"%s\".") % deltitle)
             if c:
-                del visuals[(config.user_id, delname)]
-                save(what, visuals)
+                del visuals[(user_id, delname)]
+                save(what, visuals, user_id)
                 html.reload_sidebar()
             elif c == False:
                 html.footer()
                 return
         except MKUserError, e:
-            html.write("<div class=error>%s</div>\n" % e.message)
-            html.add_user_error(e.varname, e.message)
+            html.write("<div class=error>%s</div>\n" % e)
+            html.add_user_error(e.varname, e)
 
     keys_sorted = visuals.keys()
     keys_sorted.sort(cmp = lambda a,b: -cmp(a[0],b[0]) or cmp(a[1], b[1]))
@@ -318,10 +345,6 @@ def page_list(what, title, visuals, custom_columns = [],
             # Actions
             table.cell(_('Actions'), css = 'buttons visuals')
 
-            # Edit
-            if owner == config.user_id:
-                html.icon_button("edit_%s.py?load_name=%s" % (what_s, visual_name), _("Edit"), "edit")
-
             # Clone / Customize
             buttontext = _("Create a customized copy of this")
             backurl = html.urlencode(html.makeuri([]))
@@ -330,9 +353,15 @@ def page_list(what, title, visuals, custom_columns = [],
             html.icon_button(clone_url, buttontext, "clone")
 
             # Delete
+            if owner and (owner == config.user_id or config.may('general.delete_foreign_%s' % what)):
+                add_vars = [('_delete', visual_name)]
+                if owner != config.user_id:
+                    add_vars.append(('_user_id', owner))
+                html.icon_button(html.makeactionuri(add_vars), _("Delete!"), "delete")
+
+            # Edit
             if owner == config.user_id:
-                html.icon_button(html.makeactionuri([('_delete', visual_name)]),
-                    _("Delete!"), "delete")
+                html.icon_button("edit_%s.py?load_name=%s" % (what_s, visual_name), _("Edit"), "edit")
 
             # Custom buttons - visual specific
             if render_custom_buttons:
@@ -424,8 +453,8 @@ def page_create_visual(what, info_keys, next_url = None):
             return
 
         except MKUserError, e:
-            html.write("<div class=error>%s</div>\n" % e.message)
-            html.add_user_error(e.varname, e.message)
+            html.write("<div class=error>%s</div>\n" % e)
+            html.add_user_error(e.varname, e)
 
     html.begin_form('create_visual')
     html.hidden_field('mode', 'create')
@@ -457,43 +486,45 @@ def page_create_visual(what, info_keys, next_url = None):
 def get_context_specs(visual, info_handler):
     context_specs = []
     info_keys = info_handler and info_handler(visual) or infos.keys()
-    for info_key in info_keys:
+
+    single_info_keys = [key for key in info_keys if key in visual['single_infos']]
+    multi_info_keys =  [key for key in info_keys if key not in single_info_keys]
+
+    def visual_spec_single(info_key):
         info = infos[info_key]
+        params = info['single_spec']
+        optional = True
+        isopen = True
+        return Dictionary(
+            title = info['title'],
+            # render = 'form',
+            form_isopen = isopen,
+            optional_keys = optional,
+            elements = params,
+        )
 
-        if info_key in visual['single_infos']:
-            params = info['single_spec']
-            optional = True
-            isopen = True
-            vs = Dictionary(
-                title = info['title'],
-                # render = 'form',
-                form_isopen = isopen,
-                optional_keys = optional,
-                elements = params,
-            )
-        else:
-            filter_list  = VisualFilterList([info_key], title=info['title'])
-            filter_names = filter_list.filter_names()
+    def visual_spec_multi(info_key):
+        info = infos[info_key]
+        filter_list  = VisualFilterList([info_key], title=info['title'], ignore=set(single_info_keys))
+        filter_names = filter_list.filter_names()
 
-            if not filter_names:
-                continue # Skip infos which have no filters available
+        if not filter_names:
+            return # Skip infos which have no filters available
 
-            params = [
-                ('filters', filter_list),
-            ]
-            optional = None
-            # Make it open by default when at least one filter is used
-            isopen = bool([ fn for fn in visual.get('context', {}).keys()
-                                                   if fn in filter_names ])
-            vs = filter_list
+        params = [
+            ('filters', filter_list),
+        ]
+        optional = None
+        # Make it open by default when at least one filter is used
+        isopen = bool([ fn for fn in visual.get('context', {}).keys()
+                                                if fn in filter_names ])
+        return filter_list
 
+    # single infos first, the rest afterwards
+    return [(info_key, visual_spec_single(info_key)) for info_key in single_info_keys] +\
+        [(info_key, visual_spec_multi(info_key)) for info_key in multi_info_keys
+                            if visual_spec_multi(info_key) ]
 
-        # Single info context specifications should be listed first
-        if info_key in visual['single_infos']:
-            context_specs.insert(0, (info_key, vs))
-        else:
-            context_specs.append((info_key, vs))
-    return context_specs
 
 def process_context_specs(context_specs):
     context = {}
@@ -552,6 +583,7 @@ def page_edit_visual(what, all_visuals, custom_field_handler = None,
                 n += 1
                 newname = visualname + "_clone%d" % n
             visual["name"] = newname
+            visual["public"] = False
             visualname = newname
             oldname = None # Prevent renaming
             if cloneuser == config.user_id:
@@ -563,6 +595,7 @@ def page_edit_visual(what, all_visuals, custom_field_handler = None,
                 mode = 'clone'
                 if not visual:
                     raise MKGeneralException(_('The requested %s does not exist.') % visual_types[what]['title'])
+                visual["public"] = False
 
         single_infos = visual['single_infos']
 
@@ -721,8 +754,8 @@ def page_edit_visual(what, all_visuals, custom_field_handler = None,
                 return
 
         except MKUserError, e:
-            html.write("<div class=error>%s</div>\n" % e.message)
-            html.add_user_error(e.varname, e.message)
+            html.write("<div class=error>%s</div>\n" % e)
+            html.add_user_error(e.varname, e)
 
     html.begin_form("visual", method = "POST")
     html.hidden_field("back", back_url)
@@ -730,7 +763,7 @@ def page_edit_visual(what, all_visuals, custom_field_handler = None,
     html.hidden_field("load_user", html.var("load_user", "")) # safe old name in case user changes it
     html.hidden_field("load_name", oldname) # safe old name in case user changes it
 
-    # FIXME: Hier werden die Flags aus visbility nicht korrekt geladen. Wäre es nicht besser,
+    # FIXME: Hier werden die Flags aus visibility nicht korrekt geladen. Wäre es nicht besser,
     # diese in einem Unter-Dict zu lassen, anstatt diese extra umzukopieren?
     visib = []
     for key, title in visibility_choices:
@@ -787,6 +820,23 @@ def declare_filter(sort_index, f, comment = None):
     f.comment = comment
     f.sort_index = sort_index
 
+
+def show_filter(f):
+    html.write('<div class="floatfilter %s">' % (f.double_height() and "double" or "single"))
+    html.write('<div class=legend>%s</div>' % html.attrencode(f.title))
+    html.write('<div class=content>')
+    try:
+        f.display()
+    except Exception, e:
+        if config.debug:
+            raise
+        html.icon(_("This filter cannot be displayed"), "alert")
+        html.write("%s" % e)
+
+    html.write("</div>")
+    html.write("</div>")
+
+
 # Base class for all filters
 # name:          The unique id of that filter. This id is e.g. used in the
 #                persisted view configuration
@@ -873,6 +923,18 @@ class Filter:
         for varname in self.htmlvars:
             html.set_var(varname, value.get(varname))
 
+
+
+# TODO: We should merge this with Filter() and make all vars unicode ...
+class FilterUnicodeFilter(Filter):
+    def value(self):
+        val = {}
+        for varname in self.htmlvars:
+            val[varname] = html.get_unicode_input(varname, '')
+        return val
+
+
+
 def get_filter(name):
     return multisite_filters[name]
 
@@ -968,7 +1030,7 @@ def add_context_to_uri_vars(visual, only_infos=None, only_count=False):
     for info_key in only_infos:
         for filter_name, filter_vars in visual['context'].items():
             if type(filter_vars) == dict: # this is a multi-context filter
-                # We add the filter only if *none* if its HTML variables are present on the URL
+                # We add the filter only if *none* of its HTML variables are present on the URL
                 # This important because checkbox variables are not present if the box is not checked.
                 skip = False
                 for uri_varname, value in filter_vars.items():
@@ -1045,20 +1107,23 @@ class VisualFilterList(ListOfMultiple):
     def __init__(self, infos, **kwargs):
         self._infos = infos
 
+        ignore = kwargs.get("ignore", set())
+
         # First get all filters useful for the infos, then create VisualFilter
         # valuespecs from them and then sort them
         fspecs = {}
         self._filters = {}
         for info in self._infos:
             for fname, filter in filters_allowed_for_info(info).items():
-                if fname not in fspecs and fname not in ubiquitary_filters:
+                if fname not in fspecs and fname not in ignore:
                     fspecs[fname] = VisualFilter(fname,
                         title = filter.title,
                     )
                     self._filters[fname] = fspecs[fname]._filter
 
         # Convert to list and sort them!
-        fspecs = sorted(fspecs.items(), key=lambda x: (x[1]._filter.sort_index, x[1].title()))
+        fspecs = sorted(fspecs.items(),
+            key=lambda x: (x[1]._filter.sort_index, x[1].title()))
 
         kwargs.setdefault('title', _('Filters'))
         kwargs.setdefault('add_label', _('Add filter'))
@@ -1070,6 +1135,7 @@ class VisualFilterList(ListOfMultiple):
     def filter_names(self):
         return self._filters.keys()
 
+
 # Realizes a Multisite/visual filter in a valuespec. It can render the filter form, get
 # the filled in values and provide the filled in information for persistance.
 class VisualFilter(ValueSpec):
@@ -1092,12 +1158,7 @@ class VisualFilter(ValueSpec):
             self._filter.set_value(value)
 
         # A filter can not be used twice on a page, because the varprefix is not used
-        html.write('<div class="floatfilter %s">' % (self._filter.double_height() and "double" or "single"))
-        html.write('<div class=legend>%s</div>' % self._filter.title)
-        html.write('<div class=content>')
-        self._filter.display()
-        html.write("</div>")
-        html.write("</div>")
+        show_filter(self._filter)
 
     def value_to_text(self, value):
         # FIXME: optimize. Needed?
@@ -1158,6 +1219,12 @@ def unpack_context_after_editing(packed_context):
 #   |                                                                      |
 #   '----------------------------------------------------------------------'
 
+def declare_info(infoname, info):
+    infos[infoname] = info
+
+def is_single_site_info(info_key):
+    return infos[info_key].get('single_site', True)
+
 def single_infos_spec(single_infos):
     return ('single_infos', FixedValue(single_infos,
         title = _('Show information of single'),
@@ -1216,11 +1283,15 @@ def visual_title(what, visual):
 # the variables "event_id" and "history_line" to be set in order
 # to exactly specify one history entry.
 def info_params(info_key):
-    return dict(infos[info_key]['single_spec']).keys()
+    single_spec = infos[info_key]['single_spec']
+    if single_spec == None:
+        return []
+    else:
+        return dict(single_spec).keys()
 
 def get_single_info_keys(visual):
     keys = []
-    for info_key in visual['single_infos']:
+    for info_key in visual.get('single_infos', []):
         keys += info_params(info_key)
     return list(set(keys))
 
@@ -1233,7 +1304,7 @@ def get_singlecontext_vars(visual):
 def get_singlecontext_html_vars(visual):
     vars = get_singlecontext_vars(visual)
     for key in get_single_info_keys(visual):
-        val = html.var_utf8(key)
+        val = html.get_unicode_input(key)
         if val != None:
             vars[key] = val
     return vars
@@ -1301,6 +1372,11 @@ def collect_context_links_of(visual_type_name, this_visual, active_filter_vars,
                 break
             vars_values.append((var, val))
 
+        # When all infos of the target visual are showing single site data, add
+        # the site hint when available
+        if html.var('site') and all([ is_single_site_info(info_key)for info_key in visual['single_infos']]):
+            vars_values.append(('site', html.var('site')))
+
         if not skip:
             # add context link to this visual. For reports we put in
             # the *complete* context, even the non-single one.
@@ -1344,8 +1420,12 @@ def transform_old_visual(visual):
 #   |  Handling of popup for adding a visual element to a dashboard, etc.  |
 #   '----------------------------------------------------------------------'
 
+# TODO: Remove this code as soon as everything is moved over to pagetypes.py
 def ajax_popup_add():
+    add_type = html.var("add_type")
+
     html.write("<ul>")
+    pagetypes.render_addto_popup(add_type)
 
     for visual_type_name, visual_type in visual_types.items():
         if "popup_add_handler" in visual_type:
@@ -1362,8 +1442,8 @@ def ajax_popup_add():
 
 
 def ajax_add_visual():
-    visual_type = html.var('visual_type') # dashboards / views / ...
-    visual_type = visual_types[visual_type]
+    visual_type_name = html.var('visual_type') # dashboards / views / ...
+    visual_type = visual_types[visual_type_name]
     module_name = visual_type["module_name"]
     visual_module = __import__(module_name)
     handler = visual_module.__dict__[visual_type["add_visual_handler"]]
@@ -1373,12 +1453,8 @@ def ajax_add_visual():
     # type of the visual to add (e.g. view)
     element_type = html.var("type")
 
-    # Context and params are | separated lists of : separated triples
-    # of name, datatype and value. Datatype is int or string
     extra_data = []
     for what in [ 'context', 'params' ]:
-        value = html.var(what)
-        if value:
-            extra_data.append(json.loads(value))
+        extra_data.append(json.loads(html.var(what)))
 
     handler(visual_name, element_type, *extra_data)
