@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -28,22 +28,40 @@
 
 # Filters for substring search, displaying a text input field
 class FilterText(Filter):
-    def __init__(self, name, title, info, column, htmlvar, op):
-        Filter.__init__(self, name, title, info, [htmlvar], [column])
+    def __init__(self, name, title, info, column, htmlvar, op, negateable=False):
+        htmlvars = [htmlvar]
+        if negateable:
+            htmlvars.append("neg_" + htmlvar)
+        link_columns = type(column) == list and column or [column]
+        Filter.__init__(self, name, title, info, htmlvars, link_columns)
         self.op = op
         self.column = column
+        self.negateable = negateable
 
     def _current_value(self):
         htmlvar = self.htmlvars[0]
         return html.var(htmlvar, "")
 
     def display(self):
-        html.text_input(self.htmlvars[0], self._current_value())
+        current_value = self._current_value()
+        html.text_input(self.htmlvars[0], current_value, self.negateable and 'neg' or '')
+        if self.negateable:
+            html.write(" <nobr>")
+            html.checkbox(self.htmlvars[1], label=_("negate"))
+            html.write("</nobr>")
 
     def filter(self, infoname):
         current_value = self._current_value()
+
+        if self.negateable and html.get_checkbox(self.htmlvars[1]):
+            negate = "!"
+        else:
+            negate = ""
+
         if current_value:
-            return "Filter: %s %s %s\n" % (self.column, self.op, lqencode(current_value))
+            if type(current_value) == unicode:
+                current_value = current_value.encode("utf-8")
+            return "Filter: %s %s%s %s\n" % (self.column, negate, self.op, lqencode(current_value))
         else:
             return ""
 
@@ -55,28 +73,43 @@ class FilterText(Filter):
 
 
 class FilterUnicode(FilterText):
+    def __init__(self, *args):
+        FilterText.__init__(self, *args)
+
     def _current_value(self):
         htmlvar = self.htmlvars[0]
-        return html.var_utf8(htmlvar, "")
+        return html.get_unicode_input(htmlvar, "")
+
+class FilterHostnameOrAlias(FilterUnicode):
+    def __init__(self, *args):
+        FilterUnicode.__init__(self, *args)
 
     def filter(self, infoname):
         current_value = self._current_value()
+
+        if self.negateable and html.get_checkbox(self.htmlvars[1]):
+            negate = "!"
+        else:
+            negate = ""
+
         if current_value:
-            return "Filter: %s %s %s\n" % (self.column, self.op, lqencode(current_value.encode('utf-8')))
+            if type(current_value) == unicode:
+                current_value = current_value.encode("utf-8")
+            return "Filter: host_name %s%s %s\nFilter: host_alias %s%s %s\nOr: 2\n" % ((negate, self.op, lqencode(current_value)) * 2)
         else:
             return ""
 
 #                               filter          title              info       column           htmlvar
-declare_filter(100, FilterText("hostregex",    _("Hostname"),        "host",    "host_name",      "host_regex",    "~~"),
+declare_filter(100, FilterText("hostregex",    _("Hostname"),        "host",    "host_name",      "host_regex",    "~~" , True),
                           _("Search field allowing regular expressions and partial matches"))
 
-declare_filter(101, FilterText("host",    _("Hostname (exact match)"),             "host",    "host_name",          "host",    "="),
+declare_filter(101, FilterText("host",    _("Hostname (exact match)"),             "host",    "host_name",          "host",    "=", True),
                           _("Exact match, used for linking"))
 
-declare_filter(102, FilterUnicode("hostalias",   _("Hostalias"),      "host",     "host_alias",      "hostalias",    "~~"),
+declare_filter(102, FilterUnicode("hostalias",   _("Hostalias"),      "host",     "host_alias",      "hostalias",    "~~", True),
                           _("Search field allowing regular expressions and partial matches"))
 
-declare_filter(200, FilterUnicode("serviceregex", _("Service"),         "service", "service_description",   "service_regex", "~~"),
+declare_filter(200, FilterUnicode("serviceregex", _("Service"),         "service", "service_description",   "service_regex", "~~", True),
                           _("Search field allowing regular expressions and partial matches"))
 
 declare_filter(201, FilterUnicode("service", _("Service (exact match)"),              "service", "service_description",   "service", "="),
@@ -87,39 +120,135 @@ declare_filter(202, FilterUnicode("service_display_name", _("Service alternative
 
 declare_filter(202, FilterUnicode("output",  _("Status detail"), "service", "service_plugin_output", "service_output", "~~"))
 
+declare_filter(102, FilterHostnameOrAlias("hostnameoralias",   _("Hostname or Alias"), "host", ["host_alias", "host_name"],  "hostnameoralias", "~~", False),
+                          _("Search field allowing regular expressions and partial matches"))
+
+
 class FilterIPAddress(Filter):
-    def __init__(self):
-        Filter.__init__(self, "host_address", _("Host IP Address"), "host", ["host_address", "host_address_prefix"], ["host_address"])
+    def __init__(self, what):
+        self._what = what
+
+        if what == "primary":
+            varname = "host_address"
+            title = _("Host address (Primary)")
+            link_columns = ["host_address"]
+        elif what == "ipv4":
+            varname = "host_ipv4_address"
+            title = _("Host address (IPv4)")
+            link_columns = []
+        else:
+            varname = "host_ipv6_address"
+            title = _("Host address (IPv6)")
+            link_columns = []
+
+        # name, title, info, htmlvars, link_columns
+        Filter.__init__(self, varname, title, "host", [varname, varname+"_prefix"], link_columns)
 
     def display(self):
-        html.text_input("host_address")
+        html.text_input(self.htmlvars[0])
         html.write("<br><br>")
         html.begin_radio_group()
-        html.radiobutton("host_address_prefix", "yes", True, _("Prefix match"))
-        html.radiobutton("host_address_prefix", "no", False, _("Exact match"))
+        html.radiobutton(self.htmlvars[1], "yes", True, _("Prefix match"))
+        html.radiobutton(self.htmlvars[1], "no", False, _("Exact match"))
         html.end_radio_group()
 
     def double_height(self):
         return True
 
     def filter(self, infoname):
-        address = html.var("host_address")
+        address = html.var(self.htmlvars[0])
         if address:
-            if html.var("host_address_prefix") == "yes":
-                return "Filter: host_address ~ ^%s\n" % lqencode(address)
+            op = "="
+            if html.var(self.htmlvars[1]) == "yes":
+                op = "~"
+                address = "^" + lqencode(address)
             else:
-                return "Filter: host_address = %s\n" % lqencode(address)
+                address = lqencode(address)
+
+            if self._what == "primary":
+                return "Filter: host_address %s %s\n" % (op, address)
+            else:
+                varname = self._what == "ipv4" and "ADDRESS_4" or "ADDRESS_6"
+                return "Filter: host_custom_variables %s %s %s\n" % (op, varname, address)
         else:
             return ""
 
     def variable_settings(self, row):
-        return [ ("host_address", row["host_address"]) ]
+        return [ (self.htmlvars[0], row["host_address"]) ]
 
     def heading_info(self):
-        return html.var("host_address")
+        return html.var(self.htmlvars[0])
 
-declare_filter(102, FilterIPAddress())
 
+declare_filter(102, FilterIPAddress(what="primary"))
+declare_filter(102, FilterIPAddress(what="ipv4"))
+declare_filter(102, FilterIPAddress(what="ipv6"))
+
+
+class FilterAddressFamily(Filter):
+    def __init__(self):
+        Filter.__init__(self, name="address_family", title=_("Host address family (Primary)"),
+                        info="host", htmlvars=[ "address_family" ], link_columns=[])
+
+    def display(self):
+        html.begin_radio_group()
+        html.radiobutton("address_family", "4", False, _("IPv4"))
+        html.radiobutton("address_family", "6", False, _("IPv6"))
+        html.radiobutton("address_family", "both", True, _("Both"))
+        html.end_radio_group()
+
+    def filter(self, infoname):
+        family = html.var("address_family", "both")
+        if family == "both":
+            return ""
+        else:
+            return "Filter: host_custom_variables = ADDRESS_FAMILY %s\n" % lqencode(family)
+
+
+declare_filter(103, FilterAddressFamily())
+
+class FilterAddressFamilies(Filter):
+    def __init__(self):
+        Filter.__init__(self,
+            name="address_families", title=_("Host address families"),
+            info="host", htmlvars=[ "address_families", ], link_columns=[])
+
+    def display(self):
+        html.begin_radio_group()
+        html.radiobutton("address_families", "4", False, label="v4")
+        html.radiobutton("address_families", "6", False, label="v6")
+        html.radiobutton("address_families", "both", False, label=_("both"))
+        html.radiobutton("address_families", "4_only", False, label=_("only v4"))
+        html.radiobutton("address_families", "6_only", False, label=_("only v6"))
+        html.radiobutton("address_families", "", True, label=_("(ignore)"))
+        html.end_radio_group()
+
+    def filter(self, infoname):
+        family = html.var("address_families")
+        if not family:
+            return ""
+
+        elif family == "both":
+            return "Filter: host_custom_variables ~ TAGS (^|[ ])ip-v4($|[ ])\n" \
+                   "Filter: host_custom_variables ~ TAGS (^|[ ])ip-v6($|[ ])\n"
+        else:
+            if family[0] == "4":
+                tag = "ip-v4"
+            elif family[0] == "6":
+                tag = "ip-v6"
+            filt = "Filter: host_custom_variables ~ TAGS (^|[ ])%s($|[ ])\n" % lqencode(tag)
+
+            if family.endswith("_only"):
+                if family[0] == "4":
+                    tag = "ip-v6"
+                elif family[0] == "6":
+                    tag = "ip-v4"
+                filt += "Filter: host_custom_variables !~ TAGS (^|[ ])%s($|[ ])\n" % lqencode(tag)
+
+            return filt
+
+
+declare_filter(103, FilterAddressFamilies())
 
 # Helper that retrieves the list of host/service/contactgroups via Livestatus
 # use alias by default but fallback to name if no alias defined
@@ -142,7 +271,7 @@ class FilterMultigroup(Filter):
         return True
 
     def valuespec(self):
-        return DualListChoice(choices = all_groups(self.what), autoheight=False, enlarge_active=True)
+        return DualListChoice(choices = all_groups(self.what), rows=4, autoheight=False, enlarge_active=True)
 
     def selection(self):
         current = html.var(self.htmlvar, "").strip().split("|")
@@ -472,12 +601,14 @@ declare_filter(251, FilterNagiosExpression("service", "has_performance_data",
             "Filter: service_perf_data != \n",
             "Filter: service_perf_data = \n"))
 
-declare_filter(130, FilterNagiosFlag("host",    "host_in_notification_period",      _("Host in notif. period")))
+declare_filter(130, FilterNagiosFlag("host",    "host_in_notification_period",      _("Host in notification period")))
+declare_filter(130, FilterNagiosFlag("host",    "host_in_service_period",           _("Host in service period")))
 declare_filter(131, FilterNagiosFlag("host",    "host_acknowledged",                _("Host problem has been acknowledged")))
 declare_filter(132, FilterNagiosFlag("host",    "host_active_checks_enabled",       _("Host active checks enabled")))
 declare_filter(133, FilterNagiosFlag("host",    "host_notifications_enabled",       _("Host notifications enabled")))
 declare_filter(230, FilterNagiosFlag("service", "service_acknowledged",             _("Problem acknowledged")))
-declare_filter(231, FilterNagiosFlag("service", "service_in_notification_period",   _("Service in notif. per.")))
+declare_filter(231, FilterNagiosFlag("service", "service_in_notification_period",   _("Service in notification period")))
+declare_filter(231, FilterNagiosFlag("service", "service_in_service_period",        _("Service in service period")))
 declare_filter(233, FilterNagiosFlag("service", "service_active_checks_enabled",    _("Active checks enabled")))
 declare_filter(234, FilterNagiosFlag("service", "service_notifications_enabled",    _("Notifications enabled")))
 declare_filter(236, FilterNagiosFlag("service", "service_is_flapping",              _("Flapping")))
@@ -661,6 +792,10 @@ declare_filter(250, FilterTime("host", "host_last_state_change", _("Last host st
 declare_filter(251, FilterTime("host", "host_last_check", _("Last host check"), "host_last_check"))
 declare_filter(253, FilterTime("comment", "comment_entry_time", _("Time of comment"), "comment_entry_time" ))
 declare_filter(253, FilterTime("downtime", "downtime_entry_time", _("Time when downtime was created"), "downtime_entry_time" ))
+declare_filter(254, FilterText("downtime_comment", _("Downtime comment"), "downtime", "downtime_comment", "downtime_comment", "~"))
+declare_filter(255, FilterTime("downtime", "downtime_start_time", _("Start of downtime"), "downtime_start_time" ))
+declare_filter(256, FilterText("downtime_author", _("Downtime author"), "downtime", "downtime_author", "downtime_author", "~"))
+
 #    _
 #   | |    ___   __ _
 #   | |   / _ \ / _` |
@@ -733,11 +868,13 @@ class FilterLogClass(Filter):
             return "".join(headers) + ("Or: %d\n" % len(headers))
 
 declare_filter(255, FilterLogClass())
+#                               filter          title              info       column           htmlvar
 declare_filter(202, FilterUnicode("log_plugin_output",  _("Log: plugin output"), "log", "log_plugin_output", "log_plugin_output", "~~"))
-declare_filter(203, FilterText("log_type", _("Log: message type"), "log", "log_type", "log_type", "~~"))
-declare_filter(204, FilterText("log_state_type", _("Log: state type"), "log", "log_state_type", "log_state_type", "~~"))
-declare_filter(260, FilterText("log_contact_name",   _("Log: contact name"),  "log", "log_contact_name",  "log_contact_name",  "="),
+declare_filter(203, FilterText("log_type",           _("Log: message type"), "log", "log_type", "log_type", "~~"))
+declare_filter(204, FilterText("log_state_type",     _("Log: state type"), "log", "log_state_type", "log_state_type", "~~"))
+declare_filter(260, FilterText("log_contact_name",   _("Log: contact name (exact match)"),  "log", "log_contact_name",  "log_contact_name",  "="),
                                                                                                   _("Exact match, used for linking"))
+declare_filter(261, FilterText("log_contact_name_regex",   _("Log: contact name"),  "log", "log_contact_name",  "log_contact_name_regex",  "~~", negateable=True))
 
 class FilterLogState(Filter):
     def __init__(self):
@@ -781,6 +918,37 @@ class FilterLogState(Filter):
 
 declare_filter(270, FilterLogState())
 
+class NotificationPhaseFilter(FilterTristate):
+    def __init__(self):
+	FilterTristate.__init__(self, "log_notification_phase", _("Notification phase"), "log", "log_command_name", -1)
+
+    def double_height(self):
+        return True
+
+    def display(self):
+        current = html.var(self.varname)
+        html.begin_radio_group(horizontal = False)
+        for value, text in [
+            ("-1", _("Show all phases of notifications")),
+            ("1",  _("Show just preliminary notifications")),
+            ("0",  _("Show just end-user-notifications")),
+        ]:
+            checked = current == value or (current in [ None, ""] and int(value) == self.deflt)
+            html.radiobutton(self.varname, value, checked, text + " &nbsp; ")
+            html.write("<br>")
+        html.end_radio_group()
+
+    def filter_code(self, infoname, positive):
+        # Note: this filter also has to work for entries that are no notification.
+        # In that case the filter is passive and lets everything through
+        if positive:
+            return "Filter: %s = check-mk-notify\nFilter: %s =\nOr: 2\n" % (self.column, self.column)
+        else:
+            return "Filter: %s != check-mk-notify\n" % self.column
+
+
+declare_filter(271, NotificationPhaseFilter())
+
 class BIServiceIsUsedFilter(FilterTristate):
     def __init__(self):
 	FilterTristate.__init__(self, "aggr_service_used", _("Used in BI aggregate"), "service", None)
@@ -823,8 +991,8 @@ class FilterHostTags(Filter):
     def display(self):
         groups = [ (e[0], e[1].lstrip("/") ) for e in config.wato_host_tags ]
         operators = [
-            ("is", _("=")),
-            ("isnot", HTML(_("&ne;"))),
+            ("is", "="),
+            ("isnot", u"≠"),
         ]
 
         # replace unicode strings, before writing out as "json"
@@ -838,11 +1006,11 @@ class FilterHostTags(Filter):
                 if tag is None:
                     tag = ''
 
-                if type(title) == unicode:
-                    title = title.encode("utf-8")
+                # if type(title) == unicode:
+                #     title = title.encode("utf-8")
                 grouped[entry[0]].append([tag, title])
 
-        html.javascript('g_hosttag_groups = %r;' % grouped)
+        html.javascript('g_hosttag_groups = %s;' % json.dumps(grouped))
         html.write('<table>')
         for num in range(self.count):
             prefix = 'host_tag_%d' % num
@@ -915,7 +1083,7 @@ class FilterStarred(FilterTristate):
         icon = '<img class="icon inline" src="images/icon_starred.png"> '
         FilterTristate.__init__(self,
             name   = what + "_favorites",
-            title  = icon  + (what == "host" and _("Favorite Hosts") or _("Favorite Services")),
+            title  = HTML(icon  + (what == "host" and _("Favorite Hosts") or _("Favorite Services"))),
             info   = what,
             column = what + "_favorite", # Column, not used
             deflt  = -1,
