@@ -19,7 +19,7 @@
 # in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
 # out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
 # PARTICULAR PURPOSE. See the  GNU General Public License for more de-
-# ails.  You should have  received  a copy of the  GNU  General Public
+# tails. You should have  received  a copy of the  GNU  General Public
 # License along with GNU Make; see the file  COPYING.  If  not,  write
 # to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
 # Boston, MA 02110-1301 USA.
@@ -46,6 +46,9 @@ modules += [
       ( "static_checks",      _("Manual Checks"),     "static_checks", "rulesets",
       _("Configure fixed checks without using service discovery")),
 
+      ( "check_plugins",     _("Check Plugins"), "check_plugins", None,
+      _("Browse the catalog of all check plugins, create static checks")),
+
       ( "host_groups",       _("Host & Service Groups"),  "hostgroups", "groups",
       _("Organize your hosts and services in groups independent of the tree structure.") ),
 
@@ -68,7 +71,7 @@ modules += [
       ( "pattern_editor", _("Logfile Pattern Analyzer"), "analyze", "pattern_editor",
         _("Analyze logfile pattern rules and validate logfile patterns against custom text.")),
 
-      ( "bi_rules", _("BI - Business Intelligence"), "aggr", "bi_rules",
+      ( "bi_packs", _("BI - Business Intelligence"), "aggr", "bi_rules",
       _("Configuration of Check_MK's Business Intelligence component.")),
 
       ( "sites",  _("Distributed Monitoring"), "sites", "sites",
@@ -77,5 +80,14 @@ modules += [
       ( "snapshot", _("Backup & Restore"), "backup", "snapshots",
         _("Make snapshots of your configuration, download, upload and restore snapshots.")),
 
-    ]
+      ( "icons", _("Custom Icons"), "icons", "icons",
+        _("Upload your own icons that can be used in views or custom actions")),
+]
 
+# Register the builtin agent download page on the top level of WATO only when the agent bakery
+# does not exist (e.g. when using CRE)
+if "agents" not in modes:
+    modules.append(
+        ("download_agents", _("Monitoring Agents"), "download_agents", "download_agents",
+         _("Downloads the Check_MK monitoring agents"))
+    )
